(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1342620,      24837]*)
(*NotebookOutlinePosition[   1343297,      24861]*)
(*  CellTagsIndexPosition[   1343253,      24857]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(Needs["\<Controls`LinearControl`\>"]\)], "Input"],

Cell[BoxData[{
    \(par[r1_, r2_] := 1\/\(1\/r1 + 1\/r2\)\), "\[IndentingNewLine]", 
    \(ser[r1_, r2_] := r1 + r2\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = \(Solve[{Vout \[Equal] G\ V2, 
            V2 \[Equal] \(Z3\/\(Z2 + Z3\)\) 
                V1, \((Vout - V1)\)\/Z4 + \((Vin - V1)\)\/Z1 + \((V2 - \
V1)\)\/Z2 \[Equal] 0}, 
          Vout, {V1, 
            V2}]\)\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \({Vout \[Rule] \(-\(\(G\ Vin\ Z3\ Z4\)\/\(\(-Z1\)\ Z2 - Z1\ Z3 + 
                G\ Z1\ Z3 - Z1\ Z4 - Z2\ Z4 - Z3\ Z4\)\)\)}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(getZPK[
        f_] := \[IndentingNewLine]Block[{num, den, K0, Kinf, Q, freq, 
          sl}, \[IndentingNewLine]num = 
          Coefficient[Numerator[f], s, {0, 1, 2}]; 
        den = Coefficient[Denominator[f], 
            s, {0, 1, 2}]; \[IndentingNewLine]K0 = 
          Simplify[
            num\[LeftDoubleBracket]1\[RightDoubleBracket]/
              den\[LeftDoubleBracket]1\[RightDoubleBracket]]; 
        Kinf = Simplify[
            num\[LeftDoubleBracket]3\[RightDoubleBracket]/
              den\[LeftDoubleBracket]3\[RightDoubleBracket]]; \
\[IndentingNewLine]Print["\<K(f=0) = \>", \ K0, \ "\< (\>", 
          N[K0], "\<)\>"]; \[IndentingNewLine]Print["\<K(f=\[Infinity]) = \
\>", \ Kinf, \ "\< (\>", N[Kinf], "\<)\>"]; \[IndentingNewLine]sl = 
          Solve[Denominator[f] \[Equal] 0, 
            s]; \[IndentingNewLine]Print["\<Poles at = \>", \((\(s/2\)/\[Pi] /. 
              sl\[LeftDoubleBracket]1\[RightDoubleBracket])\), \ "\< and \>", \
\((\(s/2\)/\[Pi] /. 
              sl\[LeftDoubleBracket]2\[RightDoubleBracket])\), "\< \>"]; 
        freq = \(\@\(\((s /. sl\[LeftDoubleBracket]1\[RightDoubleBracket])\) \
\((s /. sl\[LeftDoubleBracket]2\[RightDoubleBracket])\)\)/2\)/\[Pi] // 
            PowerExpand; \[IndentingNewLine]Print["\<Pole frequency = \>", 
          freq, \ "\< (\>", 
          N[freq], "\<)\>"]; \[IndentingNewLine]Q = \(1/\((\(den\
\[LeftDoubleBracket]2\[RightDoubleBracket]/
                      den\[LeftDoubleBracket]3\[RightDoubleBracket]\)/\ \
\@\(den\[LeftDoubleBracket]1\[RightDoubleBracket]/den\[LeftDoubleBracket]3\
\[RightDoubleBracket]\))\) // Simplify\) // 
            PowerExpand; \[IndentingNewLine]Print["\<Pole Q = \>", 
          Q, \ "\< (\>", N[Q], "\<)\>"]; \[IndentingNewLine]sl = 
          Solve[Numerator[f] \[Equal] 0, 
            s]; \[IndentingNewLine]freq = \(\@\(\((s /. \
sl\[LeftDoubleBracket]1\[RightDoubleBracket])\) \((s /. \
sl\[LeftDoubleBracket]2\[RightDoubleBracket])\)\)/2\)/\[Pi] // 
            PowerExpand; \[IndentingNewLine]Print["\<Zero frequency = \>", 
          freq, "\< (\>", 
          N[freq], "\<)\>"]; \[IndentingNewLine]Q = \(1/\((\(num\
\[LeftDoubleBracket]2\[RightDoubleBracket]/
                      num\[LeftDoubleBracket]3\[RightDoubleBracket]\)/\ \
\@\(num\[LeftDoubleBracket]1\[RightDoubleBracket]/num\[LeftDoubleBracket]3\
\[RightDoubleBracket]\))\) // Simplify\) // 
            PowerExpand; \[IndentingNewLine]Print["\<Zero Q = \>", 
          Q, \ "\< (\>", N[Q], "\<)\>"];\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["High Pass", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Vout/Vin /. sol\) /. {Z1 \[Rule] 1\/\(s\ C\), Z2 \[Rule] 1\/\(s\ C\), 
          Z3 \[Rule] R, Z4 \[Rule] R, G \[Rule] 3 - \@2} // 
      Simplify\), "\[IndentingNewLine]", 
    \(getZPK[%]\), "\[IndentingNewLine]", 
    \(\(%% /. {R \[Rule] 1, C \[Rule] 1/\((2  \[Pi])\), 
          s \[Rule] 2\ \[Pi]\ \[ImaginaryI]\ f};\)\), "\[IndentingNewLine]", 
    \(\(BodePlot[%, {f, 0.01, 100}];\)\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\((\(-3\) + \@2)\)\ C\^2\ R\^2\ s\^2\)\/\(1 + \@2\ C\ R\ s + 
            C\^2\ R\^2\ s\^2\)\)\)\)], "Output"],

Cell[BoxData[
    InterpretationBox[\("K(f=0) = "\[InvisibleSpace]0\[InvisibleSpace]" ("\
\[InvisibleSpace]0.`\[InvisibleSpace]")"\),
      SequenceForm[ "K(f=0) = ", 0, " (", 0.0, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("K(f=\[Infinity]) = "\[InvisibleSpace]\(3 - \@2\)\
\[InvisibleSpace]" ("\[InvisibleSpace]1.5857864376269049`\[InvisibleSpace]")"\
\),
      SequenceForm[ "K(f=\[Infinity]) = ", 
        Plus[ 3, 
          Times[ -1, 
            Power[ 2, 
              Rational[ 1, 2]]]], " (", 1.5857864376269049, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole frequency = "\[InvisibleSpace]1\/\(2\ C\ \[Pi]\ \
R\)\[InvisibleSpace]" ("\[InvisibleSpace]0.15915494309189535`\/\(C\ R\)\
\[InvisibleSpace]")"\),
      SequenceForm[ "Pole frequency = ", 
        Times[ 
          Rational[ 1, 2], 
          Power[ C, -1], 
          Power[ Pi, -1], 
          Power[ R, -1]], " (", 
        Times[ .15915494309189535, 
          Power[ C, -1], 
          Power[ R, -1]], ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole Q = "\[InvisibleSpace]1\/\@2\[InvisibleSpace]" \
("\[InvisibleSpace]0.7071067811865475`\[InvisibleSpace]")"\),
      SequenceForm[ "Pole Q = ", 
        Power[ 2, 
          Rational[ -1, 2]], " (", .70710678118654746, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Zero Q = "\[InvisibleSpace]Indeterminate\
\[InvisibleSpace]" ("\[InvisibleSpace]Indeterminate\[InvisibleSpace]")"\),
      SequenceForm[ "Zero Q = ", Indeterminate, " (", Indeterminate, ")"],
      Editable->False]], "Print"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.246914 0.587286 0.00762758 [
[.00617 -0.0125 -14 -12.5625 ]
[.00617 -0.0125 14 0 ]
[.25309 -0.0125 -11 -12.5625 ]
[.25309 -0.0125 11 0 ]
[.5 -0.0125 -5 -12.5625 ]
[.5 -0.0125 5 0 ]
[.74691 -0.0125 -8 -12.5625 ]
[.74691 -0.0125 8 0 ]
[.99383 -0.0125 -11 -12.5625 ]
[.99383 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -8 -25.125 ]
[.5 -0.0125 8 -12.5625 ]
[-0.0125 .12963 -18 -4.5 ]
[-0.0125 .12963 0 4.5 ]
[-0.0125 .28218 -18 -4.5 ]
[-0.0125 .28218 0 4.5 ]
[-0.0125 .43473 -18 -4.5 ]
[-0.0125 .43473 0 4.5 ]
[-0.0125 .58729 -6 -4.5 ]
[-0.0125 .58729 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -8 ]
[-0.01875 .30902 -18 8 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12.5625 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .12963 m
1 .12963 L
s
0 .28218 m
1 .28218 L
s
0 .43473 m
1 .43473 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -69 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12963 m
.00625 .12963 L
s
[(-60)] -0.0125 .12963 1 0 Mshowa
0 .28218 m
.00625 .28218 L
s
[(-40)] -0.0125 .28218 1 0 Mshowa
0 .43473 m
.00625 .43473 L
s
[(-20)] -0.0125 .43473 1 0 Mshowa
0 .58729 m
.00625 .58729 L
s
[(0)] -0.0125 .58729 1 0 Mshowa
.125 Mabswid
0 .16777 m
.00375 .16777 L
s
0 .20591 m
.00375 .20591 L
s
0 .24405 m
.00375 .24405 L
s
0 .32032 m
.00375 .32032 L
s
0 .35846 m
.00375 .35846 L
s
0 .3966 m
.00375 .3966 L
s
0 .47287 m
.00375 .47287 L
s
0 .51101 m
.00375 .51101 L
s
0 .54915 m
.00375 .54915 L
s
0 .09149 m
.00375 .09149 L
s
0 .05336 m
.00375 .05336 L
s
0 .01522 m
.00375 .01522 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -93.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 10.2813 translate
90 rotate
-69 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dB) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Magnitude) show
117.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .00763 m
.03955 .04887 L
.06699 .08278 L
.08762 .10827 L
.1043 .12887 L
.11959 .14777 L
.1325 .16373 L
.14471 .17881 L
.15529 .19188 L
.16457 .20335 L
.17363 .21454 L
.18168 .2245 L
.1889 .23341 L
.19608 .24229 L
.20256 .2503 L
.20906 .25832 L
.21496 .26561 L
.22034 .27227 L
.22579 .279 L
.23079 .28518 L
.23585 .29143 L
.24052 .2972 L
.24482 .30252 L
.24922 .30795 L
.25309 .31273 L
s
.25309 .31273 m
.28646 .35396 L
.31391 .38785 L
.33453 .4133 L
.35121 .43385 L
.3665 .45265 L
.37942 .46847 L
.39162 .48334 L
.4022 .49614 L
.41148 .50725 L
.42054 .51798 L
.4286 .52737 L
.43581 .53562 L
.44299 .54366 L
.44948 .55072 L
.45597 .55757 L
.46187 .56356 L
.46726 .56881 L
.4727 .57389 L
.4777 .57831 L
.48277 .58254 L
.48743 .58621 L
.49174 .58938 L
.49613 .5924 L
.5 .59487 L
s
.5 .59487 m
.50873 .59983 L
.51754 .60397 L
.53337 .60945 L
.54093 .61132 L
.54845 .6128 L
.56082 .61457 L
.56654 .61517 L
.57241 .61568 L
.58233 .61633 L
.59127 .61675 L
.60001 .61705 L
.60753 .61724 L
.61412 .61737 L
.62042 .61746 L
.62689 .61754 L
.63325 .6176 L
.63897 .61765 L
.64473 .61768 L
.64969 .61771 L
.65908 .61775 L
.66792 .61777 L
.67578 .61779 L
.68356 .6178 L
.69055 .61781 L
.69687 .61781 L
.70321 .61782 L
.70898 .61782 L
.71479 .61782 L
.72011 .61782 L
.72498 .61783 L
.72993 .61783 L
.7345 .61783 L
.73871 .61783 L
.74302 .61783 L
.74691 .61783 L
s
.74691 .61783 m
.75564 .61783 L
.76446 .61783 L
.77294 .61783 L
.78029 .61783 L
.78792 .61783 L
.79443 .61783 L
.80147 .61783 L
.80773 .61783 L
.81317 .61783 L
.81864 .61783 L
.82781 .61783 L
.83674 .61783 L
.84447 .61783 L
.85243 .61783 L
.85923 .61783 L
.86578 .61783 L
.87249 .61783 L
.87899 .61783 L
.88456 .61783 L
.89502 .61783 L
.89981 .61783 L
.90476 .61783 L
.9139 .61783 L
.92201 .61783 L
.92928 .61783 L
.93651 .61783 L
.94303 .61783 L
.94956 .61783 L
.9555 .61783 L
.96091 .61783 L
.96639 .61783 L
.97141 .61783 L
.97602 .61783 L
.98073 .61783 L
.98507 .61783 L
.9895 .61783 L
.9936 .61783 L
.99383 .61783 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00hWoo0`000Woo0`000Woo1P00_Woo003S
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000_Woo003SOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`2oOol00>=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
0;ioo`00hgoo1P000goo00D007ooOomoo`000;moo`00hgoo00<007ooOol00Woo00@007ooOomoo`H0
0;ioo`00hgoo00<007ooOol00Woo00<007ooOol0aGoo003ROol30002Ool30036Ool00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo000iOol40006Ool20006Ool40004Ool7000dOol40006Ool20005Ool7
0010Ool70015Ool70003Ool4000nOol70003Ool40005Ool4000KOol003Qoo`03001oogoo009oo`03
001oogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo
009oo`03001oogoo00=oo`8000Qoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03001o
ogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo
00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo
00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qo
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Ao
o`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03
001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001o
ogoo00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol0
03Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo009oo`<003Ioo`03
001oogoo009oo`03001oogoo00]oo`<004Aoo`<004Uoo`<000Eoo`03001oogoo009oo`03001oogoo
03aoo`<000Eoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Uoo`@000io
o`@000Moo`03001oogoo03Eoo`@0011oo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00Ao
o`@0045oo`03001oogoo00Aoo`@000Eoo`@001]oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo0017Oooo0018000ROol004Moo`03001oo`0001Moo`03
001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`0FOol00`00Oomoo`0;Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007oo
Ool00goo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol0000GOol00`00Oomoo`0;
Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool01@00Oomoogoo00000Woo00@007ooOol0029oo`00Agoo00<007oo00005goo00<007ooOol02goo
00<007ooOol01goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo
00D007ooOomoo`00009oo`03001oogoo01Ioo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo
00Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00
Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool01@00Oomoogoo00000goo00D007ooOomoo`0001Moo`03001oogoo00]oo`03001oogoo
00Qoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogoo
Ool00002Ool01000Oomoo`008Woo0017Ool00`00Ool0000GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`04001oo`0?000FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool004Moo`80000300moo`0001Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo
00<007oo00l00Woo00<007ooOol04Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017
Ool00`00Ool03`02Ool00`00Oomoo`0BOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?00=oo`03001oogoo015oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029o
o`00Agoo00<007oo00l017oo00<007ooOol047oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool03`05Ool00`00Oomoo`0?Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo
000ROol004Moo`03001oo`0?00Ioo`03001oogoo00ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`00Agoo00<007oo00l01goo00<007ooOol03Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`07Ool00`00Oomoo`0=Ool00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?00Qoo`03001oogoo00aoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l02Goo00<007ooOol02goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0:Ool00`00Oomoo`0:Ool00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol004Moo`03001oo`0?00]oo`03001oogoo00Uoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo0P0000<03gooOol02Woo00<007ooOol027oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0<Ool00`00Oomoo`08Ool00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?00eoo`03001oogoo00Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l03Woo00<007ooOol01Woo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0?Ool00`00Oomoo`05Ool0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?011oo`03001oogoo00Ao
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l04Goo00<007ooOol0
0goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0AOol00`00Oomo
o`03Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?019oo`03001o
ogoo009oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l04goo00D0
07ooOomoo`0?00eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l057oo00@007ooOol0
3`eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l057oo00@007ooOol03`eoo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00Agoo0P0000<03gooOol04goo00<007oo00l03Goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`0FOol00`0000moo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?01Ioo`0300003goo00aoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<007ooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
001oo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300l007oo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03goo00002goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`0GOol0100?Oomoo`002Woo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo
0017Ool00`00Ool03`0GOol01@0?Oomoogoo00002Goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000dOol4
0004Ool40007Ool00`00Ool03`0GOol00`0?Oomoo`02Ool00`00Oomoo`06Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol003=oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`04Ool00`00Ool03`0G
Ool00`0?Oomoo`03Ool00`00Oomoo`05Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol003=oo`03001oogoo
009oo`04001oogoo0004Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`04Ool00`00Oomo
o`04Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo000ROol003=oo`8000=oo`04001oogoo0004Ool00`00Oomoo`04
Ool00`00Ool03`0GOol00`0?Oomoo`05Ool00`00Oomoo`03Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
02Uoo`H000Aoo`03001oo`00008000=oo`03001oogoo009oo`03001oogoo00Aoo`<002003`030000
3`0?0?l03b403`03001oogoo021oo`00<goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0
17oo00<007oo00l05goo00<03gooOol01goo00D007ooOomoo`0?00Uoo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=7oo00<0
07ooOol017oo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol01goo00D0
07ooOomoo`0?00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol0029oo`00=Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
17oo00<007oo00l05goo00<03gooOol027oo00@007ooOol03`Uoo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=Woo0`000goo
10001goo00<007oo00l05goo00<03gooOol02Goo00<007oo00l02Goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00
Ool03`0GOol00`0?Oomoo`0:Ool00`0000moo`08Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`03
00moogoo00]oo`03001oogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo
00<007ooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?001oo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moo`0000Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029o
o`00Agoo00<007oo00l05goo00<03gooOol02goo00<03goo00001goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00
Ool03`0GOol00`0?Oomoo`0;Ool0100?Oomoo`001Woo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool200000`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool01@0?Oomoogoo00001Goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`02Ool00`00Oomoo`02Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`03
00moogoo00]oo`0300moogoo009oo`03001oogoo009oo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol00goo00D007ooOomoo`0?00Moo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03goo
Ool02goo00<03gooOol017oo00@007ooOol03`Moo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01Goo00<007oo00l01goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`06Ool0
0`0000moo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03001oogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03`00Ool01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Ool00005Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moo`0000Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00@03gooOol000Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo0P0000<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00D03gooOomoo`0000=oo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol00Woo00@007ooOol03`Ioo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol00Woo
00@007ooOol03`Ioo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol00goo00<007oo00l0
1Woo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0000moo`05Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03001oogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03`00Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Ool00004Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moo`0000Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00@03gooOol0
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00D03gooOomoo`00009oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00Woo00<007oo00l017oo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0000moo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`80000300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03001oogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<007ooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?001oo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Mo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moo`00009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00H03gooOol0
07oo00l4Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0600moogooOol0000?17oo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool01P0?Oomoogoo00003`Aoo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<007ooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?001oo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol003Aoo`@000Aoo`@000Moo`03001oo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moo`00009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=Woo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo00000Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo000fOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool01P0?
Oomoo`00Ool03`=oo`0400moogoo00lHOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00<Woo1P000goo00<007ooOol00Woo00<007ooOol017oo0`00A`0?
00<0000?00l0n@0?00<007ooOol087oo000YOol60004Ool01000Oomoo`0017oo00<007ooOol00Woo
00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D007ooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000K
Ool4000DOol01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03`00Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo000JOol00`00Oomoo`02Ool00`00Oomoo`0BOol0
0`00Ool00004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Ool007oo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol001Yoo`03001oogoo009oo`03001oogoo019oo`03001oo`0000Ao
o`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moo`00Ool0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`006Woo00<007ooOol00Woo00<007ooOol04goo0P001Goo10001goo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOol0000?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000GOol01000Oomoo`000goo00<007oo
Ool09Woo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`00009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000GOol9000W
Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomoogoo00l007oo00lHOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`007goo00<007ooOol09Goo00<0
07oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00P03gooOomoo`0?001oo`0?67oo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0800moogooOol03goo00003aQoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<007ooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol001Qoo`03001oogoo00Aoo`03001oogoo02Eoo`03001oo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?001oo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol0029oo`0067oo20009goo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moo`0001Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo000HOol01000Oomoo`000goo00<007ooOol09Goo0P0000<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moo`0001Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000HOol01000Oomoo`000goo00<007oo
Ool09Goo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`0067oo00@0
07ooOol000=oo`03001oogoo02Eoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool01@0?Oomoogoo000057oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol001Qoo`04001oogoo0003Ool00`00Oomoo`0UOol00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol00Woo00<007ooOol04Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol001Uoo`800004Ool00000000XOol0
0`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol00Woo00<007ooOol0
4Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Mo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`03Ool00`00Oomo
o`0@Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo00Aoo`03001o
ogoo00moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo
0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol01Goo00<0
07ooOol03Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`06Ool0
0`00Oomoo`0=Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo00Io
o`03001oogoo00eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
1goo00<007ooOol037oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`08Ool00`00Oomoo`0;Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`00Agoo0P0000<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo00Uoo`03001oogoo00Yoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol02Woo00<007ooOol02Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0:Ool00`00Oomoo`09Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo00]oo`03001oogoo00Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol037oo00<007ooOol01goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0=Ool00`00Oomoo`06Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo00ioo`03001oogoo00Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol03goo00<007ooOol017oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0?Ool00`00Oomoo`04Ool00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo011oo`03001oogoo00=oo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol04Goo00<007ooOol00Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol01@00Oomoogoo00l03Goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`80000300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0COol01000Oomoo`0?3Goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0DOol00`00Ool03`0=Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Aoo`03001oo`0?00eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Goo
00<0000?Ool037oo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`00Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300l007oo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo00002goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol0100?Oomoo`002Woo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol0100?Oomoo`002Woo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo
000ROol0039oo`H000Aoo`@000Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol01@0?Oomoogoo00002Goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol0039oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol00Woo
00<007ooOol01Woo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol003=oo`03
001oogoo00Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`03Ool00`00Oomoo`05Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=7oo00<007ooOol017oo00<007ooOol00Woo
00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00=oo`03001oogoo00Eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo000YOol60006Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool3001_
00l00`0000l03`3A00l00`00Oomoo`0POol003Ioo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`05Ool00`00Oomoo`03Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00<Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`06Ool00`00Oomo
o`02Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00<Woo00<007ooOol0
0Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`06Ool00`00Oomoo`02Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`00<goo10001Goo10001goo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00Moo`05001oogooOol0
3`09Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00Qoo`04001oogoo00l9Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00Uoo`03001oo`0?00Uoo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02Woo00<0000?Ool027oo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo
000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`00Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`03001oogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03`00
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Ool00007Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo0P0000<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0400moogoo0006Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0500moogooOol00005Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0500moogooOol00005Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo009oo`03001oogoo009oo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol00goo00D007ooOomoo`0?00Moo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol017oo00@007ooOol03`Moo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool0
0`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01Goo00<007oo00l01goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`06Ool00`0000moo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03001o
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03`00Ool01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?001oo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moo`0000Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool0
0`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01goo00@03gooOol000Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool200000`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00D03gooOomoo`0000=oo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol00Woo00@007ooOol03`Eoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool00goo00<007oo00l01Goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`00
00moo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Aoo`0300003goo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<007ooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?001oo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moo`0000=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00@03gooOol0009oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00L0
3gooOomoo`00Ool03`04Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo009oo`030000
3goo00=oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo
0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<007ooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`800003
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`00Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300l007oo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03goo00000Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool01P0?Oomoo`00Ool03`Aoo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00H03gooOomo
o`0000l4Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03001oogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03`00Ool00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Ool00002Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo0080000500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo000lOol40007Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00H03gooOomoo`0000l3Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
>goo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`05001oogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`008Woo000kOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03`00001oo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo000ROol003]oo`03001oogoo009oo`03001oogoo00Aoo`03001o
o`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
0`0?Oomoo`020003Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000kOol00`00Oomoo`02Ool00`00
Oomoo`04Ool3000GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00H03gooOomoo`0?0002Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000kOol00`00Oomo
o`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00T03gooOomoo`0?Ool007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
>goo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool2000GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo000kOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300l0
000001Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol003aoo`@000Moo`03001oo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol0
01Aoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOomoo`<0015oo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol017oo0`003Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`07Ool50009Ool00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool0000GOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00<007ooOol05Woo
00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00aoo`H000=oo`03001oogoo00]oo`03
001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol00003
Ool01@00Oomoogoo00005goo00<007ooOol02goo00<007ooOol027oo00<007ooOol017oo00<007oo
Ool017oo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo000ROol0
04Moo`03001oo`0001Moo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`0FOol00`00
Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol04Woo90001Goo00<007ooOol00goo00D007oo
Oomoo`0000=oo`05001oogooOol0000GOol00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`04
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007oo
Ool0029oo`00Agooo`00B0008Woo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5o
o`00ogoo/Goo003EOol4003GOol00=Uoo`03001oogoo0=Aoo`00fGoo00<007ooOol0e7oo0031Ool3
0003Ool30003Ool50003Ool300000goo001oo`02Ool30002Ool300000goo000000050005Ool40004
Ool300000goo00000002Ool300000goo00000004Ool4002POol00<9oo`03001oogoo00=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo0P0017oo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol01Goo00<007ooOol00Woo00@007ooOol000=oo`80009oo`04001oogooOol20004Ool00`00
Oomoo`02Ool00`00Oomoo`2MOol00<9oo`04001oogoo0002Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`2ROol0
0<9oo`07001oo`00Ool007oo000017oo10000goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol00Woo00@007oo
Ool000Aoo`03001oogoo009oo`H009moo`00`Woo00L007oo001oo`00Ool00003Ool01@00Oomoogoo
00000goo00@007ooOomoo`8000Aoo`8000=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo009oo`04001oogoo0003Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`2MOol0
0<9oo`07001oo`00Ool007oo000017oo0`001Goo0`0000=oo`0000000Woo0P0000Aoo`00000000Ao
o`<000Eoo`L0009oo`8000=oo`8000=oo`<00003Ool007oo00Aoo`@00:1oo`00`Woo0P000goo0P00
:7oo00<007ooOol04Woo00<007ooOol0Ygoo0031Ool30003Ool3000WOol00`00Oomoo`0BOol00`00
Oomoo`2WOol00>Uoo`03001oogoo01Uoo`800:Uoo`00jGoo00<007ooOol0a7oo003oOonaOol00?mo
ok5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.91386, -93.8113, \
0.0186604, 0.60406}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.246914 1.24258 0.00345762 [
[.00617 -0.0125 -14 -12.5625 ]
[.00617 -0.0125 14 0 ]
[.25309 -0.0125 -11 -12.5625 ]
[.25309 -0.0125 11 0 ]
[.5 -0.0125 -5 -12.5625 ]
[.5 -0.0125 5 0 ]
[.74691 -0.0125 -8 -12.5625 ]
[.74691 -0.0125 8 0 ]
[.99383 -0.0125 -11 -12.5625 ]
[.99383 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -8 -25.125 ]
[.5 -0.0125 8 -12.5625 ]
[-0.0125 .03241 -24 -4.5 ]
[-0.0125 .03241 0 4.5 ]
[-0.0125 .11885 -24 -4.5 ]
[-0.0125 .11885 0 4.5 ]
[-0.0125 .20529 -24 -4.5 ]
[-0.0125 .20529 0 4.5 ]
[-0.0125 .29173 -24 -4.5 ]
[-0.0125 .29173 0 4.5 ]
[-0.0125 .37817 -24 -4.5 ]
[-0.0125 .37817 0 4.5 ]
[-0.0125 .46461 -24 -4.5 ]
[-0.0125 .46461 0 4.5 ]
[-0.0125 .55105 -24 -4.5 ]
[-0.0125 .55105 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -20 ]
[-0.01875 .30902 -24 20 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12.5625 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .03241 m
1 .03241 L
s
0 .11885 m
1 .11885 L
s
0 .20529 m
1 .20529 L
s
0 .29173 m
1 .29173 L
s
0 .37817 m
1 .37817 L
s
0 .46461 m
1 .46461 L
s
0 .55105 m
1 .55105 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -69 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .03241 m
.00625 .03241 L
s
[(-350)] -0.0125 .03241 1 0 Mshowa
0 .11885 m
.00625 .11885 L
s
[(-325)] -0.0125 .11885 1 0 Mshowa
0 .20529 m
.00625 .20529 L
s
[(-300)] -0.0125 .20529 1 0 Mshowa
0 .29173 m
.00625 .29173 L
s
[(-275)] -0.0125 .29173 1 0 Mshowa
0 .37817 m
.00625 .37817 L
s
[(-250)] -0.0125 .37817 1 0 Mshowa
0 .46461 m
.00625 .46461 L
s
[(-225)] -0.0125 .46461 1 0 Mshowa
0 .55105 m
.00625 .55105 L
s
[(-200)] -0.0125 .55105 1 0 Mshowa
.125 Mabswid
0 .0497 m
.00375 .0497 L
s
0 .06698 m
.00375 .06698 L
s
0 .08427 m
.00375 .08427 L
s
0 .10156 m
.00375 .10156 L
s
0 .13614 m
.00375 .13614 L
s
0 .15342 m
.00375 .15342 L
s
0 .17071 m
.00375 .17071 L
s
0 .188 m
.00375 .188 L
s
0 .22258 m
.00375 .22258 L
s
0 .23986 m
.00375 .23986 L
s
0 .25715 m
.00375 .25715 L
s
0 .27444 m
.00375 .27444 L
s
0 .30902 m
.00375 .30902 L
s
0 .32631 m
.00375 .32631 L
s
0 .34359 m
.00375 .34359 L
s
0 .36088 m
.00375 .36088 L
s
0 .39546 m
.00375 .39546 L
s
0 .41275 m
.00375 .41275 L
s
0 .43003 m
.00375 .43003 L
s
0 .44732 m
.00375 .44732 L
s
0 .4819 m
.00375 .4819 L
s
0 .49919 m
.00375 .49919 L
s
0 .51647 m
.00375 .51647 L
s
0 .53376 m
.00375 .53376 L
s
0 .01512 m
.00375 .01512 L
s
0 .56834 m
.00375 .56834 L
s
0 .58563 m
.00375 .58563 L
s
0 .60291 m
.00375 .60291 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -111.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
81 10.2813 translate
90 rotate
-81 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(degree) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phase) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .6174 m
.03955 .61638 L
.06699 .61526 L
.08762 .61421 L
.1043 .61321 L
.11959 .61213 L
.1325 .6111 L
.14471 .61 L
.15529 .60894 L
.16457 .60792 L
.17363 .60684 L
.18168 .60579 L
.1889 .60479 L
.19608 .60372 L
.20256 .60269 L
.20906 .60159 L
.21496 .60054 L
.22034 .59952 L
.22579 .59844 L
.23079 .5974 L
.23585 .59629 L
.24052 .59522 L
.24482 .59419 L
.24922 .5931 L
.25309 .59209 L
s
.25309 .59209 m
.28646 .58172 L
.31391 .5703 L
.33453 .55944 L
.35121 .54885 L
.3665 .53741 L
.37942 .52622 L
.39162 .51411 L
.4022 .50225 L
.41148 .49064 L
.42054 .47811 L
.4286 .46587 L
.43581 .45398 L
.44299 .4412 L
.44948 .42883 L
.45597 .41566 L
.46187 .403 L
.46726 .3909 L
.4727 .37815 L
.4777 .36607 L
.48277 .35347 L
.48743 .34163 L
.49174 .33054 L
.49613 .31911 L
.5 .30902 L
s
.5 .30902 m
.53337 .22569 L
.56082 .16993 L
.58144 .13707 L
.59812 .1154 L
.61342 .09873 L
.62633 .08665 L
.63854 .07665 L
.64912 .06896 L
.65839 .06287 L
.66745 .05745 L
.67551 .05303 L
.68272 .04936 L
.68991 .04596 L
.69639 .04309 L
.70288 .04039 L
.70878 .03808 L
.71417 .03608 L
.71962 .03417 L
.72461 .0325 L
.72968 .03088 L
.73435 .02946 L
.73865 .02821 L
.74305 .02698 L
.74691 .02594 L
s
.74691 .02594 m
.78029 .01839 L
.80773 .01374 L
.82836 .01095 L
.84504 .00906 L
.86033 .00756 L
.87324 .00646 L
.88545 .00553 L
.89603 .00481 L
.90531 .00423 L
.91437 .00371 L
.92242 .00328 L
.92964 .00293 L
.93682 .0026 L
.9433 .00232 L
.9498 .00206 L
.9557 .00183 L
.96108 .00163 L
.96653 .00144 L
.97153 .00128 L
.97659 .00112 L
.98126 .00098 L
.98556 .00086 L
.98996 .00074 L
.99383 .00063 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00iWoo0`000Woo0`000Woo1P00^Woo003W
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000^Woo003WOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`2kOol00>Moo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
0;Yoo`00igoo1P000goo00D007ooOomoo`000;]oo`00igoo00<007ooOol00Woo00@007ooOomoo`H0
0;Yoo`00igoo00<007ooOol00Woo00<007ooOol0`Goo003VOol30002Ool30032Ool00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo000nOol40006Ool20006Ool40004Ool7000cOol40006Ool20005Ool7
0011Ool70015Ool70003Ool4000mOol70003Ool40005Ool4000GOol003eoo`03001oogoo009oo`03
001oogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=oo`03001oogoo
009oo`03001oogoo00=oo`8000Qoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Eoo`03001o
ogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001oogoo
00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001oogoo
00eoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003eo
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=o
o`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Eoo`03
001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001o
ogoo00eoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol0
03eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo009oo`<003Eoo`03
001oogoo009oo`03001oogoo00]oo`<004Eoo`<004Uoo`<000Eoo`03001oogoo009oo`03001oogoo
03]oo`<000Eoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003ioo`@000io
o`@000Moo`03001oogoo03Aoo`@0011oo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00Ao
o`@0041oo`03001oogoo00Aoo`@000Eoo`@001Moo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo001;Oooo0018000NOol004]oo`03001oo`0001Qoo`03
001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo000017oo00@007oo
Ool001Moo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool0
0`00Oomoo`07Ool00`00Oomoo`05OolI00000goo001oo`0MOol004]oo`03001oo`0001Qoo`03001o
ogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`07Ool0
0`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo000017oo00@007ooOol0
01Moo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo
009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00
Ool0000@0005Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00L007ooOomoo`00Ool0000NOol0
04]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`03Ool:0008Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMo
o`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0DOol70008Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomo
o`0?Ool0000NOol004]oo`<001Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0<Ool800000goo00moo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001o
o`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
17oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`06Ool60009
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002ioo`@000Eoo`@000Eoo`@000Mo
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`03
Ool3000?Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002eoo`03001oogoo009o
o`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l067oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomo
o`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0000<0019oo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01`0?Oomoogoo00moo`0001ioo`00<Woo00<007ooOol01Woo00D007ooOomoo`0000Aoo`03
001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0600moogooOol03goo1000
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000bOol00`00Oomoo`06Ool01@00
Oomoogoo000017oo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00<0
3goo00000`000Woo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
000TOol60006Ool20009Ool01@00Oomoogoo000017oo00<007ooOol017oo0`00j@0?0P00F00?00<0
07ooOol077oo000bOol00`00Oomoo`02Ool40004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Ool0000200001@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000bOol00`00Oomoo`02Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool20003Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000]
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?0000000200000`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000^Ool40005Ool50004Ool40007
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool20004Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0100?Oomoogoo0P0000=oo`0?Ool00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?
Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo
00<03gooOol017oo00@03goo000000=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300l0
07oo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMo
o`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00=oo`8000Ioo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomo
o`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Mo
o`0400moogooOol200000goo00moo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0100?Oomoo`000goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<0
3gooOol037oo00<03gooOol01goo00<03`00000017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomo
ogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol0
1goo00<007ooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo
00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01Goo0P0000<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomo
o`0?5goo00<03gooOol037oo00<03gooOol00goo0P000Woo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03goo
Ool037oo00<03gooOol00Woo00<007ooOol00Woo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo
00D03gooOomoo`0000Eoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol004]oo`<001Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0400moogoo0006Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`04
00moogoo00lGOol00`0?Oomoo`0<Ool00`0?Ool00007Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomo
o`0<Ool00`0?001oo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol0
3goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`00Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0400moogoo00lGOol00`0?Oomoo`0;Ool00`0000moo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomo
o`0:Ool00`00Ool03`09Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol0
3goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`09Ool01000Oomoo`0?2Goo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<0
07oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`04Ool0100?Oomoo`0?5goo00<03gooOol027oo00D007ooOomoo`0?00Uoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002ioo`@000Aoo`H000Aoo`@000Mo
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03aMoo`0300moogoo00Moo`03001oogoo009oo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002eoo`03001o
ogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l0
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0
100?Oomoo`0?5goo00<03gooOol01Woo00<007ooOol00goo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00<Woo00<007ooOol00Woo00<0
07ooOol02Woo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol01Goo00<007oo
Ool017oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo
00moo`0001ioo`00<Woo00<007ooOol00goo00<007ooOol02Goo00<007ooOol017oo0`00_`0?00<0
000?00l0P@0?00<007ooOol077oo000TOol60006Ool20007Ool00`00Oomoo`08Ool00`00Oomoo`04
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`04Ool00`00Oomoo`05Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000bOol00`00
Oomoo`05Ool00`00Oomoo`03Ool40007Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`03Ool0
0`00Oomoo`06Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700mo
ogooOol03goo00007Woo000bOol01@00Oomoogoo000017oo00<007ooOol00Woo00<007ooOol027oo
00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`04Ool0100?Oomoo`0?5goo00<03gooOol00Woo00<007ooOol01goo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00;Goo00<007oo
Ool00Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo00Qoo`03001oo`0?01Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03aMoo`0500moogooOol0000:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo000^Ool40005Ool40005Ool50006Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`04
00moogoo00lGOol01@0?Oomoogoo00002Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00@03gooOol0
00]oo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moo`0000aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001o
o`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
17oo00@03gooOol03aMoo`0300moo`0000aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03
00l007oo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03001oogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]o
o`<001Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
17oo00@03gooOol03aMoo`03001oogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aIoo`03
00003goo00eoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aIoo`0300003goo00eoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]o
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03aEoo`03001oo`0?00ioo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3aAoo`04001oogoo00l>Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lDOol01000Oomoo`0?3Woo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`00
01ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`04Ool0100?Oomoo`0?4goo00D007ooOomoo`0?00ioo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@0
3gooOol03a9oo`03001oogoo009oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3a9oo`03001oogoo009oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03a5oo`03
001oogoo00=oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03a5oo`03001oogoo
00=oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03a1oo`03001oogoo00Aoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol004]oo`<001Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l017oo00@03gooOol03a1oo`03001oogoo00Aoo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03`moo`03001oogoo00Eoo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002io
o`@000Eoo`@000Eoo`@000Moo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`moo`03001oogoo00Eoo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol002eoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<0
07ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`04Ool0100?Oomoo`0?3Woo00<007ooOol01Woo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00
<Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0HOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400mo
ogoo00l>Ool00`00Oomoo`06Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000bOol01@00Oomoogoo000017oo00D0
07ooOomoo`0000Aoo`03001oogoo00Aoo`<00:h03`0300003`0?09803`03001oogoo01aoo`0097oo
1P001Woo0P0017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?
01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo
00@03gooOol03`eoo`03001oogoo00Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0039oo`05001oogooOol00004
Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?37oo00<007ooOol0
27oo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1`0?Oomoogoo00moo`0001ioo`00<Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00
Oomoo`04Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00Aoo`0400moogoo00l<Ool00`00Oomoo`08Ool00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000]
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03`]oo`03001oogoo00Uoo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002ioo`@000Eoo`@0
00Eoo`@000Moo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l017oo00@03gooOol03`]oo`03001oogoo00Uoo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0
04]oo`<001Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03`Yoo`03001oogoo00Yoo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?
01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo
00@03gooOol03`Yoo`03001oogoo00Yoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03`Yoo`03001oogoo00Yoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Moo`@0031oo`03001oo`0?01Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03`Uoo`03001oogoo00]oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001oogoo009oo`03001oogoo
02eoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l017oo00@03gooOol03`Uoo`03001oogoo00]oo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03
001oogoo009oo`03001oogoo02eoo`<001Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`Qoo`03001oogoo00aoo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol001Ioo`03001oogoo009oo`03001oogoo02eoo`03001oo`0?01Qoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`Qoo`03001o
ogoo00aoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00L03gooOomoo`0?Ool0000NOol001=oo`04001oogoo0003Ool00`00Oomoo`0^Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Ao
o`0400moogoo00l8Ool00`00Oomoo`0<Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000COol9000_Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Ao
o`0400moogoo00l7Ool00`00Oomoo`0=Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000KOol00`00Oomoo`0]Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00Aoo`0400moogoo00l7Ool00`00Oomoo`0=Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Ao
o`0400moogoo00l6Ool00`00Oomoo`0>Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00l6
Ool00`00Oomoo`0>Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00l6Ool00`00
Oomoo`0>Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0700moogooOol03goo00007Woo000GOol4000`Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00l5Ool00`00
Oomoo`0?Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00Oomoo`0]Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Ao
o`0400moogoo00l5Ool00`00Oomoo`0?Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool0
0`00Oomoo`0]Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00Aoo`0400moogoo00l4Ool00`00Oomoo`0@Ool00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
000FOol00`00Ool00002Ool00`00Oomoo`0]Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00l4Ool00`00Oomoo`0@
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`07
00moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00Oomoo`0]Ool3000HOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00l3
Ool00`00Oomoo`0AOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0700moogooOol03goo00007Woo000GOol200000goo001oo`0_Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`04
00moogoo00l3Ool00`00Oomoo`0AOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000]Ool60006Ool00`00Oomoo`04
Ool40007Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00Aoo`0400moogoo00l3Ool00`00Oomoo`0AOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000]
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00l2Ool00`00Oomoo`0BOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000GOol4000C
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00l2Ool0
0`00Oomoo`0BOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Oomoo`02Ool01000Oomoo`0047oo00<0
07ooOol027oo00<007ooOol01goo00<007ooOol017oo0`00XP0?00<0000?00l0WP0?00<007ooOol0
77oo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo1P001Woo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`04Ool01P0?Oomoo`0?Ool001Eoo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Io
o`03001oogoo009oo`04001oogoo000BOol00`00Oomoo`06Ool00`00Oomoo`03Ool40007Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0600moogoo00moo`005Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`005goo00@007ooOol000=oo`03001o
ogoo00aoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00Qoo`03001o
o`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
17oo00D03gooOol03`0001Ioo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`P000moo`03001oogoo009oo`05
001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Ool03`0HOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogoo00l0000F
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`07
00moogooOol03goo00007Woo000FOol00`00Oomoo`0EOol40004Ool60004Ool50006Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Ao
o`0400moogoo000GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo000GOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo
00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00Aoo`0400moogoo000GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Ao
o`0400moo`0000lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Oomoo`02Ool00`00Oomoo`0]Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00Aoo`0400moo`0000lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol6000_Ool00`00Ool03`0HOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400mo
o`0000lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0700moogooOol03goo00007Woo000GOol01@00Oomoogoo0000;goo00<007oo00l067oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?001o
o`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01`0?Oomoogoo00moo`0001ioo`005Woo00<007ooOol00Woo00<007ooOol0;Goo0`0067oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?001o
o`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01`0?Oomoogoo00moo`0001ioo`005Woo00<007ooOol00Woo00<007ooOol0;Goo00<007oo00l0
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0
100?001oo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`005Woo00<007ooOol0<Woo00<007oo00l067oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool01000Oomo
o`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool01000Oomoo`0?5goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`00
01ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0000moogoo00l05goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@00
00moogoo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`005goo1000<7oo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0000moogoo00l0
5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1`0?Oomoogoo00moo`0001ioo`005Woo00<007oo00000Woo00<007ooOol0;Goo00<007oo00l067oo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`02Ool00`00
Ool03`02Ool00`0?Oomoo`0EOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00Oomo
o`0]Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?009oo`03001oo`0?009oo`0300moogoo01Eoo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03
001oo`00009oo`03001oogoo02eoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00<007oo00l00Woo00<03gooOol05Goo00<03goo
Ool037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo
00moo`0001ioo`005Woo00<007oo00000Woo00<007ooOol0;Goo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0700moogooOol03goo00000Woo00@03gooOol0
3aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00L03gooOomoo`0?Ool0000NOol001Moo`800003Ool007oo02moo`<001Qoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01`0?Oomoogoo00moo`00009oo`0400moogoo00lGOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700mo
ogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00H03gooOomoo`0?0003Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00
;Goo1P0017oo10001Goo10001goo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0600moogooOol03`000goo00@03gooOol03aMoo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0
02eoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol017oo
00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool00004Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`005goo10004goo00<007ooOol02Woo
00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo000017oo00@03gooOol03aMoo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol001Ioo`03001oo`00009oo`03001oogoo015oo`03001oogoo00Uoo`05001oogooOol00004
Ool00`00Oomoo`04Ool3002G00l00`0000l03`2Y00l00`00Oomoo`0LOol001Ioo`03001oo`00009o
o`03001oogoo00Ioo`H000Ioo`03001oogoo00Qoo`05001oogooOol00004Ool00`00Oomoo`04Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOol0
000?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00Oomo
o`0COol00`00Oomoo`03Ool40004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0HOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOol0000?00Aoo`0400mo
ogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00Oomoo`0?Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo001oo`0?00Ao
o`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0700moogooOol03goo00007Woo000GOol200000goo001oo`0AOol00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo001oo`0?00Aoo`04
00moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo000^Ool40005Ool50004Ool40007Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo001oo`0?00Aoo`04
00moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03`00Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo0000
7Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03`00Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D007ooOomoo`0?00Aoo`04
00moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D007ooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol0
3goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<0000?Ool00Woo00<03gooOol00Woo00@03gooOol03aMoo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0
04]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`00
00moo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0700moogooOol007oo00l00goo00<03gooOol00Woo
00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool01`0?Oomoogoo001oo`0?00=oo`0300moogoo009oo`0400moogoo00lGOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700mo
ogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00@03gooOol0009oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00
Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0400moogoo0002Ool01@0?
Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Ool00003Ool01@0?Oomoogoo00l017oo00@03goo
Ool03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Ool00003Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0
04]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?001oo`03Ool01@0?
Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?001oo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`00Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`00Oomoo`03
Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?
01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0000moo`04Ool01@0?Oomoogoo00l017oo
00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool01`0?
Oomoogoo001oo`0?00Eoo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001io
o`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0700moogooOol007oo00l01Goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000]Ool60003Ool60004Ool40007
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00@03gooOol0009oo`0300moogoo00=oo`0500mo
ogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00;Goo00<007ooOol00Woo00D0
07ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03goo00000goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lG
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`07
00moogooOol03goo00007Woo000^Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03goo00000goo00<03gooOol00goo00D03gooOomo
o`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000_Ool00`00Oomoo`06Ool00`00Oomo
o`09Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03`00Ool00goo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000TOol6
0006Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`04Ool3002900l00`0000l03`2g00l0
0`00Oomoo`0LOol0035oo`03001oogoo00Ioo`03001oogoo00=oo`@000Moo`03001oo`0?01Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`00Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00L03gooOomoo`0?Ool0000NOol002eoo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`02Ool00`00Oomoo`08Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol017oo00<0000?Ool017oo
00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000]
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol00Woo00<007ooOol027oo00<007oo
00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Aoo`0300003goo00Aoo`0300moogoo00=oo`0500moogooOol03`04
Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00;Woo10001Goo10001Goo1@001Woo00<007oo
00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00=oo`03001oo`0?00Eoo`0300moogoo00=oo`0500moogooOol03`04
Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo009oo`04
001oogoo00l5Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool01@0?Oomoogoo00000goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00D03gooOomoo`0000=oo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0400moogoo0004Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Ool00005Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?001oo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?001oo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`00Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`06Ool00`0000moo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?
01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`05Ool00`00Ool03`07Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo
00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`00Ool03`07
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomo
o`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`04Ool01000Oomoo`0?1goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3
000HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol00goo00D007ooOomoo`0?00Moo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo009oo`03001o
ogoo009oo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0
100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0500moogooOol00005Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool0100?Oomoo`001Woo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03goo00001goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo0P0027oo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol0
3goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02Woo00<0000?Ool027oo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000]Ool60004
Ool40005Ool40007Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02Goo00<007oo00l02Goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000]Ool00`00
Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?
01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`07Ool20002
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002ioo`03001oogoo00Eoo`03001oogoo
009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol01Woo00<007ooOol00Woo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo
00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo000_Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo
000017oo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00Eoo`03001oogoo00=oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00mo
o`0001ioo`0097oo1P001Woo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03
001oogoo00Aoo`<006h03`800=<03`03001oogoo01aoo`00<Goo00<007ooOol00Woo00<007ooOol0
0Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`02Ool00`00Oomoo`06Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00L03gooOomoo`0?Ool0000NOol002eoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomo
ogoo000017oo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo008000Uoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001io
o`00;Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
00002goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000^Ool40005Ool40005Ool40007
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo0P0037oo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol04goo0P0000<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogoo
Ool03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol047oo0`000Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol03Woo0P00
1Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol037oo0P001goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol02Woo0P002Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400mo
ogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol01goo0`002goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogoo
Ool03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
0goo10003Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo00000`004Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo0`005Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700mo
ogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoogoo0`0000=o
o`0?Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool0100?Oomoogoo1@0000D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?
Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol01P0000=oo`0?Ool00Woo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo
0`0067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol01P000Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomo
o`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol0
1goo00<03goo000020000goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo
00<007oo00l067oo00<03gooOol02goo00<03`0000002@001Woo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0
100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00005goo40002Goo00<007ooOol0
1Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001o
ogoo01Eoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001o
ogoo00=oo`05001oogooOol00004Ool01000Oomoo`005goo00<007ooOol037oo00<007ooOol01goo
00<007ooOol017oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00
00=oo`03001oogoo01Eoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo
00=oo`03001oogoo00=oo`05001oogooOol00003Ool01`00Oomoogoo001oo`0001ioo`00Bgoo00<0
07oo00005`0000=oo`00Ool037oo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo01Eoo`03001oogoo00]o
o`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol0
0004Ool01000Oomoo`005goo00<007ooOol037oo00<007ooOol01goo00<007ooOol017oo00<007oo
Ool017oo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo01Eoo`03
001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00=oo`05
001oogooOol00003Ool01`00Oomoogoo001oo`0001ioo`00Bgooo`00B0007Woo003oOonaOol00?mo
ok5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo
003IOol50004Ool30002Ool30003Ool50003Ool50005Ool4002]Ool00=Yoo`03001oogoo00Ioo`03
001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo
000017oo00<007ooOol0ZWoo003JOol00`00Oomoo`06Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00<007ooOol01goo00D007ooOomoo`000;5oo`00fWoo1@0017oo00<007ooOol00Woo00<007oo
Ool00Woo10001Goo100017oo1P00[7oo003JOol00`00Oomoo`02Ool01000Oomoogoo0P000goo00D0
07ooOomoo`0000=oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomo
o`2ZOol00=Yoo`03001oogoo009oo`06001oogooOol007oo0`001Goo0`001Woo1@0017oo1000[Goo
003JOol00`00Oomoo`02Ool01@00Oomoogoo0000c7oo003IOol60004Ool00`00Oomoo`3:Ool00>9o
o`800<aoo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.96984, -396.471, \
0.0186604, 1.33257}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Low Pass", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Vout/Vin /. sol\) /. {Z1 \[Rule] R, Z2 \[Rule] R, 
          Z3 \[Rule] 1\/\(s\ C\), Z4 \[Rule] 1\/\(s\ C\), G \[Rule] 3 - \@2} // 
      Simplify\), "\[IndentingNewLine]", 
    \(getZPK[%]\), "\[IndentingNewLine]", 
    \(\(%% /. {R \[Rule] 1, C \[Rule] 1/\((2  \[Pi])\), 
          s \[Rule] 2\ \[Pi]\ \[ImaginaryI]\ f};\)\), "\[IndentingNewLine]", 
    \(\(BodePlot[%, {f, 0.01, 100}];\)\)}], "Input"],

Cell[BoxData[
    \(\(3 - \@2\)\/\(1 + \@2\ C\ R\ s + C\^2\ R\^2\ s\^2\)\)], "Output"],

Cell[BoxData[
    InterpretationBox[\("K(f=0) = "\[InvisibleSpace]\(3 - \@2\)\
\[InvisibleSpace]" ("\[InvisibleSpace]1.5857864376269049`\[InvisibleSpace]")"\
\),
      SequenceForm[ "K(f=0) = ", 
        Plus[ 3, 
          Times[ -1, 
            Power[ 2, 
              Rational[ 1, 2]]]], " (", 1.5857864376269049, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("K(f=\[Infinity]) = "\[InvisibleSpace]0\
\[InvisibleSpace]" ("\[InvisibleSpace]0.`\[InvisibleSpace]")"\),
      SequenceForm[ "K(f=\[Infinity]) = ", 0, " (", 0.0, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole frequency = "\[InvisibleSpace]1\/\(2\ C\ \[Pi]\ \
R\)\[InvisibleSpace]" ("\[InvisibleSpace]0.15915494309189535`\/\(C\ R\)\
\[InvisibleSpace]")"\),
      SequenceForm[ "Pole frequency = ", 
        Times[ 
          Rational[ 1, 2], 
          Power[ C, -1], 
          Power[ Pi, -1], 
          Power[ R, -1]], " (", 
        Times[ .15915494309189535, 
          Power[ C, -1], 
          Power[ R, -1]], ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole Q = "\[InvisibleSpace]1\/\@2\[InvisibleSpace]" \
("\[InvisibleSpace]0.7071067811865475`\[InvisibleSpace]")"\),
      SequenceForm[ "Pole Q = ", 
        Power[ 2, 
          Rational[ -1, 2]], " (", .70710678118654746, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Zero frequency = "\[InvisibleSpace]\(\@\(s \
/. \[InvisibleSpace]{}\[LeftDoubleBracket]1\[RightDoubleBracket]\)\ \@\(s \
/. \[InvisibleSpace]{}\[LeftDoubleBracket]2\[RightDoubleBracket]\)\)\/\(2\ \
\[Pi]\)\[InvisibleSpace]" ("\[InvisibleSpace]\(0.15915494309189535`\ \@\(s \
/. \[InvisibleSpace]{}\[LeftDoubleBracket]1\[RightDoubleBracket]\)\ \@\(s \
/. \[InvisibleSpace]{}\[LeftDoubleBracket]2\[RightDoubleBracket]\)\)\
\[InvisibleSpace]")"\),
      SequenceForm[ "Zero frequency = ", 
        Times[ 
          Rational[ 1, 2], 
          Power[ Pi, -1], 
          Power[ 
            ReplaceAll[ s, 
              Part[ {}, 1]], 
            Rational[ 1, 2]], 
          Power[ 
            ReplaceAll[ s, 
              Part[ {}, 2]], 
            Rational[ 1, 2]]], " (", 
        Times[ .15915494309189535, 
          Power[ 
            ReplaceAll[ s, 
              Part[ {}, 1]], 
            Rational[ 1, 2]], 
          Power[ 
            ReplaceAll[ s, 
              Part[ {}, 2]], 
            Rational[ 1, 2]]], ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Zero Q = "\[InvisibleSpace]Indeterminate\
\[InvisibleSpace]" ("\[InvisibleSpace]Indeterminate\[InvisibleSpace]")"\),
      SequenceForm[ "Zero Q = ", Indeterminate, " (", Indeterminate, ")"],
      Editable->False]], "Print"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.246914 0.586934 0.00762301 [
[.00617 -0.0125 -14 -12.5625 ]
[.00617 -0.0125 14 0 ]
[.25309 -0.0125 -11 -12.5625 ]
[.25309 -0.0125 11 0 ]
[.5 -0.0125 -5 -12.5625 ]
[.5 -0.0125 5 0 ]
[.74691 -0.0125 -8 -12.5625 ]
[.74691 -0.0125 8 0 ]
[.99383 -0.0125 -11 -12.5625 ]
[.99383 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -8 -25.125 ]
[.5 -0.0125 8 -12.5625 ]
[-0.0125 .12955 -18 -4.5 ]
[-0.0125 .12955 0 4.5 ]
[-0.0125 .28201 -18 -4.5 ]
[-0.0125 .28201 0 4.5 ]
[-0.0125 .43447 -18 -4.5 ]
[-0.0125 .43447 0 4.5 ]
[-0.0125 .58693 -6 -4.5 ]
[-0.0125 .58693 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -8 ]
[-0.01875 .30902 -18 8 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12.5625 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .12955 m
1 .12955 L
s
0 .28201 m
1 .28201 L
s
0 .43447 m
1 .43447 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -69 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12955 m
.00625 .12955 L
s
[(-60)] -0.0125 .12955 1 0 Mshowa
0 .28201 m
.00625 .28201 L
s
[(-40)] -0.0125 .28201 1 0 Mshowa
0 .43447 m
.00625 .43447 L
s
[(-20)] -0.0125 .43447 1 0 Mshowa
0 .58693 m
.00625 .58693 L
s
[(0)] -0.0125 .58693 1 0 Mshowa
.125 Mabswid
0 .16767 m
.00375 .16767 L
s
0 .20578 m
.00375 .20578 L
s
0 .2439 m
.00375 .2439 L
s
0 .32013 m
.00375 .32013 L
s
0 .35824 m
.00375 .35824 L
s
0 .39636 m
.00375 .39636 L
s
0 .47259 m
.00375 .47259 L
s
0 .5107 m
.00375 .5107 L
s
0 .54882 m
.00375 .54882 L
s
0 .09144 m
.00375 .09144 L
s
0 .05332 m
.00375 .05332 L
s
0 .01521 m
.00375 .01521 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -93.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 10.2813 translate
90 rotate
-69 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dB) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Magnitude) show
117.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .61746 m
.0149 .61746 L
.02372 .61746 L
.0322 .61746 L
.03955 .61746 L
.04718 .61746 L
.05368 .61746 L
.06073 .61746 L
.06699 .61746 L
.07242 .61746 L
.0779 .61746 L
.08707 .61746 L
.096 .61746 L
.10373 .61746 L
.11169 .61746 L
.11849 .61746 L
.12503 .61746 L
.13175 .61746 L
.13776 .61746 L
.14382 .61746 L
.14928 .61746 L
.1549 .61746 L
.16459 .61746 L
.17368 .61746 L
.18176 .61746 L
.18899 .61746 L
.19619 .61746 L
.20269 .61746 L
.2092 .61746 L
.21511 .61746 L
.22051 .61746 L
.22597 .61746 L
.23097 .61746 L
.23557 .61746 L
.24026 .61746 L
.24459 .61746 L
.24901 .61746 L
.25309 .61746 L
s
.25309 .61746 m
.26182 .61746 L
.27063 .61746 L
.27912 .61745 L
.28646 .61745 L
.2941 .61745 L
.3006 .61744 L
.30765 .61744 L
.31391 .61743 L
.31934 .61742 L
.32481 .61742 L
.33398 .6174 L
.34291 .61737 L
.35065 .61734 L
.35861 .61729 L
.3654 .61725 L
.37195 .61719 L
.37867 .61711 L
.38467 .61702 L
.39073 .61691 L
.3962 .61678 L
.40181 .61662 L
.4115 .61627 L
.42059 .61579 L
.42867 .61523 L
.4359 .61456 L
.4431 .61372 L
.44961 .61276 L
.45611 .61158 L
.46202 .61027 L
.46742 .60886 L
.47288 .6072 L
.47788 .60543 L
.48249 .60359 L
.48718 .6015 L
.49151 .59935 L
.49593 .59693 L
.5 .59452 L
s
.5 .59452 m
.53337 .56787 L
.56082 .5391 L
.58144 .51534 L
.59812 .49545 L
.61342 .47692 L
.62633 .46116 L
.63854 .44619 L
.64912 .43319 L
.65839 .42177 L
.66745 .41061 L
.67551 .40067 L
.68272 .39178 L
.68991 .38292 L
.69639 .37491 L
.70288 .3669 L
.70878 .35962 L
.71417 .35297 L
.71962 .34624 L
.72461 .34007 L
.72968 .33382 L
.73435 .32806 L
.73865 .32274 L
.74305 .31731 L
.74691 .31254 L
s
.74691 .31254 m
.78029 .27133 L
.80773 .23743 L
.82836 .21196 L
.84504 .19137 L
.86033 .17248 L
.87324 .15653 L
.88545 .14146 L
.89603 .1284 L
.90531 .11694 L
.91437 .10575 L
.92242 .0958 L
.92964 .08689 L
.93682 .07802 L
.9433 .07001 L
.9498 .062 L
.9557 .05471 L
.96108 .04806 L
.96653 .04133 L
.97153 .03516 L
.97659 .0289 L
.98126 .02314 L
.98556 .01783 L
.98996 .0124 L
.99383 .00762 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00hWoo0`000Woo0`000Woo1P00_Woo003S
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000_Woo003SOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`2oOol00>=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
0;ioo`00hgoo1P000goo00D007ooOomoo`000;moo`00hgoo00<007ooOol00Woo00@007ooOomoo`H0
0;ioo`00hgoo00<007ooOol00Woo00<007ooOol0aGoo003ROol30002Ool30036Ool00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo000iOol40006Ool20006Ool40004Ool7000dOol40006Ool20005Ool7
0010Ool70015Ool70003Ool4000nOol70003Ool40005Ool4000KOol003Qoo`03001oogoo009oo`03
001oogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo
009oo`03001oogoo00=oo`8000Qoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03001o
ogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo
00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo
00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qo
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Ao
o`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03
001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001o
ogoo00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol0
03Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo009oo`<003Ioo`03
001oogoo009oo`03001oogoo00]oo`<004Aoo`<004Uoo`<000Eoo`03001oogoo009oo`03001oogoo
03aoo`<000Eoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Uoo`@000io
o`@000Moo`03001oogoo03Eoo`@0011oo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00Ao
o`@0045oo`03001oogoo00Aoo`@000Eoo`@001]oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo0017Oooo0018000ROol004Moo`03001oo`0001Moo`03
001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`0FOol00`00Oomoo`0;Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007oo
Ool00goo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol0000GOol00`00Oomoo`0;
Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool01@00Oomoogoo00000Woo00@007ooOol0029oo`00Agoo00<007oo00005goo00<007ooOol02goo
00<007ooOol01goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo
00D007ooOomoo`00009oo`03001oogoo01Ioo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo
00Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00
Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool01@00Oomoogoo00000goo00D007ooOomoo`0001Moo`03001oogoo00]oo`03001oogoo
00Qoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogoo
Ool00002Ool01000Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
001oogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomoogoo00moo`0000l2Ool00`00Oomo
o`0POol004Moo`80000300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomoogoo00l007oo00l2Ool00`00Oomoo`0P
Ool004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomoogoo00l007oo00l2Ool00`00Oomoo`0POol004Mo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00000Woo00@03gooOol0029oo`00Agoo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogoo00003`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3goo001oo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Ool007oo00l0
0Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500l007ooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D007ooOomoo`0?009oo`0400moogoo000ROol004Mo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool01P0?Oomoogoo00003`=oo`0400moogoo00l2Ool00`00Oomoo`0POol004Moo`03001oo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool01P0?
Oomoogoo00003`=oo`0400moogoo00l2Ool00`00Oomoo`0POol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool01P0?Oomoo`00Ool0
3`=oo`0400moogoo00l2Ool00`00Oomoo`0POol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Ool00002Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300l007oo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool200000`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<007ooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
1P0?Oomoogoo00003`Aoo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00H03gooOomoo`0000l4Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0600moogoo001oo`0?17oo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Ool00002Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029o
o`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00l007oo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<007ooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`00Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00=oo`0300003goo00=oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol00Woo00<007oo00l017oo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`00Ool03`04Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029o
o`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0500moogooOol00002
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo
0P0000<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0400moogoo0003Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moo`0000Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03`00Ool017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`00Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`03001oogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol00goo00<0000?
Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`02Ool00`00Ool03`06Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0500moogooOol00002Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0400moogoo0003Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=7oo100017oo10001goo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moo`0000Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000cOol00`00Oomoo`02Ool01000Oomo
o`0017oo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300l007oo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo000cOol00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol017oo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300l007oo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo000cOol20003Ool01000Oomoo`0017oo00<007oo
Ool017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`03001oogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000YOol60004
Ool00`00Ool000020003Ool00`00Oomoo`02Ool00`00Oomoo`04Ool3003o00lQ00l00`0000l03`0P
00l00`00Oomoo`0POol003=oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Aoo`03001o
o`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`06Ool00`00Ool03`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=7oo00<007ooOol017oo00<0
07ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Eoo`04001oogoo00l6
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`00=Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Aoo`05001oogooOol03`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=Woo0`000goo10001goo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00=oo`03001oogoo009oo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol00Woo00<007ooOol00goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`02Ool00`00Oomoo`03Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
01Moo`0300moogoo00]oo`0500moogooOol00006Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0400moogoo0007Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moo`0000Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo0000
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?001oo`08Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`00Agoo0P0000<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03001oogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<007ooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0:Ool00`0000moo`09Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00Uoo`03001oo`0?00Yoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol027oo00@007oo
Ool03`Yoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol01goo00D007ooOomoo`0?00Yo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol01goo00D007ooOomoo`0?00Yoo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol01Woo00<007ooOol00Woo00<03gooOol027oo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`05Ool00`00Oomoo`03Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00Aoo`03001oogoo00Aoo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol00goo00<007ooOol01Goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`02Ool00`00Oomoo`06Ool00`0?Oomo
o`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol0029oo`00Agoo0P0000<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo009oo`03001oogoo00Ioo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00D03gooOomoo`0000Uoo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00@03gooOol000Yoo`0300moogoo00Qoo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03goo00002goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?001oo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<0
07oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300l007oo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<007ooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0FOol00`0000moo`0<Ool00`0?Oomo
o`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`03001oo`0?00eoo`0300moogoo00Qoo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05Goo00<007oo00l03Goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0DOol01000Oomoo`0?3Goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0C
Ool01@00Oomoogoo00l03Goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0BOol00`00
Oomoo`02Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo0P0000<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?015o
o`03001oogoo00=oo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool0
0`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
4Goo00<007ooOol00goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Mo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0@Ool00`00Oomoo`04Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?00moo`03001oogoo00Eoo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo
0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l03Woo00<007ooOol01Woo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0=Ool00`00Oomoo`07Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?00aoo`03001oogoo00Qoo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l037oo00<007ooOol027oo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0;Ool00`00Oomoo`09Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`00=7oo100017oo10001goo00<007oo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?00Yoo`03001oogoo00Yoo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo000fOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l02Goo00<007ooOol02goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool003Ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`08Ool00`00Oomoo`0<Ool0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00<Woo1P000goo00<007ooOol0
0Woo00<007ooOol017oo0`00n00?00<0000?00l0B00?00<007ooOol087oo000YOol60004Ool01000
Oomoo`0017oo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00Moo`03001oogoo00eoo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo000KOol4000DOol01000Oomoo`0017oo00<007oo
Ool00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?00Ioo`03001oogoo00ioo`0300moogoo00]oo`0300moogoo00Qoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo000JOol00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Ool00004Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l01Goo00<007ooOol03goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol001Yoo`03001oogoo009oo`03001oogoo019oo`03001oo`0000Aoo`03
001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`04Ool00`00Oomoo`0@Ool00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`006Woo00<007ooOol00Woo00<007ooOol04goo0P001Goo10001goo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
00=oo`03001oogoo015oo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000G
Ool01000Oomoo`000goo00<007ooOol09Woo00<007oo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?009oo`03001oogoo019oo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo000GOol9000WOol00`00Ool03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l00Woo00<007ooOol04Woo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol001moo`03001oogoo02Eoo`03001oo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00005Goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogooOol03`005Woo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol0000GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`0067oo00<007ooOol017oo00<007ooOol09Goo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOol0000?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000HOol8000WOol00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoo`0000l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol001Qoo`04001oogoo0003Ool00`00Oomoo`0UOol2
00000`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?000007oo
00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol001Qoo`04001oogoo
0003Ool00`00Oomoo`0UOol00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@00Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool001Qoo`04001oogoo0003Ool00`00Oomoo`0UOol00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@00Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol001Qoo`04001oogoo0003Ool00`00Oomoo`0UOol00`00Ool03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`02Ool00`0000moo`02Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`006Goo0P0000Aoo`00000002Qo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?009oo`0300003goo009o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool0
0`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0900moogooOol03goo001oo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0600moogooOol03`000Woo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol00003Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOol0000?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Ool007oo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500l007ooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D007ooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo0P0000<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@00Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300003goo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0000moo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00L03gooOomoo`00Ool03`03Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00@0
3gooOol0009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo00000goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?001oo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300l007oo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<007ooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`02Ool00`0000moo`04Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0700moogooOol007oo
00l01Goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0100?Oomoo`000Woo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`00Agoo0P0000<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Ool00003Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moo`0000=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03`00Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`00
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Aoo`0300003goo00Aoo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol00goo00<007oo00l01Goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`02Ool01000Oomoo`0?1Goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool01@0?Oomoogoo00000goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
1@0?Oomoogoo00000goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00<Woo1P00
17oo10001goo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool0100?Oomoo`0017oo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00<Woo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo00001Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00<goo00<007ooOol01Goo00<007ooOol00Woo00<007oo
Ool017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?001oo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000dOol00`00
Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`03001oogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol002Uoo`H000Ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
00Aoo`<00<l03`0300003`0?07403`03001oogoo021oo`00=Woo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`06Ool00`0000moo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo
000bOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`00Ool03`07Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo000bOol00`00Oomoo`02Ool01@00Oomoogoo0000
17oo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`05Ool00`00Ool03`07Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo
000cOol40005Ool40007Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Aoo`04001oogoo00l7Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00=oo`05001oogooOol03`07Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017
Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo009oo`03
001oogoo009oo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol00Woo
00<007ooOol00Woo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029o
o`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool01@0?Oomoogoo
00001Goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0100?Oomoo`001Woo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Ool00007Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300l007oo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo000ROol004Moo`80000300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03`00Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`00Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00Yoo`03
00003goo00Qoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02Goo00<007oo00l02Goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`08Ool01000Oomoo`0?2Goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`07Ool01@00Oomoogoo00l02Goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`07Ool01@00Oomoogoo00l02Goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`06Ool00`00Oomoo`02Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00Eoo`03001oogoo00=oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol017oo00<007ooOol017oo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`03Ool00`00Oomoo`05Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo009oo`03001oogoo00Ioo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00D03gooOomoo`0000Uoo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`80000300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00@03gooOol000Yoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03goo00002goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?001o
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03001oogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Mo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<007ooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0DOol00`0000moo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01=oo`03001oo`0?00eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
4Woo00@007ooOol03`eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol04Woo00@007oo
Ool03`eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol04Goo00D007ooOomoo`0?00eo
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol047oo00<007ooOol00Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0?Ool00`00Oomoo`03Ool00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool200000`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00ioo`03001oogoo00Aoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol03Goo00<007ooOol01Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0<Ool00`00Oomoo`06
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00]oo`03001oogoo
00Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol02Woo00<007oo
Ool027oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`09Ool00`00
Oomoo`09Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Qoo`03
001oogoo00Yoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol01goo
00<007ooOol02goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`05
Ool2000>Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo000lOol40007Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
00Aoo`03001oogoo00ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol003]oo`03001oogoo009oo`03001oogoo00Aoo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol00goo00<007ooOol03goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00>goo
00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`02Ool00`00
Oomoo`0@Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo000kOol00`00Oomoo`02Ool00`00Oomoo`04Ool3000GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0500moogooOol0000COol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000kOol00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moo`00000DOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000kOol00`00Oomo
o`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300l007oo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool003]oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<007ooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00>goo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0600moogooOol0
3goo0P0000<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00?7oo10001goo00<007oo00l05goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400moogooOol20002
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03`000000000?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool0100?Oomoogoo0P000goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`0600000goo
00moo`02Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00005goo00<007oo
Ool02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool00Woo00D007ooOomoo`00009oo`03001oogoo01Ioo`03001oogoo00]oo`03001oogoo00Moo`03
001oogoo00Eoo`03001oogoo00H0009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomo
o`0EOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool01@00Oomoogoo00000goo00D007ooOomoo`0001Moo`03001oogoo00]oo`03001oogoo00Qo
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol0
0002Ool01000Oomoo`008Woo0017Ool00`00Ool0002;0003Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol01goo00<007oo
Ool01Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol0000G
Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0029oo`00Agooo`00B0008Woo003o
OonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003EOol4003GOol00=Uo
o`03001oogoo0=Aoo`00fGoo00<007ooOol0e7oo0031Ool30003Ool30003Ool50003Ool300000goo
001oo`02Ool30002Ool300000goo000000050005Ool40004Ool300000goo00000002Ool300000goo
00000004Ool4002POol00<9oo`03001oogoo00=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo0P0017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00@0
07ooOol000=oo`80009oo`04001oogooOol20004Ool00`00Oomoo`02Ool00`00Oomoo`2MOol00<9o
o`04001oogoo0002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`03001oogoo009oo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo009oo`04
001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`2ROol00<9oo`07001oo`00Ool007oo000017oo
10000goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo009oo`H009mo
o`00`Woo00L007oo001oo`00Ool00003Ool01@00Oomoogoo00000goo00@007ooOomoo`8000Aoo`80
00=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo
0003Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`2MOol00<9oo`07001oo`00Ool007oo000017oo
0`001Goo0`0000=oo`0000000Woo0P0000Aoo`00000000Aoo`<000Eoo`L0009oo`8000=oo`8000=o
o`<00003Ool007oo00Aoo`@00:1oo`00`Woo0P000goo0P00:7oo00<007ooOol04Woo00<007ooOol0
Ygoo0031Ool30003Ool3000WOol00`00Oomoo`0BOol00`00Oomoo`2WOol00>Uoo`03001oogoo01Uo
o`800:Uoo`00jGoo00<007ooOol0a7oo003oOonaOol00?mook5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.91386, -93.8213, \
0.0186604, 0.604422}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.246914 0.610378 0.00340285 [
[.00617 -0.0125 -14 -12.5625 ]
[.00617 -0.0125 14 0 ]
[.25309 -0.0125 -11 -12.5625 ]
[.25309 -0.0125 11 0 ]
[.5 -0.0125 -5 -12.5625 ]
[.5 -0.0125 5 0 ]
[.74691 -0.0125 -8 -12.5625 ]
[.74691 -0.0125 8 0 ]
[.99383 -0.0125 -11 -12.5625 ]
[.99383 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -8 -25.125 ]
[.5 -0.0125 8 -12.5625 ]
[-0.0125 .01488 -24 -4.5 ]
[-0.0125 .01488 0 4.5 ]
[-0.0125 .09995 -24 -4.5 ]
[-0.0125 .09995 0 4.5 ]
[-0.0125 .18502 -24 -4.5 ]
[-0.0125 .18502 0 4.5 ]
[-0.0125 .27009 -24 -4.5 ]
[-0.0125 .27009 0 4.5 ]
[-0.0125 .35516 -18 -4.5 ]
[-0.0125 .35516 0 4.5 ]
[-0.0125 .44024 -18 -4.5 ]
[-0.0125 .44024 0 4.5 ]
[-0.0125 .52531 -18 -4.5 ]
[-0.0125 .52531 0 4.5 ]
[-0.0125 .61038 -6 -4.5 ]
[-0.0125 .61038 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -20 ]
[-0.01875 .30902 -24 20 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12.5625 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .09995 m
1 .09995 L
s
0 .18502 m
1 .18502 L
s
0 .27009 m
1 .27009 L
s
0 .35516 m
1 .35516 L
s
0 .44024 m
1 .44024 L
s
0 .52531 m
1 .52531 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -69 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01488 m
.00625 .01488 L
s
[(-175)] -0.0125 .01488 1 0 Mshowa
0 .09995 m
.00625 .09995 L
s
[(-150)] -0.0125 .09995 1 0 Mshowa
0 .18502 m
.00625 .18502 L
s
[(-125)] -0.0125 .18502 1 0 Mshowa
0 .27009 m
.00625 .27009 L
s
[(-100)] -0.0125 .27009 1 0 Mshowa
0 .35516 m
.00625 .35516 L
s
[(-75)] -0.0125 .35516 1 0 Mshowa
0 .44024 m
.00625 .44024 L
s
[(-50)] -0.0125 .44024 1 0 Mshowa
0 .52531 m
.00625 .52531 L
s
[(-25)] -0.0125 .52531 1 0 Mshowa
0 .61038 m
.00625 .61038 L
s
[(0)] -0.0125 .61038 1 0 Mshowa
.125 Mabswid
0 .03189 m
.00375 .03189 L
s
0 .04891 m
.00375 .04891 L
s
0 .06592 m
.00375 .06592 L
s
0 .08294 m
.00375 .08294 L
s
0 .11696 m
.00375 .11696 L
s
0 .13398 m
.00375 .13398 L
s
0 .15099 m
.00375 .15099 L
s
0 .16801 m
.00375 .16801 L
s
0 .20204 m
.00375 .20204 L
s
0 .21905 m
.00375 .21905 L
s
0 .23606 m
.00375 .23606 L
s
0 .25308 m
.00375 .25308 L
s
0 .28711 m
.00375 .28711 L
s
0 .30412 m
.00375 .30412 L
s
0 .32114 m
.00375 .32114 L
s
0 .33815 m
.00375 .33815 L
s
0 .37218 m
.00375 .37218 L
s
0 .38919 m
.00375 .38919 L
s
0 .40621 m
.00375 .40621 L
s
0 .42322 m
.00375 .42322 L
s
0 .45725 m
.00375 .45725 L
s
0 .47426 m
.00375 .47426 L
s
0 .49128 m
.00375 .49128 L
s
0 .50829 m
.00375 .50829 L
s
0 .54232 m
.00375 .54232 L
s
0 .55933 m
.00375 .55933 L
s
0 .57635 m
.00375 .57635 L
s
0 .59336 m
.00375 .59336 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -111.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
81 10.2813 translate
90 rotate
-81 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(degree) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phase) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .60762 m
.03955 .60661 L
.06699 .60552 L
.08762 .60448 L
.1043 .60349 L
.11959 .60244 L
.1325 .60142 L
.14471 .60034 L
.15529 .5993 L
.16457 .59829 L
.17363 .59723 L
.18168 .5962 L
.1889 .59521 L
.19608 .59416 L
.20256 .59314 L
.20906 .59206 L
.21496 .59102 L
.22034 .59002 L
.22579 .58896 L
.23079 .58793 L
.23585 .58684 L
.24052 .58579 L
.24482 .58478 L
.24922 .5837 L
.25309 .58271 L
s
.25309 .58271 m
.28646 .57251 L
.31391 .56126 L
.33453 .55058 L
.35121 .54016 L
.3665 .5289 L
.37942 .51788 L
.39162 .50597 L
.4022 .49429 L
.41148 .48287 L
.42054 .47054 L
.4286 .45849 L
.43581 .44679 L
.44299 .43421 L
.44948 .42204 L
.45597 .40908 L
.46187 .39662 L
.46726 .38471 L
.4727 .37216 L
.4777 .36027 L
.48277 .34787 L
.48743 .33622 L
.49174 .32531 L
.49613 .31406 L
.5 .30412 L
s
.5 .30412 m
.53337 .22212 L
.56082 .16724 L
.58144 .1349 L
.59812 .11357 L
.61342 .09716 L
.62633 .08527 L
.63854 .07543 L
.64912 .06787 L
.65839 .06187 L
.66745 .05654 L
.67551 .05219 L
.68272 .04858 L
.68991 .04523 L
.69639 .0424 L
.70288 .03975 L
.70878 .03748 L
.71417 .03551 L
.71962 .03363 L
.72461 .03198 L
.72968 .03039 L
.73435 .029 L
.73865 .02776 L
.74305 .02655 L
.74691 .02553 L
s
.74691 .02553 m
.78029 .0181 L
.80773 .01352 L
.82836 .01078 L
.84504 .00891 L
.86033 .00744 L
.87324 .00636 L
.88545 .00544 L
.89603 .00473 L
.90531 .00416 L
.91437 .00365 L
.92242 .00323 L
.92964 .00288 L
.93682 .00256 L
.9433 .00228 L
.9498 .00202 L
.9557 .0018 L
.96108 .00161 L
.96653 .00142 L
.97153 .00126 L
.97659 .0011 L
.98126 .00097 L
.98556 .00084 L
.98996 .00072 L
.99383 .00062 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00iWoo0`000Woo0`000Woo1P00^Woo003W
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000^Woo003WOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`2kOol00>Moo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
0;Yoo`00igoo1P000goo00D007ooOomoo`000;]oo`00igoo00<007ooOol00Woo00@007ooOomoo`H0
0;Yoo`00igoo00<007ooOol00Woo00<007ooOol0`Goo003VOol30002Ool30032Ool00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo000nOol40006Ool20006Ool40004Ool7000cOol40006Ool20005Ool7
0011Ool70015Ool70003Ool4000mOol70003Ool40005Ool4000GOol003eoo`03001oogoo009oo`03
001oogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=oo`03001oogoo
009oo`03001oogoo00=oo`8000Qoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Eoo`03001o
ogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001oogoo
00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001oogoo
00eoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003eo
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=o
o`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Eoo`03
001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001o
ogoo00eoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol0
03eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo009oo`<003Eoo`03
001oogoo009oo`03001oogoo00]oo`<004Eoo`<004Uoo`<000Eoo`03001oogoo009oo`03001oogoo
03]oo`<000Eoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003ioo`@000io
o`@000Moo`03001oogoo03Aoo`@0011oo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00Ao
o`@0041oo`03001oogoo00Aoo`@000Eoo`@001Moo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo001;Oooo0018000NOol004]oo`03001oo`0001Qoo`03
001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo000017oo00@007oo
Ool001Moo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool0
0`00Oomoo`07Ool00`00Oomoo`05OolI00000goo001oo`0MOol002eoo`L000Eoo`03001oogoo00Ao
o`@000Moo`03001oo`0001Qoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol0
0`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool0
1@00Oomoogoo000017oo00@007ooOol001Moo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo
00Aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00
Oomoo`0EOol00`00Oomoo`0;Ool00`00Ool0000@0005Ool00`00Oomoo`03Ool01@00Oomoogoo0000
0goo00L007ooOomoo`00Ool0000NOol0031oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`03Ool:0008Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0031oo`03001oogoo
00Ioo`03001oogoo00Qoo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0DOol70008Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0
031oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`<001Qoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0<Ool800000goo00moo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol002Aoo`H000Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ao
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`06
Ool60009Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0031oo`03001oogoo00Mo
o`03001oogoo00=oo`@000Moo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`03Ool3000?Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool0031oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00Qoo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool00003000BOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00L03gooOomoo`0?Ool0000NOol002ioo`<000Eoo`03001oogoo009oo`03001oogoo009oo`03
001oogoo00Qoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`05000F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0031oo`03001oogoo00=oo`H000Ao
o`D000Ioo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0300moo`00008000=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?
5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00@03gooOomoo`<0009oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomo
o`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0600moo`00001oo`0?0goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l0
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0
100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol010000goo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03`0000000Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001io
o`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol00goo0P0017oo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol00`0000=oo`0?Ool00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomo
ogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol0
1goo00<03gooOol017oo00<03`00000017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo
00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
07ooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?
5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol00goo00<0000?Ool01Goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<0
3gooOol01goo00@03gooOomoo`800003Ool03goo00Eoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0400moo`00
0003Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo
00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool20005Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700mo
ogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomo
o`06Ool00`0000moo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`04Ool200000goo00moo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400mo
ogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`03Ool01@00Oomoogoo00l01Woo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03goo
Ool037oo00<03gooOol00Woo00<007ooOol00Woo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03goo
Ool00P001Goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001io
o`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03goo00001goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00;Goo1`000goo10001Goo
10001goo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03`00Ool01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00<7oo00<007ooOol00goo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMo
o`0300moogoo00aoo`03001oogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L0
3gooOomoo`0?Ool0000NOol0031oo`03001oogoo00Qoo`05001oogooOol00004Ool00`00Oomoo`04
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0;Ool00`0000moo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000`Ool00`00Oomoo`08Ool01@00
Oomoogoo000017oo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol02Woo00<0
07oo00l02Goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001io
o`0097oo1P001Woo00<007ooOol027oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`<00<@03`03
00003`0?07`03`03001oogoo01aoo`00<7oo00<007ooOol017oo100017oo00<007ooOol00Woo00<0
07ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol027oo00D007ooOomoo`0?00Uoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0031oo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3aMoo`0300moogoo00Moo`03001oogoo009oo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002ioo`<000Ioo`03001oogoo00Eoo`03001o
ogoo009oo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00Ioo`03001oogoo
00=oo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol0031oo`03001oogoo00Aoo`D000Aoo`@000Moo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03
00moogoo00Eoo`03001oogoo00Aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00Aoo`03
001oogoo00Eoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00Aoo`03001oogoo
00Eoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00=oo`03001oogoo00Ioo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo009oo`03001oogoo00Moo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]o
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03aMoo`0500moogooOol0000:Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400mo
ogoo00lGOol01@0?Oomoogoo00002Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00@03gooOol000]o
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moo`0000aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?
01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo
00@03gooOol03aMoo`0300moo`0000aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300l0
07oo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomo
o`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03001oogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03aMoo`03001oogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aIoo`030000
3goo00eoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomo
o`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aIoo`0300003goo00eoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03aEoo`03001oo`0?00ioo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aAo
o`04001oogoo00l>Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`07
00moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lDOol01000Oomoo`0?3Woo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001io
o`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`04Ool0100?Oomoo`0?4goo00D007ooOomoo`0?00ioo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03a9oo`03001oogoo009oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002eoo`L0009oo`H000Aoo`@000Moo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03a9oo`03001oogoo009oo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0031oo`03001oogoo
00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo
00lAOol00`00Oomoo`03Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000`Ool00`00Oomoo`04Ool00`00Oomoo`0:
Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo00lAOol00`00Oomoo`03Ool00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo0000
7Woo000`Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo
00l@Ool00`00Oomoo`04Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000TOol60006Ool00`00Oomoo`06Ool00`00
Oomoo`08Ool00`00Oomoo`04Ool3002a00l00`0000l03`2?00l00`00Oomoo`0LOol0031oo`03001o
ogoo00Moo`03001oogoo00=oo`@000Moo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`moo`03001oogoo00Eoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol0031oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo00Qoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03`moo`03001oogoo00Eoo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002io
o`<000Eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Qoo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3`ioo`03001oogoo00Ioo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0031oo`03001oogoo00Aoo`@000Eoo`D000Io
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03`ioo`03001oogoo00Ioo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@0
3gooOol03`eoo`03001oogoo00Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3`eoo`03001oogoo00Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`aoo`03
001oogoo00Qoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`aoo`03001oogoo
00Qoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`]oo`03001oogoo00Uoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`]oo`03001oogoo00Uoo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol004]oo`<001Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03`Yoo`03001oogoo00Yoo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]o
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03`Yoo`03001oogoo00Yoo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001o
o`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
17oo00@03gooOol03`Yoo`03001oogoo00Yoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@0
3gooOol03`Uoo`03001oogoo00]oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Moo`@0031oo`03001oo`0?01Qo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@0
3gooOol03`Uoo`03001oogoo00]oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001oogoo009oo`03001o
ogoo02eoo`<001Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03`Qoo`03001oogoo00aoo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001o
ogoo009oo`03001oogoo02eoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`Qoo`03001oogoo00aoo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol001Ioo`03001oogoo009oo`03001oogoo02eoo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`Moo`03
001oogoo00eoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00L03gooOomoo`0?Ool0000NOol001=oo`04001oogoo0003Ool00`00Oomoo`0^Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0400moogoo00l7Ool00`00Oomoo`0=Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000COol9000_Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0400moogoo00l7Ool00`00Oomoo`0=Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000KOol00`00Oomoo`0]
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00l6Ool00`00Oomoo`0>Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`04
00moogoo00l6Ool00`00Oomoo`0>Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo
00l5Ool00`00Oomoo`0?Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000]Ool70003Ool40005Ool40007Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0400moogoo00l5Ool00`00Oomoo`0?Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000GOol4000EOol00`00
Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l067oo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?
Oomoo`0?17oo00<007ooOol047oo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`005Woo00<007oo00000Woo00<007oo
Ool04Woo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03`Aoo`03001oogoo011oo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001oo`00
009oo`03001oogoo019oo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`04Ool3002U00l00`0000l03`2K00l00`00Oomoo`0LOol001Ioo`03001oo`00009oo`03001o
ogoo00Ioo`H000Ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomo
o`04Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00Aoo`0400moogoo00l3Ool00`00Oomoo`0AOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol0
0`00Ool00002Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo0000
17oo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?0goo00<007ooOol04Goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`00
01ioo`005goo0P0000=oo`00Ool057oo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`9oo`03001oogoo019oo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol002ioo`<000Eoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0400moogoo00l2Ool00`00Oomoo`0BOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000`Ool00`00Oomoo`04
Ool40005Ool40007Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo00l2Ool00`00Oomoo`0BOol00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo0000
7Woo000GOol4000`Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00Aoo`0600moogoo00moo`005Goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`005Woo00<007oo
Ool00Woo00@007ooOol002aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00H03gooOol03goo000EOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
000FOol00`00Oomoo`02Ool01000Oomoo`00;7oo00<007oo00l067oo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoo`0?00005Woo00<03goo
Ool037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo
00moo`0001ioo`005Woo00<007ooOol00Woo00@007ooOol002aoo`03001oo`0?01Qoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00D03gooOol03`00
01Ioo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00L03gooOomoo`0?Ool0000NOol001Moo`04001oogoo0003Ool00`00Oomoo`0ZOol00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`04
00moogoo000GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo000FOol8000]Ool3000HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo000GOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol0
3goo00007Woo000FOol00`00Oomoo`0bOol00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo000GOol00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo0000
7Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00Aoo`0400moo`0000lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`04
00moo`0000lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moo`0000lGOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol0
3goo00007Woo000FOol00`00Oomoo`02Ool00`00Oomoo`0]Ool00`00Ool03`0HOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moo`0000lGOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700mo
ogooOol03goo00007Woo000FOol6000_Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400l007oo00lGOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000G
Ool01@00Oomoogoo0000;goo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`04Ool0100?001oo`0?5goo00<03gooOol037oo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`005Woo
00<007ooOol00Woo00<007ooOol0;Goo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`04Ool01000Oomoo`0?5goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001io
o`005Woo00<007ooOol00Woo00<007ooOol0;Goo00<007oo00l067oo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool01000Oomoo`0?5goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00mo
o`0001ioo`005Woo00<007ooOol0<Woo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0000moogoo00l05goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`00
01ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0000moogoo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@00
00moogoo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`02Ool00`00Ool03`02Ool00`0?Oomo
o`0EOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo000GOol4000NOol00`00Oomoo`04Ool40007Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?009oo`03
001oo`0?009oo`0300moogoo01Eoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001oo`00009oo`03001o
ogoo01]oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00<007oo00l0
0Woo00<03gooOol05Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`005Woo00<007oo00000Woo00<007ooOol06goo
00<007ooOol027oo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0700moogooOol03goo00000Woo00@03gooOol03aMoo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol001Ioo`03001oo`00009oo`03001oogoo01aoo`03001oogoo00Moo`03001oogoo00Aoo`<0
09X03`0300003`0?0:H03`03001oogoo01aoo`005Woo00<007oo00000Woo00<007ooOol03goo1P00
1goo00<007ooOol01goo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0600moogooOol03`000goo00@03gooOol03aMoo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol001Moo`800003Ool007oo01ioo`03001oogoo00=oo`@000Moo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01P0?Oomoogoo00l000=oo`0400moogoo
00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo000kOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0000Aoo`04
00moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo000fOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`08Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0000Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000fOol60004Ool50006
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Ool0000?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000GOol4000`Ool3000HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOol0000?00Aoo`0400moogoo
00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00Oomoo`0]Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOol0000?00Aoo`04
00moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00Oomoo`0]Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo001oo`0?
00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00Oomoo`0]
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
001oo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00
Oomoo`0]Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03goo001oo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000GOol200000goo001o
o`0_Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03`00Oomo
o`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03`00Oomoo`0?00Aoo`0400moogoo00lG
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`07
00moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D007ooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
07ooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0000?Ool00Woo00<03gooOol0
0Woo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0000moo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0700moogooOol007oo00l00goo00<03gooOol00Woo00@03gooOol03aMoo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01`0?Oomoogoo001o
o`0?00=oo`0300moogoo009oo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00@03gooOol0009oo`0500moogooOol03`04
Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0400moogoo0002Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Ool00003Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]o
o`<001Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Ool00003Ool01@0?Oomoogoo00l0
17oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?001oo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol003Moo`@000Eoo`@000Moo`03001oo`0?01Qoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?001oo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol003Ioo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<007ooOol00goo00D03gooOomoo`0?00Ao
o`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0700moogooOol03goo00007Woo000kOol01@00Oomoogoo000017oo00<007ooOol0
17oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03001oogoo00=oo`0500mo
ogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00>goo00D007ooOomoo`0000Ao
o`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0000mo
o`04Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002eoo`H000Qo
o`05001oogooOol00004Ool00`00Oomoo`04Ool3002<00l00`0000l03`2d00l00`00Oomoo`0LOol0
03Moo`@000Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool01`0?Oomoogoo001oo`0?00Eoo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00mo
o`0001ioo`00=goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol017oo00<007oo00l067oo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0400moogoo0002Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@0
3gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00L03gooOomoo`0?Ool0000NOol003Moo`03001oogoo00Eoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Ool00003Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol003Moo`D000Aoo`@000Mo
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Ool00003Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?001oo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?001oo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]o
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`00Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0000moo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0000mo
o`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`03Ool00`00Ool03`05Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`02Ool01000Oomoo`0?1Goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo
00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00D03gooOomoo`0000=oo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00mo
o`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0500moogooOol00003Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool0100?Oomoo`0017oo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3goo00001Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lG
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`07
00moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03`00Ool01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<007ooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01Woo00<0
000?Ool01Woo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lG
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`07
00moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01Goo00<007oo00l01goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01Goo00<007oo00l01goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
17oo00@007ooOol03`Moo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?
Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00=oo`05001oogooOol03`07Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`02Ool00`00Oomoo`02Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0
03Ioo`H000Aoo`@000Moo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool01@0?Oomoogoo00001Goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000f
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l067oo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0400moogoo0006Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00L03gooOomoo`0?Ool0000NOol003Moo`03001oogoo00Yoo`03001oogoo00Aoo`03001oo`0?01Qo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Ool0
0007Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@0
3gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00L03gooOomoo`0?Ool0000NOol003Qoo`03001oogoo00Uoo`03001oogoo00Aoo`<007L0
3`0300003`0?0<T03`03001oogoo01aoo`00;Goo1P001Woo00<007ooOol027oo00<007ooOol017oo
00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`03001oogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00>Woo00<007ooOol00goo10001goo
00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00Yoo`0300003goo00Qoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00=Woo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol027oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00Qoo`800003Ool03goo00Qoo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00
=Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol027oo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00Ioo`8000=oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomo
o`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01`0?Oomoogoo00moo`0001ioo`00=goo10001Goo1@001Woo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00Eoo`03001oogoo00=oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0
100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00=oo`8000Ioo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03goo
Ool037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo
00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo009oo`03001oogoo00Ioo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`00
01ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo008000Uoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo
00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moo`0000]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04
Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`8000aoo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00mo
o`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01=oo`80
000300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l0
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo011oo`<0009oo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo00ioo`8000Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomo
o`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo00aoo`8000Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03goo
Ool037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo
00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo00Yoo`8000Uoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00
Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Moo`<000]o
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00=oo`@000ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0
100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moo`0000<0019oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomo
ogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`<0
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo
00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00<03goo0000100000=oo`0?Ool05Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`04
00moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Ool000040002Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?000000040003Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool70004Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`06Ool900000`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400mo
ogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0700moogooOol03goo00007Woo0010Ool40007Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool0
0`0?0000000600000goo00moo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogoo
Ool03goo00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol@0009Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
000oOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool0000G00000goo00moo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo
00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo
00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool0000HOol00`00Oomoo`0;Ool0
0`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol01goo00<007ooOol0
1Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000Aoo`04001oogoo000GOol00`00
Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol01goo
00<007ooOol01Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000=oo`07001oogoo
Ool007oo00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool0000HOol00`00Oomo
o`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol01goo00<0
07ooOol01Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000Aoo`04001oogoo000G
Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<007ooOol02goo00<007oo
Ool01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000=oo`07
001oogooOol007oo00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04Oooo0018000NOol003mo
o`03001oogoo009oo`03001oogoo0?moofYoo`00@7oo1000ogooKGoo003oOonaOol00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00=Uoo`D000Aoo`<0009oo`<000=o
o`D000=oo`D000Eoo`@00:eoo`00fWoo00<007ooOol01Woo00<007ooOol00Woo00D007ooOomoo`00
00=oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`2ZOol00=Yo
o`03001oogoo00Ioo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`07Ool01@00Oomo
ogoo0000/Goo003JOol50004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool40005Ool40004Ool6002/
Ool00=Yoo`03001oogoo009oo`04001oogooOol20003Ool01@00Oomoogoo00000goo00<007ooOol0
0Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo0:Yoo`00fWoo00<007ooOol00Woo
00H007ooOomoo`00Ool30005Ool30006Ool50004Ool4002]Ool00=Yoo`03001oogoo009oo`05001o
ogooOol0003<Ool00=Uoo`H000Aoo`03001oogoo0<Yoo`00hWoo0P00c7oo003oOonaOol00?mook5o
o`00ogoo/Goo003oOonaOol00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.96984, -217.067, \
0.0186604, 1.35402}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Whitening", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Vout/Vin /. sol\) /. {Z1 \[Rule] par[1\/\(s\ C\), R2], 
          Z2 \[Rule] par[1\/\(s\ C\), R2], Z3 \[Rule] R, Z4 \[Rule] R, 
          G \[Rule] 1} // Simplify\), "\[IndentingNewLine]", 
    \(\(% /. {R \[Rule] 1.1, C \[Rule] 1/\((2  \[Pi])\), 
          R2 \[Rule] 10};\)\), "\[IndentingNewLine]", 
    \(getZPK[%]\), "\[IndentingNewLine]", 
    \(\(%% /. {s \[Rule] 
            2\ \[Pi]\ \[ImaginaryI]\ f};\)\), "\[IndentingNewLine]", 
    \(\(BodePlot[%, {f, 0.01, 100}];\)\)}], "Input"],

Cell[BoxData[
    \(\((R + C\ R\ R2\ s)\)\^2\/\((R + R2 + C\ R\ R2\ s)\)\^2\)], "Output"],

Cell[BoxData[
    InterpretationBox[\("K(f=0) = "\[InvisibleSpace]0.009820631442253066`\
\[InvisibleSpace]" \
("\[InvisibleSpace]0.009820631442253066`\[InvisibleSpace]")"\),
      SequenceForm[ 
      "K(f=0) = ", .0098206314422530656, " (", .0098206314422530656, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("K(f=\[Infinity]) = "\[InvisibleSpace]1.`\
\[InvisibleSpace]" ("\[InvisibleSpace]1.`\[InvisibleSpace]")"\),
      SequenceForm[ "K(f=\[Infinity]) = ", 1.0, " (", 1.0, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole frequency = \
"\[InvisibleSpace]1.009090909090909`\[InvisibleSpace]" \
("\[InvisibleSpace]1.009090909090909`\[InvisibleSpace]")"\),
      SequenceForm[ 
      "Pole frequency = ", 1.009090909090909, " (", 1.009090909090909, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole Q = "\[InvisibleSpace]0.5000000000000001`\
\[InvisibleSpace]" ("\[InvisibleSpace]0.5000000000000001`\[InvisibleSpace]")"\
\),
      SequenceForm[ 
      "Pole Q = ", .50000000000000011, " (", .50000000000000011, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Zero frequency = "\[InvisibleSpace]0.1`\
\[InvisibleSpace]" ("\[InvisibleSpace]0.1`\[InvisibleSpace]")"\),
      SequenceForm[ 
      "Zero frequency = ", .10000000000000001, " (", .10000000000000001, ")"],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Zero Q = "\[InvisibleSpace]0.5`\[InvisibleSpace]" ("\
\[InvisibleSpace]0.5`\[InvisibleSpace]")"\),
      SequenceForm[ "Zero Q = ", .5, " (", .5, ")"],
      Editable->False]], "Print"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.246914 0.616426 0.0153272 [
[.00617 -0.0125 -14 -12.5625 ]
[.00617 -0.0125 14 0 ]
[.25309 -0.0125 -11 -12.5625 ]
[.25309 -0.0125 11 0 ]
[.5 -0.0125 -5 -12.5625 ]
[.5 -0.0125 5 0 ]
[.74691 -0.0125 -8 -12.5625 ]
[.74691 -0.0125 8 0 ]
[.99383 -0.0125 -11 -12.5625 ]
[.99383 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -8 -25.125 ]
[.5 -0.0125 8 -12.5625 ]
[-0.0125 .00334 -18 -4.5 ]
[-0.0125 .00334 0 4.5 ]
[-0.0125 .15661 -18 -4.5 ]
[-0.0125 .15661 0 4.5 ]
[-0.0125 .30988 -18 -4.5 ]
[-0.0125 .30988 0 4.5 ]
[-0.0125 .46315 -18 -4.5 ]
[-0.0125 .46315 0 4.5 ]
[-0.0125 .61643 -6 -4.5 ]
[-0.0125 .61643 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -8 ]
[-0.01875 .30902 -18 8 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12.5625 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .15661 m
1 .15661 L
s
0 .30988 m
1 .30988 L
s
0 .46315 m
1 .46315 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -69 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .00334 m
.00625 .00334 L
s
[(-40)] -0.0125 .00334 1 0 Mshowa
0 .15661 m
.00625 .15661 L
s
[(-30)] -0.0125 .15661 1 0 Mshowa
0 .30988 m
.00625 .30988 L
s
[(-20)] -0.0125 .30988 1 0 Mshowa
0 .46315 m
.00625 .46315 L
s
[(-10)] -0.0125 .46315 1 0 Mshowa
0 .61643 m
.00625 .61643 L
s
[(0)] -0.0125 .61643 1 0 Mshowa
.125 Mabswid
0 .03399 m
.00375 .03399 L
s
0 .06465 m
.00375 .06465 L
s
0 .0953 m
.00375 .0953 L
s
0 .12596 m
.00375 .12596 L
s
0 .18727 m
.00375 .18727 L
s
0 .21792 m
.00375 .21792 L
s
0 .24857 m
.00375 .24857 L
s
0 .27923 m
.00375 .27923 L
s
0 .34054 m
.00375 .34054 L
s
0 .37119 m
.00375 .37119 L
s
0 .40185 m
.00375 .40185 L
s
0 .4325 m
.00375 .4325 L
s
0 .49381 m
.00375 .49381 L
s
0 .52446 m
.00375 .52446 L
s
0 .55512 m
.00375 .55512 L
s
0 .58577 m
.00375 .58577 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -93.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 10.2813 translate
90 rotate
-69 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dB) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Magnitude) show
117.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .00224 m
.02372 .00275 L
.03955 .00336 L
.05352 .00408 L
.06699 .00497 L
.08806 .00686 L
.10505 .00901 L
.12058 .01161 L
.13367 .01442 L
.14491 .01738 L
.1557 .02078 L
.16516 .02428 L
.17353 .02785 L
.18178 .03183 L
.18916 .03582 L
.19649 .04023 L
.2031 .04461 L
.2091 .04892 L
.21513 .05362 L
.22064 .05822 L
.22619 .06318 L
.23129 .06801 L
.23597 .0727 L
.24074 .07772 L
.24514 .08258 L
.2492 .08726 L
.25309 .09191 L
s
.25309 .09191 m
.28646 .13857 L
.31391 .18507 L
.33453 .22367 L
.35121 .25646 L
.3665 .28728 L
.37942 .31354 L
.39162 .33832 L
.4022 .3596 L
.41148 .378 L
.42054 .39564 L
.4286 .41098 L
.43581 .42439 L
.44299 .43739 L
.44948 .4488 L
.45597 .45988 L
.46187 .46963 L
.46726 .47825 L
.4727 .48668 L
.4777 .49415 L
.48277 .50146 L
.48743 .50795 L
.49174 .51374 L
.49613 .51943 L
.5 .52426 L
s
.5 .52426 m
.51754 .54409 L
.53337 .5591 L
.56082 .57914 L
.58072 .5896 L
.5985 .59663 L
.61321 .60111 L
.62691 .60441 L
.63864 .60669 L
.64882 .60832 L
.65869 .60965 L
.66741 .61064 L
.67517 .61141 L
.68285 .61207 L
.68977 .61259 L
.69666 .61304 L
.7029 .61341 L
.70858 .61371 L
.71432 .61398 L
.71956 .61421 L
.72487 .61442 L
.72974 .61459 L
.73423 .61474 L
.73881 .61487 L
.74304 .61499 L
.74691 .61509 L
s
.74691 .61509 m
.76446 .61546 L
.78029 .61571 L
.79426 .61587 L
.80773 .616 L
.81928 .61608 L
.8288 .61614 L
.84579 .61621 L
.86079 .61627 L
.87347 .6163 L
.88549 .61633 L
.89592 .61634 L
.90507 .61636 L
.91403 .61637 L
.92199 .61638 L
.92986 .61638 L
.93693 .61639 L
.94331 .61639 L
.94972 .6164 L
.95554 .6164 L
.9614 .6164 L
.96675 .6164 L
.97167 .61641 L
.97666 .61641 L
.98126 .61641 L
.9855 .61641 L
.98984 .61641 L
.99383 .61641 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00hWoo0`000Woo0`000Woo1P00_Woo003S
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000_Woo003SOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`2oOol00>=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
0;ioo`00hgoo1P000goo00D007ooOomoo`000;moo`00hgoo00<007ooOol00Woo00@007ooOomoo`H0
0;ioo`00hgoo00<007ooOol00Woo00<007ooOol0aGoo003ROol30002Ool30036Ool00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo000iOol40006Ool20006Ool40004Ool7000dOol40006Ool20005Ool7
0010Ool70015Ool70003Ool4000nOol70003Ool40005Ool4000KOol003Qoo`03001oogoo009oo`03
001oogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo
009oo`03001oogoo00=oo`8000Qoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03001o
ogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo
00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo
00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qo
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Ao
o`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03
001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001o
ogoo00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol0
03Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo009oo`<003Ioo`03
001oogoo009oo`03001oogoo00]oo`<004Aoo`<004Uoo`<000Eoo`03001oogoo009oo`03001oogoo
03aoo`<000Eoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Uoo`@000io
o`@000Moo`03001oogoo03Eoo`@0011oo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00Ao
o`@0045oo`03001oogoo00Aoo`@000Eoo`@001]oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol003Aoo`@000Aoo`@00?moog5oo`00=Woo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol0ogooKWoo000fOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Oooo0018
000ROol0039oo`H000=oo`03001oogoo009oo`03001oogoo00Aoo`l000]oo`03001oogoo00]oo`03
001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05
001oogooOol00002Ool00`00Oomoo`0FOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007oo
Ool05Goo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<007oo
Ool00goo00D007ooOomoo`0000=oo`05001oogooOol0000GOol00`00Oomoo`0;Ool00`00Oomoo`08
Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo
00000Woo00@007ooOol0029oo`00:Goo1P0017oo00@007ooOol000Aoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oo`0000aoo``000eoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo009oo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`0FOol00`00Oomo
o`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol01goo00<0
07ooOol01Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol0
000GOol00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0029oo`00<goo00@007ooOol0
00Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`/000=oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`00=7oo00<007oo000017oo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo
00<03gooOol027oo10002Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo000dOol00`00Ool00004Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?000000020005Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol003Eo
o`8000Eoo`@000Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo009oo`@00003Ool03goo
00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029o
o`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01Woo10001Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`020003Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo009oo`800003Ool03goo00Eoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol017oo0P001Woo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo0017Ool200000`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?00000004Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo0080009oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029o
o`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00Woo0P0000<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool0
0`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`00Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300l007oo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00H03goo000007oo00l4Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0600moogooOol0000?17oo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo
0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`00Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001o
o`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300l00000009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00H0
3gooOol007oo00l3Ool0100?Oomoo`0?67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol004Moo`80000300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0600moogooOol0000?0goo00@0
3gooOol03aQoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool01P0?Oomoogoo00003`=oo`0400moogoo00lHOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D007ooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?000007oo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moo`00
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOol0000?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoogoo0P0000=oo`0?Ool05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001o
o`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0800moogooOol03`00Ool03aQoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool0200?Oomoogoo00moo`0000lHOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`03001oogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool200000`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03`00
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?001oo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moo`0001Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol001Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00D03gooOomoo`0001Aoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00D03gooOomoo`0001Aoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol00Woo00<007ooOol04Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`03Ool00`00Oomoo`0@Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo00Aoo`03001oogoo00moo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol017oo00<007ooOol03goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo000ROol004Moo`80000300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`05Ool00`00Oomoo`0>Ool00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo00Ioo`03001oogoo00eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol01goo00<007ooOol037oo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`07Ool00`00Oomoo`0<Ool00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo00Qoo`03001oogoo00]oo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol02Goo00<007ooOol02Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`09Ool00`00Oomoo`0:Ool00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00<goo10001Goo10001goo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo00Yoo`03001oogoo
00Uoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000b
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l05goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo00Yoo`03001oogoo00Uoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000gOol01@00Oomoogoo000017oo
00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
00]oo`03001oogoo00Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo000gOol01@00Oomoogoo000017oo00<007ooOol017oo0`00G@0?00<0000?00l0h`0?
00<007ooOol087oo000YOol60006Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol037oo00<007ooOol01goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol003Moo`05001o
ogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol037oo00<007ooOol01goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol003Moo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol03Goo00<007ooOol01Woo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0039oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol03Woo00<007ooOol01Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol003=oo`@000Eoo`@000Moo`03001oo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0>Ool00`00Oomoo`05Ool00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo00moo`03001oogoo00Aoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol03goo00<007ooOol017oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001o
o`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0@Ool00`00Oomoo`03Ool0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<0
07oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo011oo`03001oogoo00=o
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool2
00000`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol04Goo00<007oo
Ool00Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol01@00
Oomoogoo00l03Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol01@00Oomoogoo
00l03Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0COol01000Oomoo`0?3Goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0COol01000Oomoo`0?3Goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0DOol00`00Ool03`0=Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Aoo`03001oo`0?00eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Goo00<0000?Ool037oo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`00
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03001oogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool200000`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03`00Ool02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?001oo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moo`0000]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03goo00002goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
100?Oomoo`002Woo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0100?Oomoo`00
2Woo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol01@0?Oomoogoo00002Goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol01@0?Oomoogoo00002Goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`02Ool00`00Oomoo`06Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo009oo`03001oogoo00Ioo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool200000`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol00goo00<007ooOol01Goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`03Ool00`00Oomoo`05
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00Aoo`03001oogoo
00Aoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol017oo00<007oo
Ool017oo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`04Ool00`00
Oomoo`04Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00Eoo`03
001oogoo00=oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol01Goo
00<007ooOol00goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`06
Ool00`00Oomoo`02Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00Ioo`03001oogoo009oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017
Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool01goo00D007ooOomoo`0?00Uoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool20000
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
1goo00D007ooOomoo`0?00Uoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol027oo00@0
07ooOol03`Uoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol027oo00@007ooOol03`Uo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo000KOol4000XOol00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02Goo00<007oo00l02Goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo000ROol001Yoo`03001oogoo009oo`03001oogoo02Eoo`03001o
o`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`09Ool0
0`00Ool03`09Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`006Woo00<007ooOol00Woo00<0
07ooOol09Goo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00Yoo`0300003goo00Qoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000JOol0
0`00Oomoo`02Ool00`00Oomoo`0UOol00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02Woo00<0000?Ool027oo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol001Moo`04001oogoo0003Ool00`00Oomoo`0AOol60004Ool40007Ool00`00Ool03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<007oo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol001Moo`T0019oo`03001oogoo009oo`05
001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<007ooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol001moo`03001oogoo015oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo
00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?001oo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=7oo00<007oo
Ool017oo00<007ooOol00Woo00<007ooOol017oo0`00M`0?00<0000?00l0b@0?00<007ooOol087oo
000YOol60006Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03goo0000
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol001Qoo`03001oogoo00Aoo`03001oogoo01Ao
o`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Ool00007Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol0029oo`0067oo20004Woo00<007ooOol00Woo00D007ooOomoo`0000Ao
o`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool0100?Oomoo`001Woo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
01Qoo`04001oogoo0003Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<0
07ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0400moogoo0006Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`0067oo
00@007ooOol000=oo`03001oogoo015oo`@000Eoo`@000Moo`03001oo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool01@0?Oomoogoo00001Goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo000ROol001Qoo`04001oogoo0003Ool00`00Oomoo`0UOol00`00
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00D03gooOomoo`0000Eoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000HOol01000Oomoo`00
0goo00<007ooOol09Goo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moogoo009oo`03001oogoo009oo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`008Woo000IOol2000017oo00000000:7oo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo009oo`03001oogoo009o
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol00goo00D007ooOomo
o`0?00Moo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo0017Ool200000`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol00goo00D007ooOomoo`0?
00Moo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol017oo00@007ooOol03`Moo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol017oo00@007ooOol03`Moo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01Goo00<007oo00l01goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`06Ool00`0000moo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Ioo`0300003goo00Ioo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<007oo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`00Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300l007oo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01goo00<03`00Ool01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`80
000300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Ool00005Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moo`0000Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00@0
3gooOol000Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00@03gooOol000Ao
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00D03gooOomoo`0000=oo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00D03gooOomoo`0000=oo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol00Woo00@007ooOol03`Eoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017
Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol00Woo00@007ooOol03`Eoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol00goo00<007oo00l01Goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`03Ool00`00Ool03`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo0P0000<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Aoo`0300003goo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol017oo00<0000?
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`00Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029o
o`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03001oogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03`00Ool00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?001oo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moo`0000=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
00000goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0100?Oomoo`000Woo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0100?Oomoo`000Woo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`80
000300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool01`0?Oomoogoo001oo`0?00Aoo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00L03gooOomoo`00Ool03`04Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo009oo`0300003goo00=oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<007ooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`00Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300l007oo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03`00Ool00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0039oo`L000=oo`@000Moo`03001o
o`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Ool00002Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=Goo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moo`00009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo000eOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00H03gooOol007oo00l4Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00=Goo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool017oo0`00TP0?00<0000?00l0[P0?00<007ooOol087oo000YOol60006Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00H03gooOomoo`0000l4Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029o
o`00=Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03001oogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo000eOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03`00Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol003=oo`<0
00Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?001oo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00=Goo00<007ooOol017oo10001goo00<007oo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moo`00009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00H03gooOol007oo00l3Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0600moogoo001oo`0?0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01P0?Oomoogoo00003`=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00H03gooOomoo`0000l3Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo0P0000<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`05001oogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03`00Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Mo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?001oogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
o`00Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOol0000?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00000goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol00003Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00H03gooOomoo`0?0002Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017
Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00T03gooOomoo`0?Ool007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0000moo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool200000`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`03001oogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03`00Ool0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?001oo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0001Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Mo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol001Aoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0001=oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0001=oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol00Woo00<007ooOol047oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`03Ool2000@Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo00Eoo`03001oogoo00eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`80000300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol01Woo0P003Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`08Ool00`00Oomoo`0:Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo00Uoo`03001oogoo00Uoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol02Woo0P002Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0<Ool00`00Oomoo`06Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo00eoo`03001oogoo00Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol03Woo0P001Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0@Ool00`00Oomoo`02Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo015oo`05001oogooOol03`0=Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo019oo`800003Ool03goo00aoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`80000300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
57oo0P003Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?0000000;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo
0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo008000Uoo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol00Woo0P001goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`04Ool40003Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00Qoo`@000Uoo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03`0000000P001Goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol0029oo`00?7oo10001goo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`02Ool70006Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`008Woo000kOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moo`0000L000Aoo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol003]oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0001Moo`03
001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`0FOol00`00Oomoo`0;Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007oo
00004P000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol027oo00<007ooOol017oo00<0
07ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo000R
Ool003]oo`03001oogoo009oo`03001oogoo00Aoo`<001Moo`03001oogoo00]oo`03001oogoo00Mo
o`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol0
0002Ool00`00Oomoo`0FOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<0
07ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00goo00D0
07ooOomoo`0000=ooeD0009oo`03001oogoo021oo`00>goo00<007ooOol00Woo00<007ooOol017oo
o`00B0008Woo000kOol00`00Oomoo`02Ool00`00Oomoo`3oOom^Ool003]oo`03001oogoo009oo`03
001oogoo0?moofioo`00>goo00<007ooOol00Woo00<007ooOol0ogooKWoo000lOol4003oOomaOol0
0?mook5oo`00ogoo/Goo003EOol4003GOol00=Uoo`03001oogoo0=Aoo`00fGoo00<007ooOol0e7oo
0031Ool30003Ool30003Ool50003Ool300000goo001oo`02Ool30002Ool300000goo000000050005
Ool40004Ool300000goo00000002Ool300000goo00000004Ool4002POol00<9oo`03001oogoo00=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo0P0017oo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol000=oo`80009oo`04001oogooOol20004
Ool00`00Oomoo`02Ool00`00Oomoo`2MOol00<9oo`04001oogoo0002Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomo
o`2ROol00<9oo`07001oo`00Ool007oo000017oo10000goo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol00Woo
00@007ooOol000Aoo`03001oogoo009oo`H009moo`00`Woo00L007oo001oo`00Ool00003Ool01@00
Oomoogoo00000goo00@007ooOomoo`8000Aoo`8000=oo`03001oogoo00=oo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0003Ool20004Ool00`00Oomoo`02Ool00`00Oomo
o`2MOol00<9oo`07001oo`00Ool007oo000017oo0`001Goo0`0000=oo`0000000Woo0P0000Aoo`00
000000Aoo`<000Eoo`L0009oo`8000=oo`8000=oo`<00003Ool007oo00Aoo`@00:1oo`00`Woo0P00
0goo0P00:7oo00<007ooOol04Woo00<007ooOol0Ygoo0031Ool30003Ool3000WOol00`00Oomoo`0B
Ool00`00Oomoo`2WOol00>Uoo`03001oogoo01Uoo`800:Uoo`00jGoo00<007ooOol0a7oo003oOona
Ool00?mook5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.91386, -48.5864, \
0.0186604, 0.30061}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.246914 0.010828 0.00547577 [
[.00617 -0.0125 -14 -12.5625 ]
[.00617 -0.0125 14 0 ]
[.25309 -0.0125 -11 -12.5625 ]
[.25309 -0.0125 11 0 ]
[.5 -0.0125 -5 -12.5625 ]
[.5 -0.0125 5 0 ]
[.74691 -0.0125 -8 -12.5625 ]
[.74691 -0.0125 8 0 ]
[.99383 -0.0125 -11 -12.5625 ]
[.99383 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -8 -25.125 ]
[.5 -0.0125 8 -12.5625 ]
[-0.0125 .01083 -6 -4.5 ]
[-0.0125 .01083 0 4.5 ]
[-0.0125 .12034 -12 -4.5 ]
[-0.0125 .12034 0 4.5 ]
[-0.0125 .22986 -12 -4.5 ]
[-0.0125 .22986 0 4.5 ]
[-0.0125 .33937 -12 -4.5 ]
[-0.0125 .33937 0 4.5 ]
[-0.0125 .44889 -12 -4.5 ]
[-0.0125 .44889 0 4.5 ]
[-0.0125 .55841 -18 -4.5 ]
[-0.0125 .55841 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -20 ]
[-0.01875 .30902 -18 20 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12.5625 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .12034 m
1 .12034 L
s
0 .22986 m
1 .22986 L
s
0 .33937 m
1 .33937 L
s
0 .44889 m
1 .44889 L
s
0 .55841 m
1 .55841 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -69 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01083 m
.00625 .01083 L
s
[(0)] -0.0125 .01083 1 0 Mshowa
0 .12034 m
.00625 .12034 L
s
[(20)] -0.0125 .12034 1 0 Mshowa
0 .22986 m
.00625 .22986 L
s
[(40)] -0.0125 .22986 1 0 Mshowa
0 .33937 m
.00625 .33937 L
s
[(60)] -0.0125 .33937 1 0 Mshowa
0 .44889 m
.00625 .44889 L
s
[(80)] -0.0125 .44889 1 0 Mshowa
0 .55841 m
.00625 .55841 L
s
[(100)] -0.0125 .55841 1 0 Mshowa
.125 Mabswid
0 .03821 m
.00375 .03821 L
s
0 .06559 m
.00375 .06559 L
s
0 .09296 m
.00375 .09296 L
s
0 .14772 m
.00375 .14772 L
s
0 .1751 m
.00375 .1751 L
s
0 .20248 m
.00375 .20248 L
s
0 .25724 m
.00375 .25724 L
s
0 .28462 m
.00375 .28462 L
s
0 .312 m
.00375 .312 L
s
0 .36675 m
.00375 .36675 L
s
0 .39413 m
.00375 .39413 L
s
0 .42151 m
.00375 .42151 L
s
0 .47627 m
.00375 .47627 L
s
0 .50365 m
.00375 .50365 L
s
0 .53103 m
.00375 .53103 L
s
0 .58578 m
.00375 .58578 L
s
0 .61316 m
.00375 .61316 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -105.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
81 10.2813 translate
90 rotate
-81 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(degree) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phase) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .06715 m
.03955 .08747 L
.06699 .10938 L
.08762 .12966 L
.1043 .14884 L
.11959 .16886 L
.1325 .18771 L
.14471 .20724 L
.15529 .22555 L
.16457 .24266 L
.17363 .2603 L
.18168 .27673 L
.1889 .29201 L
.19608 .3077 L
.20256 .32224 L
.20906 .33711 L
.21496 .35086 L
.22034 .36356 L
.22579 .37652 L
.23079 .38847 L
.23585 .40062 L
.24052 .4118 L
.24482 .42209 L
.24922 .43254 L
.25309 .44167 L
s
.25309 .44167 m
.28646 .51538 L
.31391 .56421 L
.32508 .57984 L
.33453 .5909 L
.34343 .59939 L
.35121 .60523 L
.35511 .6076 L
.35919 .60967 L
.36274 .61112 L
.36597 .61217 L
.36926 .61296 L
.37096 .61326 L
.37277 .6135 L
.37366 .61359 L
.37412 .61362 L
.37462 .61366 L
.37509 .61368 L
.37552 .6137 L
.37573 .61371 L
.37595 .61372 L
.37635 .61373 L
.37674 .61373 L
.37696 .61373 L
.37716 .61373 L
.37758 .61373 L
.37781 .61372 L
.37802 .61372 L
.37839 .61371 L
.3788 .61369 L
.37953 .61365 L
.38025 .6136 L
.38103 .61353 L
.38242 .61336 L
.38405 .6131 L
.38552 .61281 L
.38849 .61205 L
.39154 .61104 L
.3969 .60869 L
.40166 .60599 L
.41113 .59896 L
.42036 .59001 L
.42855 .58039 L
.43588 .5705 L
.44317 .55953 L
.44975 .5487 L
.45571 .53818 L
.46172 .52694 L
.4672 .51618 L
.47273 .50485 L
Mistroke
.47781 .49411 L
.48247 .48396 L
.48722 .47337 L
.4916 .46342 L
.49607 .45312 L
.5 .44395 L
Mfstroke
.5 .44395 m
.53337 .36437 L
.56082 .30144 L
.58144 .25828 L
.59812 .22671 L
.61342 .20054 L
.62633 .18052 L
.63854 .16329 L
.64912 .14964 L
.65839 .13858 L
.66745 .12858 L
.67551 .1203 L
.68272 .11336 L
.68991 .10686 L
.69639 .10133 L
.70288 .09611 L
.70878 .09161 L
.71417 .08771 L
.71962 .08395 L
.72461 .08066 L
.72968 .07747 L
.73435 .07466 L
.73865 .07217 L
.74305 .06973 L
.74691 .06766 L
s
.74691 .06766 m
.78029 .05253 L
.80773 .04314 L
.82836 .0375 L
.84504 .03366 L
.86033 .03063 L
.87324 .02838 L
.88545 .0265 L
.89603 .02502 L
.90531 .02385 L
.91437 .02279 L
.92242 .02193 L
.92964 .02121 L
.93682 .02053 L
.9433 .01996 L
.9498 .01943 L
.9557 .01897 L
.96108 .01857 L
.96653 .01819 L
.97153 .01785 L
.97659 .01753 L
.98126 .01724 L
.98556 .01699 L
.98996 .01674 L
.99383 .01653 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00hWoo0`000Woo0`000Woo1P00_Woo003S
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000_Woo003SOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`2oOol00>=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
0;ioo`00hgoo1P000goo00D007ooOomoo`000;moo`00hgoo00<007ooOol00Woo00@007ooOomoo`H0
0;ioo`00hgoo00<007ooOol00Woo00<007ooOol0aGoo003ROol30002Ool30036Ool00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo000iOol40006Ool20006Ool40004Ool7000dOol40006Ool20005Ool7
0010Ool70015Ool70003Ool4000nOol70003Ool40005Ool4000KOol003Qoo`03001oogoo009oo`03
001oogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo
009oo`03001oogoo00=oo`8000Qoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03001o
ogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo
00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo
00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qo
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Ao
o`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03
001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001o
ogoo00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol0
03Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo009oo`<003Ioo`03
001oogoo009oo`03001oogoo00]oo`<004Aoo`<004Uoo`<000Eoo`03001oogoo009oo`03001oogoo
03aoo`<000Eoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Uoo`@000io
o`@000Moo`03001oogoo03Eoo`@0011oo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00Ao
o`@0045oo`03001oogoo00Aoo`@000Eoo`@001]oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo000lOol40007Oooo0018000ROol003]oo`03001oogoo
009oo`03001oogoo00Aoo`03001oo`0001Moo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00002Ool00`00
Oomoo`0FOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<007ooOol02goo
00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`00
00=oo`05001oogooOol0000GOol00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0029o
o`00>goo00<007ooOol00Woo00<007ooOol017oo00<007oo00005goo00<007ooOol02goo00<007oo
Ool01goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00D007oo
Oomoo`00009oo`03001oogoo01Ioo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0E
Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool01@00Oomoogoo00000goo00D007ooOomoo`0001Moo`03001oogoo00]oo`03001oogoo00Qoo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00002
Ool01000Oomoo`008Woo000kOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol003]oo`03001oogoo009oo`03001oogoo00Aoo`<0
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00>goo00<007ooOol00Woo00<007oo
Ool017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000kOol00`00
Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03goo00002P000Woo00<007ooOol087oo000kOol00`00
Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo
00<03gooOol02`000goo00D03gooOomoo`0?009oo`0400moogoo000ROol003aoo`@000Moo`03001o
o`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Ool000070004Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00=oo`L000Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol027oo2@001Goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`04Ool40003Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
01Moo`0300moogoo009oo`8000Moo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool20000
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo1@002Goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0BOol500000`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00moo`<000Eoo`0300moogoo00]oo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l037oo0`0027oo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`09Ool3000;Ool00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?00Moo`8000ioo`0300moogoo00]oo`0300moogoo00Qoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l01Goo0P0047oo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`03Ool2000BOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00H03gooOomoo`0?Ool2000DOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029o
o`00Agoo0`005goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOomoo`80
01Ioo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`02
000EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoo`0000l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?009oo`03001o
ogoo019oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500l00000Ool03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l00goo0P00
4Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D007ooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`05Ool2000@Ool0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`02Ool00`0000moo`02Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l01goo00<0
07ooOol03Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00P0000=oo`0?Ool00Woo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001o
o`0?00Qoo`8000eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00<03gooOol00P000goo00D03gooOomoo`0?
01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0:
Ool00`00Oomoo`0:Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500l00000Ool03`03Ool01@0?Oomoogoo
00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?
00]oo`03001oogoo00Uoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D007ooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo0P0000<0
3gooOol02Woo0P002Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0000moo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Mo
o`03001oo`0?00ioo`03001oogoo00Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00L03gooOomoo`00Ool03`03Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool004Moo`03001oo`0?00moo`03001oogoo00Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00@03goo0000009oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo
000ROol004Moo`03001oo`0?011oo`8000Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03`00Ool00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029o
o`00Agoo00<007oo00l04Woo00<007ooOol00Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`00Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo000bOol60004Ool40007Ool00`00Ool03`0COol01@00Oomoogoo00l03Goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0100?Oomoogoo0P0000<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`00<Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001o
o`0?01Aoo`04001oogoo00l=Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0400moogoo0002Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000cOol00`00Oomoo`05Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0EOol00`00Ool03`0=Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moo`0000=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol003Aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Io
o`0300003goo00aoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3goo00000goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=Goo00<007ooOol00goo00<007ooOol0
0Woo00<007ooOol017oo0`005P0?00<0000?00l0`00?00<0000?00l0I`0?00<007ooOol087oo000f
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`00Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Aoo`8000Eoo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol0039oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04
Ool00`00Ool03`0GOol00`0?001oo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00=oo`03001oo`0?00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0039oo`03001oogoo
009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Ool0000;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo009oo`04001oogoo00l5Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo000cOol40005Ool40007Ool00`00Ool03`0GOol0100?Oomoo`002Woo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool01@0?Oomoogoo00000goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00D03gooOomoo`0000Uoo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00@03gooOol000Aoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo009oo`03001oogoo00Io
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo00001Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol00goo00<007ooOol0
1Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?001oo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo0017Ool200000`0?Oomoo`0EOol00`0?Oomoo`04Ool00`00
Oomoo`04Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300l007oo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00Eoo`03
001oogoo00=oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<007ooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol01Woo
00<007ooOol00Woo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`06Ool00`0000moo`06Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`07
Ool01@00Oomoogoo00l02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`06Ool00`0000moo`06Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`07Ool01@00
Oomoogoo00l02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`00Ool03`07Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`08Ool01000Oomoo`0?
2Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`00Ool03`07Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`09Ool00`00Ool03`09Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Aoo`04001oogoo00l7Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0:Ool00`0000moo`08Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00=oo`05001oogooOol03`07Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017
Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`00Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo009oo`03
001oogoo009oo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`80000300moogoo01Eoo`0300moogoo00]oo`03001oogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
0Woo00<007ooOol00Woo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03`00Ool01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool01@0?Oomo
ogoo00001Goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo00<007oo00l05goo00<03gooOol02goo00<03goo00001goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0100?Oomoo`001Woo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03goo00001goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Ool00007Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool0100?Oomoo`001Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Ool00007Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool0
1@0?Oomoogoo00001Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?001oo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool01@0?Oomo
ogoo00001Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?001oo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`02Ool0
0`00Oomoo`02Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`03001oogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo009o
o`03001oogoo009oo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<007ooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol0029oo`00Agoo0P0000<03gooOol05Goo00<03gooOol02goo00<03goo
Ool00goo00D007ooOomoo`0?00Moo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02Woo00<0000?Ool027oo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol00goo
00D007ooOomoo`0?00Moo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02Goo00<007oo00l02Goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol017oo00@007oo
Ool03`Moo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2Goo00<007oo00l02Goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01Goo00<007oo00l01goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`08Ool01000Oomo
o`0?2Goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01Goo00<007oo00l01goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`07Ool01@00Oomoogoo00l02Goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01Woo00<0000?Ool01Woo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`07Ool01@00Oomoogoo00l02Goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=7oo100017oo10001goo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<007ooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`06Ool00`00Oomoo`02Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000f
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`00Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00Ioo`03001oogoo009oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol003Ioo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300l007oo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol01Goo
00<007ooOol00goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00<Woo1P000goo00<007ooOol00Woo00<007ooOol017oo0`00<@0?00<0000?
00l0R`0?00<0000?00l0P@0?00<007ooOol087oo000KOol4000DOol01000Oomoo`0017oo00<007oo
Ool00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
00001Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`04
Ool00`00Oomoo`04Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo000JOol00`00Oomoo`02Ool00`00Oomoo`0AOol01000Oomoo`0017oo00<0
07ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00@0
3gooOol000Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool00goo00<007ooOol01Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`006Woo00<007ooOol00Woo00<007ooOol04Woo00<007oo000017oo
00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00@03gooOol000Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol00goo00<007ooOol01Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol0029oo`006Woo00<007ooOol00Woo00<007ooOol04Woo00<007oo0000
17oo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol0
1goo00D03gooOomoo`0000=oo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol00Woo00<007ooOol01Woo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`005goo00@007ooOol000=oo`03001oogoo01Aoo`80
00Eoo`@000Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0500moogooOol00003
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0500moogooOol00009
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo000GOol9000WOol00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`02
Ool01000Oomoo`0?1Woo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol01@0?Oomoogoo0000
2Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`007goo00<007ooOol09Goo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol00Woo00@007ooOol03`Ioo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00@03goo
Ool000Yoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo009o
o`04001oogoo00l6Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0400moogoo000:Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo
0017Ool200000`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`03Ool00`00
Ool03`06Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moo`0000]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00=oo`03001oo`0?00Ioo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo00002goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`006goo1000:7oo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol017oo00<0000?Ool01Goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?001oo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000JOol00`00Ool00002Ool00`00
Oomoo`0UOol00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`00
00moo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300l007oo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol001Yoo`03
001oo`00009oo`03001oogoo02Eoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`03001oogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<007oo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`006Woo00<007oo00000Woo00<007ooOol09Goo00<007oo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<007ooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`00Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo000JOol00`00Ool00002Ool00`00Oomoo`0UOol00`00Ool03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?001oo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`03001oogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol001]oo`800003Ool007oo02Moo`03001o
o`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300l007oo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol057oo00<0000?Ool037oo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo000017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0DOol00`0000moo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool200000`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Ool00004Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01=oo`03001oo`0?00eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol001]oo`@002Qoo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0400moogoo0003Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01=oo`03001oo`0?00eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol001Yoo`03001oogoo009oo`04001oogoo000TOol00`00Ool03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0100?Oomoo`000goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0COol00`00Ool03`0=Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000JOol00`00Oomoo`02Ool01000Oomo
o`0097oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00@03goo
Ool000=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol04Woo00@007ooOol03`eoo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol001Yoo`03
001oogoo009oo`04001oogoo000TOol00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool01@0?Oomoogoo00000Woo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0BOol0
1000Oomoo`0?3Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`006goo00@007ooOol000=oo`03001oogoo029oo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0500moogooOol00002Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo015oo`05001oogooOol03`0=Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000JOol8000UOol00`00Ool03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`00Ool03`04Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo015oo`05001oogooOol03`0=Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000JOol00`00Oomoo`0ZOol00`00Ool0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`00Ool0
3`04Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo015oo`05001oogooOol03`0=Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0000moo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo011oo`03001oogoo009oo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`80000300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300003goo
00=oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol047oo00<007ooOol00Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<007oo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0?Ool00`00Oomoo`03Ool00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000JOol00`00
Oomoo`02Ool00`00Oomoo`0UOol00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`00Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00moo`03001oogoo
00=oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol001Yoo`H002Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300l007oo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol03Woo
00<007ooOol017oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`006goo00D007ooOomoo`0002Moo`03001oo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300l007oo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol03Woo00<007ooOol017oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`006Woo00<007ooOol00Woo
00<007ooOol04Woo100017oo10001goo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03goo00000Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0=Ool00`00
Oomoo`05Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo000JOol00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`02
Ool01000Oomoo`0017oo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03goo00000Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0=Ool0
0`00Oomoo`05Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo000JOol00`00Oomoo`0FOol00`00Oomoo`02Ool01000Oomo
o`0017oo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00H03gooOol007oo00l4Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00aoo`03001oogoo00Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol003=oo`8000=oo`04001oogoo0004Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool01P0?Oomoo`00Ool03`Ao
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol037oo00<007ooOol01Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00<goo00<007oo00000P000goo00<007oo
Ool00Woo00<007ooOol017oo0`00@@0?00<0000?00l0J`0?00<0000?00l0T@0?00<007ooOol087oo
000cOol00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool01P0?Oomoogoo00003`Aoo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool02goo00<007ooOol01goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`006goo10005Goo00<007ooOol017oo00<007oo
Ool00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00H03gooOomoo`0000l4Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00]oo`03001oogoo00Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol001Yoo`03001oo`00009oo`03001oogoo01=oo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`03001oogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol02Woo00<007ooOol027oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`006Woo00<007oo00000Woo00<007ooOol057oo0`000goo10001goo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<007ooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0:Ool00`00Oomoo`08Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000JOol00`00Ool0
0002Ool00`00Oomoo`0UOol00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`00Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Uoo`03001oogoo00Uo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0400moogoo000ROol001Yoo`03001oo`00009oo`03001oogoo02Eoo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300l0
07oo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol02Goo00<007ooOol02Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`006goo0P0000=oo`00Ool09goo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03`00Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`08Ool00`00Oomoo`0:Ool00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017
Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Ool00002Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo00Qoo`03001oogoo00Yoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`80000300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moo`00009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol027oo00<007ooOol02Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03goo00000Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`07Ool00`00Oomoo`0;Ool00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo000KOol4000XOol00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool01P0?Oomoo`00Ool03`=oo`0400moogoo00lHOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol01goo00<007ooOol02goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`006Woo00<007oo00000Woo00<007ooOol09Goo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00H03gooOol007oo00l3
Ool0100?Oomoo`0?67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Ioo`03001o
ogoo00aoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol001Yoo`03001oo`00009oo`03001oogoo02Eoo`03001oo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0600moogoo001oo`0?0goo00@03gooOol03aQoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`06Ool00`00Oomoo`0<Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000JOol00`00Ool00002Ool00`00Oomo
o`0UOol00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool01P0?Oomoogoo00003`=oo`0400moogoo00lHOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol01Goo00<007ooOol03Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`006Woo00<0
07oo00000Woo00<007ooOol09Goo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00H03gooOomoo`0000l3Ool0100?Oomoo`0?
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Eoo`03001oogoo00eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol001]oo`800003Ool007oo02Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05001oogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol01Goo
00<007ooOol03Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D007oo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`04
Ool00`00Oomoo`0>Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo0017Ool200000`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?001oogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo00Aoo`03001oogoo00ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500l007ooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol00goo00<007ooOol03goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03goo001oo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`03Ool00`00Oomoo`0?Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Ool007oo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo009oo`03001oogoo011oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogoo00003`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol00Woo00<007ooOol047oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOol0000?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`02Ool00`00Oomoo`0@Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoo`0000l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0500moogooOol0000COol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00000Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0500moogooOol0000COol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00000Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400mo
ogoo000DOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool200000`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomo
ogoo00l007oo00lHOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol001Aoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0800moogooOol03`00Ool03aQoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0057oo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<0
07oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00P03gooOomoo`0?Ool0000?67oo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moo`0001Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0800moogooOol03goo00003aQoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0
000EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomoogoo00mo
o`0000lHOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03`00Ool05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029o
o`00<goo10001Goo10001goo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
001oogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?001oo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo000bOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`03001oogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`00Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000bOol00`00Oomoo`02Ool01@00Oomoogoo
000017oo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
001oogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`00Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo000bOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300l007oo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0000moo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000cOol40004Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool3001@00l00`0000l03`1<00l00`0000l03`2Q00l00`00Oomoo`0POol0039oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03goo00005Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00T03gooOomoo`0?Ool007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00<Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Ao
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Ool0000FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool02@0?Oomoogoo00moo`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000bOol00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01P0?Oomoogoo00l0009oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0400moogoo000ROol003=oo`@000Eoo`@000Moo`03001oo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`005Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00H03gooOomoo`0?0002Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00D03gooOomoo`0001Aoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0600moogooOol03`000Woo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`05
00moogooOol0000DOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00000goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
009oo`03001oogoo015oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol00003Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool200000`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol00Woo00<007ooOol04Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOol0000?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`02Ool00`00Oomoo`0AOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoo`0000l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo00=oo`03001oogoo011oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moo`00Ool03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol00goo00<007ooOol047oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo001oo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`04Ool00`00Oomoo`0?Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Ool007oo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo00Aoo`03001oogoo00moo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500l007ooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol01Goo00<007ooOol03Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03`00Oomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`05Ool00`00Oomoo`0>Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@00Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo00Ioo`03001oogoo00eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05001oogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool200000`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol01Woo00<007ooOol03Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00H03gooOomoo`0000l3Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo00Moo`03001oogoo00aoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0600moogooOol0000?0goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`07Ool00`00Oomoo`0<Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01P0?Oomoo`00Ool03`=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol027oo00<007ooOol02goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00H03gooOol007oo00l3Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo00Qoo`03001oogoo00]oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moo`00009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol02Goo00<007ooOol02Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03`00Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`09Ool00`00Oomoo`0:Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?001oo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo00Yoo`03001oogoo00Uoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`03001oogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol02Woo00<007ooOol02Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<007ooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`80000300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0;Ool00`00Oomoo`08Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool01P0?Oomoogoo00003`Aoo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol02goo00<007ooOol027oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00H03gooOomoo`0000l4Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo00aoo`03001oogoo00Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0600moogoo001oo`0?17oo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0<Ool00`00Oomoo`07Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool01P0?Oomoo`00Ool03`Aoo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
3Goo00<007ooOol01Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03goo00000Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0>Ool00`00Oomoo`05Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Ool00002Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`00:Goo1`000goo10001Goo10001goo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo00ioo`03001oogoo00Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300l007oo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo000/Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo00moo`03001oogoo00Aoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`03001oogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo000/Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo00moo`03001oogoo00Aoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`03001oogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo000/Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo0000
17oo00<007ooOol017oo0`00HP0?00<0000?00l0:00?00<0000?00l0/`0?00<007ooOol087oo000/
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo011oo`03001oogoo00=oo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo009oo`0300003goo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000/Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo015oo`03001oogoo009oo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0700moogooOol007oo00l017oo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol002aoo`03001oogoo00=oo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol04Woo00D007ooOomoo`0?00eoo`0300moogoo00Moo`03
00moogoo00Eoo`0700moogooOol007oo00l017oo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol002Yoo`<000Eoo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool04goo00@007ooOol03`eoo`0300moogoo00Moo`0300moogoo00Eoo`0400moogoo0002Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029o
o`00;7oo00<007ooOol017oo10001Goo10001goo00<007oo00l05goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01=oo`04001oogoo00l=Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Ool00003Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Aoo`03001oo`0?00eoo`0300moogoo00Moo`0300moogoo00Eoo`0300l007oo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Goo00<0000?Ool037oo00<03gooOol01goo00<03gooOol01Goo00<007ooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Mo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`00Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0000moo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo0P0000<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03001oogoo00]oo`03
00moogoo00Moo`0300moogoo00Aoo`0300003goo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03`00Ool02goo00<03gooOol01goo
00<03gooOol00goo00<007oo00l01Goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Ool0000;Ool00`0?Oomoo`07Ool00`0?Oomoo`02
Ool01000Oomoo`0?1Goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol0100?Oomoo`002Woo00<03gooOol01goo00D03gooOomoo`0000=oo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00D03gooOomoo`0000Uoo`0300moogoo00Moo`0400moogoo0004Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo009oo`03001oogoo00Ioo`0300moogoo00Moo`0300moo`0000Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol00goo0P001Woo00<03gooOol01goo00<03`00Ool01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`05Ool20004Ool00`0?Oomoo`07Ool00`00Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00Moo`80009oo`0300moogoo00=oo`@0000300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool3000GOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00<007ooOol05Woo00<007oo
Ool02Goo200017oo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo
00D007ooOomoo`0000=oo`03001oogoo01Eoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo
00Eoo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol00003Ool01@00Oomoogoo00005goo
00<007ooOol02goo00<007ooOol027oo00<007ooOol017oo00<007ooOol017oo00<007ooOol00Woo
00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo000ROol004Moo`03001oo`0001Moo`03
001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`0FOol00`00Oomoo`0;Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007oo
Ool00goo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol0000GOol00`00Oomoo`0;
Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool01@00Oomoogoo00000Woo00@007ooOol0029oo`00Agooo`00B0008Woo003oOonaOol00?mook5o
o`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003D
Ool50004Ool30002Ool30003Ool50003Ool50005Ool4002bOol00=Eoo`03001oogoo00Ioo`03001o
ogoo009oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000
17oo00<007ooOol0[goo003EOol00`00Oomoo`06Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo
00<007ooOol01goo00D007ooOomoo`000;Ioo`00eGoo1@0017oo00<007ooOol00Woo00<007ooOol0
0Woo10001Goo100017oo1P00/Goo003EOol00`00Oomoo`02Ool01000Oomoogoo0P000goo00D007oo
Oomoo`0000=oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`2_
Ool00=Eoo`03001oogoo009oo`06001oogooOol007oo0`001Goo0`001Woo1@0017oo1000/Woo003E
Ool00`00Oomoo`02Ool01@00Oomoogoo0000dGoo003DOol60004Ool00`00Oomoo`3?Ool00=eoo`80
0=5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.91386, -25.4019, \
0.0186604, 0.841437}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dewhitening", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Vout/Vin /. sol\) /. {Z1 \[Rule] R, Z2 \[Rule] R, 
          Z3 \[Rule] ser[1\/\(s\ C\), R2], Z4 \[Rule] ser[1\/\(s\ C\), R2], 
          G \[Rule] 1} // Simplify\), "\[IndentingNewLine]", 
    \(\(% /. {R \[Rule] 1, C \[Rule] 1/\((2  \[Pi])\), 
          R2 \[Rule] 0.1};\)\), "\[IndentingNewLine]", 
    \(getZPK[%]\), "\[IndentingNewLine]", 
    \(\(%% /. {s \[Rule] 
            2\ \[Pi]\ \[ImaginaryI]\ f};\)\), "\[IndentingNewLine]", 
    \(\(BodePlot[%, {f, 0.01, 100}];\)\)}], "Input"],

Cell[BoxData[
    \(\((1 + C\ R2\ s)\)\^2\/\((1 + C\ \((R + R2)\)\ s)\)\^2\)], "Output"],

Cell[BoxData[
    InterpretationBox[\("K(f=0) = "\[InvisibleSpace]1\[InvisibleSpace]" ("\
\[InvisibleSpace]1.`\[InvisibleSpace]")"\),
      SequenceForm[ "K(f=0) = ", 1, " (", 1.0, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("K(f=\[Infinity]) = \
"\[InvisibleSpace]0.008264462809917356`\[InvisibleSpace]" \
("\[InvisibleSpace]0.008264462809917356`\[InvisibleSpace]")"\),
      SequenceForm[ 
      "K(f=\[Infinity]) = ", .0082644628099173556, " (", .0082644628099173556,
         ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Poles at = \
"\[InvisibleSpace]\(-0.9090909090909091`\)\[InvisibleSpace]" and "\
\[InvisibleSpace]\(-0.9090909090909091`\)\[InvisibleSpace]" "\),
      SequenceForm[ 
      "Poles at = ", -.90909090909090906, " and ", -.90909090909090906, " "],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole frequency = \
"\[InvisibleSpace]0.9090909090909091`\[InvisibleSpace]" \
("\[InvisibleSpace]0.9090909090909091`\[InvisibleSpace]")"\),
      SequenceForm[ 
      "Pole frequency = ", .90909090909090906, " (", .90909090909090906, ")"],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole Q = "\[InvisibleSpace]0.5000000000000001`\
\[InvisibleSpace]" ("\[InvisibleSpace]0.5000000000000001`\[InvisibleSpace]")"\
\),
      SequenceForm[ 
      "Pole Q = ", .50000000000000011, " (", .50000000000000011, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Zero frequency = "\[InvisibleSpace]10.`\
\[InvisibleSpace]" ("\[InvisibleSpace]10.`\[InvisibleSpace]")"\),
      SequenceForm[ "Zero frequency = ", .1*^2, " (", .1*^2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Zero Q = "\[InvisibleSpace]0.5`\[InvisibleSpace]" ("\
\[InvisibleSpace]0.5`\[InvisibleSpace]")"\),
      SequenceForm[ "Zero Q = ", .5, " (", .5, ")"],
      Editable->False]], "Print"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.246914 0.615522 0.0147709 [
[.00617 -0.0125 -14 -12.5625 ]
[.00617 -0.0125 14 0 ]
[.25309 -0.0125 -11 -12.5625 ]
[.25309 -0.0125 11 0 ]
[.5 -0.0125 -5 -12.5625 ]
[.5 -0.0125 5 0 ]
[.74691 -0.0125 -8 -12.5625 ]
[.74691 -0.0125 8 0 ]
[.99383 -0.0125 -11 -12.5625 ]
[.99383 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -8 -25.125 ]
[.5 -0.0125 8 -12.5625 ]
[-0.0125 .02469 -18 -4.5 ]
[-0.0125 .02469 0 4.5 ]
[-0.0125 .17239 -18 -4.5 ]
[-0.0125 .17239 0 4.5 ]
[-0.0125 .3201 -18 -4.5 ]
[-0.0125 .3201 0 4.5 ]
[-0.0125 .46781 -18 -4.5 ]
[-0.0125 .46781 0 4.5 ]
[-0.0125 .61552 -6 -4.5 ]
[-0.0125 .61552 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -8 ]
[-0.01875 .30902 -18 8 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12.5625 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .17239 m
1 .17239 L
s
0 .3201 m
1 .3201 L
s
0 .46781 m
1 .46781 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -69 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02469 m
.00625 .02469 L
s
[(-40)] -0.0125 .02469 1 0 Mshowa
0 .17239 m
.00625 .17239 L
s
[(-30)] -0.0125 .17239 1 0 Mshowa
0 .3201 m
.00625 .3201 L
s
[(-20)] -0.0125 .3201 1 0 Mshowa
0 .46781 m
.00625 .46781 L
s
[(-10)] -0.0125 .46781 1 0 Mshowa
0 .61552 m
.00625 .61552 L
s
[(0)] -0.0125 .61552 1 0 Mshowa
.125 Mabswid
0 .05423 m
.00375 .05423 L
s
0 .08377 m
.00375 .08377 L
s
0 .11331 m
.00375 .11331 L
s
0 .14285 m
.00375 .14285 L
s
0 .20194 m
.00375 .20194 L
s
0 .23148 m
.00375 .23148 L
s
0 .26102 m
.00375 .26102 L
s
0 .29056 m
.00375 .29056 L
s
0 .34965 m
.00375 .34965 L
s
0 .37919 m
.00375 .37919 L
s
0 .40873 m
.00375 .40873 L
s
0 .43827 m
.00375 .43827 L
s
0 .49736 m
.00375 .49736 L
s
0 .5269 m
.00375 .5269 L
s
0 .55644 m
.00375 .55644 L
s
0 .58598 m
.00375 .58598 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -93.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 10.2813 translate
90 rotate
-69 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dB) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Magnitude) show
117.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .61551 m
.02372 .6155 L
.03955 .61549 L
.05352 .61549 L
.06699 .61547 L
.07854 .61546 L
.08806 .61545 L
.10505 .61543 L
.12005 .61539 L
.13273 .61536 L
.14475 .61532 L
.15518 .61527 L
.16433 .61523 L
.17329 .61518 L
.18125 .61512 L
.18912 .61506 L
.19619 .61499 L
.20257 .61492 L
.20897 .61485 L
.2148 .61477 L
.22066 .61468 L
.22601 .6146 L
.23093 .61451 L
.23592 .61441 L
.24051 .61431 L
.24476 .61421 L
.24909 .6141 L
.25309 .61399 L
s
.25309 .61399 m
.27063 .6134 L
.28646 .61269 L
.30044 .61185 L
.31391 .61082 L
.33497 .60862 L
.35197 .60614 L
.36749 .60315 L
.38058 .59993 L
.39182 .59655 L
.40262 .59268 L
.41208 .58872 L
.42045 .5847 L
.42869 .58024 L
.43607 .57578 L
.4434 .57089 L
.45001 .56605 L
.45601 .5613 L
.46205 .55616 L
.46755 .55115 L
.47311 .54577 L
.4782 .54055 L
.48288 .53551 L
.48765 .53013 L
.49205 .52495 L
.49612 .51998 L
.5 .51506 L
s
.5 .51506 m
.53337 .46648 L
.56082 .41922 L
.58144 .38057 L
.59812 .34806 L
.61342 .3177 L
.62633 .29197 L
.63854 .26776 L
.64912 .24704 L
.65839 .22916 L
.66745 .21205 L
.67551 .1972 L
.68272 .18423 L
.68991 .17167 L
.69639 .16066 L
.70288 .14998 L
.70878 .14058 L
.71417 .13229 L
.71962 .12418 L
.72461 .117 L
.72968 .10997 L
.73435 .10374 L
.73865 .09819 L
.74305 .09273 L
.74691 .0881 L
s
.74691 .0881 m
.76446 .06912 L
.78029 .05478 L
.80773 .03567 L
.82764 .02571 L
.84542 .01902 L
.86013 .01476 L
.87383 .01163 L
.88555 .00947 L
.89574 .00792 L
.90561 .00666 L
.91432 .00571 L
.92208 .00499 L
.92977 .00436 L
.93668 .00387 L
.94357 .00344 L
.94982 .00309 L
.9555 .0028 L
.96123 .00254 L
.96647 .00233 L
.97178 .00213 L
.97665 .00197 L
.98114 .00183 L
.98572 .0017 L
.98995 .00159 L
.99383 .0015 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00hWoo0`000Woo0`000Woo1P00_Woo003S
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000_Woo003SOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`2oOol00>=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
0;ioo`00hgoo1P000goo00D007ooOomoo`000;moo`00hgoo00<007ooOol00Woo00@007ooOomoo`H0
0;ioo`00hgoo00<007ooOol00Woo00<007ooOol0aGoo003ROol30002Ool30036Ool00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo000iOol40006Ool20006Ool40004Ool7000dOol40006Ool20005Ool7
0010Ool70015Ool70003Ool4000nOol70003Ool40005Ool4000KOol003Qoo`03001oogoo009oo`03
001oogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo
009oo`03001oogoo00=oo`8000Qoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03001o
ogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo
00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo
00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qo
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Ao
o`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03
001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001o
ogoo00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol0
03Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo009oo`<003Ioo`03
001oogoo009oo`03001oogoo00]oo`<004Aoo`<004Uoo`<000Eoo`03001oogoo009oo`03001oogoo
03aoo`<000Eoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Uoo`@000io
o`@000Moo`03001oogoo03Eoo`@0011oo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00Ao
o`@0045oo`03001oogoo00Aoo`@000Eoo`@001]oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo0017Oooo0018000ROol004Moo`03001oo`0001Moo`03
001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`0FOol00`00Oomoo`0;Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007oo
Ool00goo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol0000GOol00`00Oomoo`0;
Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0?0002Ool00`00Oomo
o`0POol004Moo`03001oo`0001Moo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`0F
Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<007ooOol02goo00<007oo
Ool01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000=oo`05
001oogooOol0000GOol00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`02Ool<0002Ool00`00
Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0029oo`00Agoo00<007oo00l05goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00=oo`X0009oo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo00000`001Goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0400moogoo000ROol003Aoo`@000Aoo`@000Moo`03001oo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`09Ool40009Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`00=Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00Moo`80009oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000fOol00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol017oo0`0017oo00<03gooOol027oo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0400moogoo000ROol0039oo`H000=oo`03001oogoo009oo`03001oogoo00Aoo`<001Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0100?Oomoogoo0`00
1goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol002Uoo`H000Aoo`04001oogoo0004Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00@03goo000000Yoo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo000cOol01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`8000aoo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo000dOol00`00Ool00004Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05Goo0P0000<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol003Ao
o`03001oo`0000Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0COol20002Ool00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=Goo0P001Goo10001goo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?015oo`8000Aoo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l047oo00<007ooOol017oo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0>Ool20007Ool00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00eoo`03001oogoo00Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l02goo0P002Woo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`80000300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0:Ool00`00Oomoo`0:Ool00`0?
Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00Uoo`03001oogoo00]oo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l027oo00<007ooOol037oo
00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`07Ool00`00Oomoo`0=
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00Ioo`03001oogoo
00ioo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l01Goo00<007oo
Ool03goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`04Ool00`00
Oomoo`0@Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00=oo`03
001oogoo015oo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l00Woo
00<007ooOol04Woo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo
00005Goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`80000300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogooOol03`005Woo
00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0000GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOol0000?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoo`0000l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500l00000Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029o
o`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D007oo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@00Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?009oo`0300003goo009oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`02Ool00`0000moo`02Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo0P0000<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool02@0?Oomoogoo00moo`00Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01P0?Oomoogoo00l0009oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00000goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool00003Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo
000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOol0000?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Ool007oo00l00goo00D03gooOomoo`0?
01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500l007ooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03`00Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@00Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05001oogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo
000ROol004Moo`80000300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0000?Ool00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300003goo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01`0?Oomoogoo001oo`0?00=oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool0100?Oomoo`000Woo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool0100?Oomoo`000Woo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Ool00003Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo000cOol40005Ool40007Ool00`00Ool03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moo`0000=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0039oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300l007oo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool003Moo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300l0
07oo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol003Moo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`03001oogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol002Uoo`H000Ioo`8000Aoo`03001o
ogoo009oo`03001oogoo00Aoo`<00=d03`0300003`0?06<03`03001oogoo021oo`00=goo00D007oo
Oomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00L03gooOomoo`00Ool03`05Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo000gOol01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool01`0?Oomoogoo001oo`0?
00Eoo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol0039oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04
Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0400moogoo0002Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000cOol40005Ool4
0007Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0400moogoo0002Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moo`0000=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
00000goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?001oo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300l007oo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`80000300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<007ooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0000moo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool0
0`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300003goo00Aoo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol00goo00<0
07oo00l01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`02Ool01000Oomoo`0?1Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`02Ool01000Oomoo`0?1Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool01@0?Oomoogoo00000goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool01@0?Oomoogoo00000goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool0100?Oomoo`0017oo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0100?
Oomoo`0017oo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo0P0000<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Ool00005
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moo`0000Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03`00Ool01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?001oo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`03001oogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<007ooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`00Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Ioo`0300003goo00Ioo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01Woo00<0000?Ool01Woo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo0P0000<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`00Ool03`07Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Eoo`03001oo`0?00Moo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
17oo00@007ooOol03`Moo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol017oo00@007oo
Ool03`Moo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol00goo00D007ooOomoo`0?00Mo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol00goo00D007ooOomoo`0?00Moo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol00Woo00<007ooOol00Woo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`02Ool00`00Oomoo`02Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0500moogooOol00005Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo000KOol4000XOol00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0500moogooOol00005Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo000JOol00`00Oomoo`02Ool00`00Oomoo`0UOol2
00000`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0400moogoo0006Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000JOol00`00Oomo
o`02Ool00`00Oomoo`0UOol00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0400moogoo0006Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo000JOol00`00Oomoo`02Ool00`00Oomoo`0UOol00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moo`0000Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol001Moo`04001oogoo0003Ool00`00Oomoo`0VOol00`00Ool03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moo`0000Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol001Moo`T002Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03`00Ool01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`007goo00<007ooOol09Goo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?001oo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo000bOol60004Ool40007Ool00`00Ool03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03001oogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0039oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`03001oogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool001Qoo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo00Eoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02Woo00<0000?Ool0
27oo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`0067oo2000
57oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0:Ool00`0000moo`08Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo000HOol01000Oomoo`000goo00<007ooOol01goo1P001Woo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol017oo0`00a00?00<0000?00l0O00?00<007oo
Ool087oo000HOol01000Oomoo`000goo00<007ooOol057oo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`09Ool00`00
Ool03`09Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000H
Ool01000Oomoo`000goo00<007ooOol047oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001o
ogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol027oo00@007ooOol0
3`Uoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol001Qoo`04
001oogoo0003Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0
17oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`08Ool01000Oomoo`0?2Goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`006Goo0P0000Ao
o`00000001Aoo`@000Eoo`@000Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool01goo00D007ooOomoo`0?00Uoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol01goo
00D007ooOomoo`0?00Uoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo
000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol01Woo00<007oo
Ool00Woo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`06Ool00`00
Oomoo`02Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00Eoo`03
001oogoo00=oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`80000300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
1Goo00<007ooOol00goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`04Ool00`00Oomoo`04Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00Aoo`03001oogoo00Aoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol00goo00<007ooOol01Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`03Ool00`00Oomoo`05Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo009oo`03001oogoo00Ioo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00D03gooOomoo`0000Uoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00D0
3gooOomoo`0000Uoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00@03gooOol0
00Yoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo
000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00@03gooOol000Yoo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Mo
o`80000300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo00002goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Ool0000;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300l007oo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03`00Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`00
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03001oogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol057oo00<0000?Ool037oo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0DOol00`0000moo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01=oo`03001oo`0?00eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`80000300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol04goo00<007oo00l03Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0BOol0
1000Oomoo`0?3Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0BOol01000Oomoo`0?
3Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0AOol01@00Oomoogoo00l03Goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0AOol01@00Oomoogoo00l03Goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<0
07oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0@Ool00`00Oomoo`02Ool00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool0
0`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo011oo`03001oogoo009oo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Mo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol03goo00<007ooOol00goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0?Ool00`00Oomoo`03Ool00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo
0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00ioo`03001oogoo00Aoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool004Moo`80000300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol03Goo00<007ooOol01Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0=Ool00`00Oomoo`05Ool00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00aoo`03001oogoo00Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol037oo00<007ooOol01Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0;Ool00`00Oomoo`07
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Yoo`03001oogoo
00Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol0039oo`L000=oo`@000Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool02Woo00<007ooOol027oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=Goo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`09Ool00`00Oomoo`09Ool00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo000eOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo00Uoo`03001oogoo00Uoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol003Eoo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol027oo
00<007ooOol02Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00:Goo1P001Woo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol017oo0`00ZP0?00<0000?00l0UP0?00<007ooOol087oo000eOol00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Moo`03001o
ogoo00]oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol003Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Ao
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol01Woo00<007ooOol037oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
<goo0`001Goo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`05Ool00`00Oomoo`0=Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo000eOol00`00Oomoo`04Ool40007Ool00`00Ool0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo00Eoo`03001oogoo00eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001o
o`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol017oo00<007ooOol03Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<0
07oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`03Ool00`00Oomoo`0?Ool00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool0
0`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo009oo`03001oogoo011oo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Mo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol00Woo00<007ooOol047oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo0P0000<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00004goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0057oo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0057oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Ool0000EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300l007oo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03`00Ool05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`00Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017
Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300003goo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool02@0?
Oomoogoo00moo`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00H03gooOomoo`0?0002Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo0017Ool200000`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0000=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00000goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogoo00003`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017
Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03goo001oo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
001oogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05001oogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00H03gooOomoo`0000l3Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0600moogoo001oo`0?0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Ool00002
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`8000=oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo0017Ool200000`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00H03gooOomoo`0000l4Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`06
00moogoo001oo`0?17oo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Mo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Ool00002Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300l007oo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00Woo0P0017oo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool01`0?Oomo
ogoo001oo`0?00Aoo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00@03gooOol0009oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017
Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03`0000000goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool20005Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo0P0000<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo009oo`800003Ool03goo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo00000P00
0goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool20006Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Eoo`80000300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017
Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol00goo0P000Woo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Ool000030004Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00?7oo10001goo00<0
07oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00Qo
o`D000Qoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000kOol00`00Oomoo`02Ool00`00Oomo
o`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<0
3gooOol00goo1@000goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol003]o
o`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0@Ool<0008Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00>goo00<007ooOol00Woo00<007ooOol017oo00<007oo00005goo00<007ooOol02goo00<0
07ooOol01goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00Woo00<007oo000070001Woo
00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo01Eoo`03001oogoo00]oo`03001oogoo
00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol00003Ool01@00
Oomoogoo00005goo00<007ooOol02goo00<007ooOol027oo00<007ooOol017oo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo000ROol003]oo`03
001oogoo009oo`03001oogoo00AoodP000=oo`05001oogooOol00002Ool00`00Oomoo`0FOol00`00
Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol01goo
00<007ooOol01Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogoo
Ool0000GOol00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0029oo`00>goo00<007oo
Ool00Woo00<007ooOol017ooo`00B0008Woo000kOol00`00Oomoo`02Ool00`00Oomoo`3oOom^Ool0
03]oo`03001oogoo009oo`03001oogoo0?moofioo`00?7oo1000ogooLGoo003oOonaOol00?mook5o
o`00ogoo/Goo003EOol4003GOol00=Uoo`03001oogoo0=Aoo`00fGoo00<007ooOol0e7oo0031Ool3
0003Ool30003Ool50003Ool300000goo001oo`02Ool30002Ool300000goo000000050005Ool40004
Ool300000goo00000002Ool300000goo00000004Ool4002POol00<9oo`03001oogoo00=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo0P0017oo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol01Goo00<007ooOol00Woo00@007ooOol000=oo`80009oo`04001oogooOol20004Ool00`00
Oomoo`02Ool00`00Oomoo`2MOol00<9oo`04001oogoo0002Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`2ROol0
0<9oo`07001oo`00Ool007oo000017oo10000goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol00Woo00@007oo
Ool000Aoo`03001oogoo009oo`H009moo`00`Woo00L007oo001oo`00Ool00003Ool01@00Oomoogoo
00000goo00@007ooOomoo`8000Aoo`8000=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo009oo`04001oogoo0003Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`2MOol0
0<9oo`07001oo`00Ool007oo000017oo0`001Goo0`0000=oo`0000000Woo0P0000Aoo`00000000Ao
o`<000Eoo`L0009oo`8000=oo`8000=oo`<00003Ool007oo00Aoo`@00:1oo`00`Woo0P000goo0P00
:7oo00<007ooOol04Woo00<007ooOol0Ygoo0031Ool30003Ool3000WOol00`00Oomoo`0BOol00`00
Oomoo`2WOol00>Uoo`03001oogoo01Uoo`800:Uoo`00jGoo00<007ooOol0a7oo003oOonaOol00?mo
ok5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.91386, -50.355, \
0.0186604, 0.311932}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.246914 0.606824 0.00533625 [
[.00617 -0.0125 -14 -12.5625 ]
[.00617 -0.0125 14 0 ]
[.25309 -0.0125 -11 -12.5625 ]
[.25309 -0.0125 11 0 ]
[.5 -0.0125 -5 -12.5625 ]
[.5 -0.0125 5 0 ]
[.74691 -0.0125 -8 -12.5625 ]
[.74691 -0.0125 8 0 ]
[.99383 -0.0125 -11 -12.5625 ]
[.99383 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -8 -25.125 ]
[.5 -0.0125 8 -12.5625 ]
[-0.0125 .0732 -24 -4.5 ]
[-0.0125 .0732 0 4.5 ]
[-0.0125 .17992 -18 -4.5 ]
[-0.0125 .17992 0 4.5 ]
[-0.0125 .28665 -18 -4.5 ]
[-0.0125 .28665 0 4.5 ]
[-0.0125 .39337 -18 -4.5 ]
[-0.0125 .39337 0 4.5 ]
[-0.0125 .5001 -18 -4.5 ]
[-0.0125 .5001 0 4.5 ]
[-0.0125 .60682 -6 -4.5 ]
[-0.0125 .60682 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -20 ]
[-0.01875 .30902 -24 20 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12.5625 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .0732 m
1 .0732 L
s
0 .17992 m
1 .17992 L
s
0 .28665 m
1 .28665 L
s
0 .39337 m
1 .39337 L
s
0 .5001 m
1 .5001 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -69 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0732 m
.00625 .0732 L
s
[(-100)] -0.0125 .0732 1 0 Mshowa
0 .17992 m
.00625 .17992 L
s
[(-80)] -0.0125 .17992 1 0 Mshowa
0 .28665 m
.00625 .28665 L
s
[(-60)] -0.0125 .28665 1 0 Mshowa
0 .39337 m
.00625 .39337 L
s
[(-40)] -0.0125 .39337 1 0 Mshowa
0 .5001 m
.00625 .5001 L
s
[(-20)] -0.0125 .5001 1 0 Mshowa
0 .60682 m
.00625 .60682 L
s
[(0)] -0.0125 .60682 1 0 Mshowa
.125 Mabswid
0 .09988 m
.00375 .09988 L
s
0 .12656 m
.00375 .12656 L
s
0 .15324 m
.00375 .15324 L
s
0 .2066 m
.00375 .2066 L
s
0 .23329 m
.00375 .23329 L
s
0 .25997 m
.00375 .25997 L
s
0 .31333 m
.00375 .31333 L
s
0 .34001 m
.00375 .34001 L
s
0 .36669 m
.00375 .36669 L
s
0 .42005 m
.00375 .42005 L
s
0 .44674 m
.00375 .44674 L
s
0 .47342 m
.00375 .47342 L
s
0 .52678 m
.00375 .52678 L
s
0 .55346 m
.00375 .55346 L
s
0 .58014 m
.00375 .58014 L
s
0 .04652 m
.00375 .04652 L
s
0 .01984 m
.00375 .01984 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -111.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
81 10.2813 translate
90 rotate
-81 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(degree) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 .54442 m
1 .54442 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phase) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .60071 m
.03955 .59848 L
.06699 .59604 L
.08762 .59376 L
.1043 .59156 L
.11959 .58922 L
.1325 .58697 L
.14471 .58458 L
.15529 .58228 L
.16457 .58006 L
.17363 .57771 L
.18168 .57544 L
.1889 .57326 L
.19608 .57094 L
.20256 .56871 L
.20906 .56635 L
.21496 .56407 L
.22034 .56187 L
.22579 .55954 L
.23079 .5573 L
.23585 .55492 L
.24052 .55263 L
.24482 .55042 L
.24922 .54808 L
.25309 .54594 L
s
.25309 .54594 m
.28646 .52403 L
.31391 .50045 L
.33453 .4787 L
.35121 .45818 L
.3665 .43684 L
.37942 .41684 L
.39162 .3962 L
.4022 .37694 L
.41148 .35903 L
.42054 .34066 L
.4286 .32364 L
.43581 .3079 L
.44299 .29181 L
.44948 .27698 L
.45597 .2619 L
.46187 .24803 L
.46726 .23529 L
.4727 .22235 L
.4777 .21049 L
.48277 .19849 L
.48743 .1875 L
.49174 .17743 L
.49613 .16726 L
.5 .15841 L
s
.5 .15841 m
.53337 .08851 L
.54735 .06412 L
.56082 .04411 L
.57211 .03027 L
.58144 .02098 L
.59035 .014 L
.59499 .0111 L
.59911 .00896 L
.60272 .00743 L
.60655 .00614 L
.61027 .00524 L
.61225 .00489 L
.6132 .00476 L
.61408 .00466 L
.61498 .00458 L
.6158 .00452 L
.61623 .00449 L
.6167 .00447 L
.61695 .00446 L
.61719 .00446 L
.61741 .00445 L
.61765 .00444 L
.61805 .00444 L
.61842 .00444 L
.61886 .00444 L
.61926 .00445 L
.61967 .00446 L
.62012 .00448 L
.62093 .00452 L
.62166 .00457 L
.62245 .00465 L
.62404 .00484 L
.6255 .00507 L
.62684 .00532 L
.62985 .00606 L
.63293 .00704 L
.63823 .00927 L
.6436 .01222 L
.64837 .01542 L
.65786 .02338 L
.6671 .03311 L
.67531 .04335 L
.68265 .05372 L
.68994 .06509 L
.69653 .07623 L
.7025 .087 L
.70852 .09843 L
.714 .10934 L
.71954 .12078 L
Mistroke
.72462 .1316 L
.72929 .1418 L
.73404 .15241 L
.73843 .16237 L
.7429 .17266 L
.74691 .182 L
Mfstroke
.74691 .182 m
.78029 .26088 L
.80773 .32286 L
.82836 .36521 L
.84504 .39614 L
.86033 .42174 L
.87324 .44131 L
.88545 .45814 L
.89603 .47147 L
.90531 .48226 L
.91437 .49203 L
.92242 .5001 L
.92964 .50688 L
.93682 .51321 L
.9433 .5186 L
.9498 .5237 L
.9557 .52808 L
.96108 .53189 L
.96653 .53555 L
.97153 .53876 L
.97659 .54187 L
.98126 .54461 L
.98556 .54704 L
.98996 .54942 L
.99383 .55144 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00iWoo0`000Woo0`000Woo1P00^Woo003W
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000^Woo003WOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`2kOol00>Moo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
0;Yoo`00igoo1P000goo00D007ooOomoo`000;]oo`00igoo00<007ooOol00Woo00@007ooOomoo`H0
0;Yoo`00igoo00<007ooOol00Woo00<007ooOol0`Goo003VOol30002Ool30032Ool00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo000nOol40006Ool20006Ool40004Ool7000cOol40006Ool20005Ool7
0011Ool70015Ool70003Ool4000mOol70003Ool40005Ool4000GOol003eoo`03001oogoo009oo`03
001oogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=oo`03001oogoo
009oo`03001oogoo00=oo`8000Qoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Eoo`03001o
ogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001oogoo
00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001oogoo
00eoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003eo
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=o
o`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Eoo`03
001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001o
ogoo00eoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol0
03eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo009oo`<003Eoo`03
001oogoo009oo`03001oogoo00]oo`<004Eoo`<004Uoo`<000Eoo`03001oogoo009oo`03001oogoo
03]oo`<000Eoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003ioo`@000io
o`@000Moo`03001oogoo03Aoo`@0011oo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00Ao
o`@0041oo`03001oogoo00Aoo`@000Eoo`@001Moo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo001;Oooo0018000NOol004]oo`03001oo`0001Qoo`03
001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo000017oo00@007oo
Ool001Moo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool0
0`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo0000
0goo00L007ooOomoo`00Ool0000NOol004]oo`03001oo`0001Qoo`03001oogoo00]oo`03001oogoo
00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`05001oogoo
Ool00003Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo000017oo00@007ooOol001Moo`03001oogoo00Qo
o`T000Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001o
ogooOol00003Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool0
0`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00L007ooOomoo`00Ool0000NOol0
04]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00Eoo`<000Aoo`0300moogoo009oo`8000=o
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03aMoo`0300moogoo00Aoo`03001oogoo00Eoo`0300moogoo00Aoo`800003
Ool03goo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001o
o`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
17oo00@03gooOol03aMoo`0300moogoo00=oo`03001oogoo00Ioo`0300moogoo00Ioo`8000Ioo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3aMoo`0400moogooOol20009Ool00`0?Oomoo`07Ool00`0?001oo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol0100?Oomoo`002goo00<0
3gooOol01goo00<03goo000017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001io
o`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`04Ool0100?Oomoo`0?5goo00<03goo000037oo00<03gooOol01goo00@03gooOol0
00=oo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@0
3gooOol03aMoo`0300l007oo00aoo`0300moogoo00Moo`0500moogooOol00002Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`00
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`02Ool00`00Ool03`06Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogoo
Ool03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lFOol00`0000moo`0=Ool00`0?Oomoo`07
Ool00`0?Oomoo`03Ool00`0000moo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00Aoo`0400moogoo00lEOol00`00Ool03`0>Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`00
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lE
Ool00`00Ool03`0>Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`00Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`07
00moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lDOol01000Oomoo`0?3Woo00<0
3gooOol01goo00<03gooOol017oo00<03`00Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001io
o`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`04Ool0100?Oomoo`0?4goo00D007ooOomoo`0?00ioo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moo`0000Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03a9oo`03001oogoo009oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
o`0000Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03a9o
o`03001oogoo009oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0400moogoo0003
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lAOol00`00
Oomoo`03Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool01@0?Oomoogoo00000Woo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?47oo00<007oo
Ool017oo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00D03gooOomoo`00009oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03a1oo`03001oogoo
00Aoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo009oo`03001oo`0?
00Aoo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00L03gooOomoo`0?Ool0000NOol002eoo`L000=oo`@000Eoo`@000Moo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3`moo`03001oogoo00Eoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
009oo`03001oo`0?00Aoo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0031oo`03001oogoo00=oo`03001oogoo009o
o`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00l>Ool00`00Oomoo`06
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0000moo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`07
00moogooOol03goo00007Woo000`Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo0000
17oo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?3Woo00<007ooOol01Woo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<007ooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`00
01ioo`00<7oo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Ao
o`<00:h03`0300003`0?02h03`0300003`0?06403`03001oogoo01aoo`0097oo1P001Woo00<007oo
Ool00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?01Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03`aoo`03001oogoo00Qoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300l007oo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0031oo`03001oogoo00=oo`03001oogoo
009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00l<Ool00`00Oomo
o`08Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?001o
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo000`Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo
000017oo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?2goo00<007ooOol02Goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo00000Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00mo
o`0001ioo`00;Woo0`001Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03`]oo`03001oogoo00Uoo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moo`00009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0031oo`03001oogoo
00Aoo`@000Eoo`@000Moo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`Yoo`03001oogoo00Yoo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0600moogoo001oo`0?17oo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00
Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`04Ool0100?Oomoo`0?2Woo00<007ooOol02Woo00<03gooOol037oo00<03gooOol01goo
00<03gooOol017oo00<03gooOol017oo00H03gooOomoo`0000l4Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`04
00moogoo00l9Ool00`00Oomoo`0;Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool01P0?Oomoogoo00003`Aoo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`Uoo`03
001oogoo00]oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`03001oogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`Qoo`03001oogoo00aoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
001oogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`Qoo`03001oogoo00aoo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300l007oo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`Moo`03001oogoo00eoo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300l007oo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03`Moo`03001oogoo00eoo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moo`00009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]o
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03`Ioo`03001oogoo00ioo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moo`00009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001o
o`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
17oo00@03gooOol03`Ioo`03001oogoo00ioo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0600moogoo001oo`0?0goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?
1Goo00<007ooOol03goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00H03gooOol007oo00l3Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00l5Ool00`00Oomoo`0?
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool01P0?Oomoogoo00003`=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomo
o`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`Aoo`03001oogoo011oo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0600moogooOol0
000?0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00
Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`04Ool0100?Oomoo`0?17oo00<007ooOol047oo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D007ooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l0
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0
100?Oomoo`0?0goo00<007ooOol04Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D007ooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomo
o`0?0goo00<007ooOol04Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D007ooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?0Woo
00<007ooOol04Woo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03`00Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?0Woo00<007oo
Ool04Woo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03`00Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool01P0?Oomoo`0?Ool001Eoo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moo`00Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l017oo00H03gooOol03goo000EOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Ool007oo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00Aoo`0500moogoo00l0000FOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoo`0000l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogoo00l0000F
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoo`0000l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`07
00moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo000GOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00000goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00Aoo`0400moogoo000GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00000goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400mo
ogoo000GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01P0?Oomoogoo00l0009oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Ool0000?5goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00H03gooOomoo`0?0002Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol003Moo`@000Eoo`@000Moo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo00003aMoo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`06
00moogooOol03`000Woo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo0000
7Woo000fOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l067oo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?
Ool0000?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00T03gooOomoo`0?Ool007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo000fOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`04Ool0100?001oo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00T03gooOomoo`0?Ool007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000fOol00`00Oomoo`02Ool01@00
Oomoogoo000017oo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?001oo`0?5goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300003goo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001io
o`00;Goo1P0017oo100017oo00<007ooOol00Woo00<007ooOol017oo0`00W@0?00<0000?00l0D00?
00<0000?00l0D00?00<007ooOol077oo000fOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<0
07ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`04Ool01000Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
001oogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00=Woo00<007ooOol0
0Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0000?Oomoo`0?01Moo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`00Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomo
o`0?Ool0000NOol003Ioo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500003gooOol03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03`00Ool05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000gOol40005Ool40007Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?009o
o`03001oo`0?009oo`0300moogoo01Eoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?001o
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00<007oo
00l00Woo00<03gooOol05Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0001Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`02Ool00`00Ool03`02Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo00005Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00L03gooOomoo`0?Ool00002Ool0100?Oomoo`0?5goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0001Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomo
ogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0700moogooOol03goo00000Woo00@03gooOol03aMoo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0057oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
001;Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00H03gooOomo
o`0?0003Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo000D
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01P0?Oomoogoo00l000=oo`0400moogoo
00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0001=oo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol00004Ool0100?Oomoo`0?5goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0500moogooOol0000COol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomo
o`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo000017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00004goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Ool0000?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
0Woo00<007ooOol047oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOol0000?
00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol00Woo00<0
07ooOol047oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOol0000?00Aoo`04
00moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol00goo00<007ooOol0
3goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo001oo`0?00Aoo`0400moogoo
00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol00goo00<007ooOol03goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000GOol4000`Ool3000HOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03goo001oo`0?00Aoo`0400moogoo00lGOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol00goo00<007ooOol03goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Oomoo`02Ool00`00Oomoo`0]Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo001oo`0?
00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol017oo00<0
07ooOol03Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Oomoo`02
Ool00`00Oomoo`0]Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03`00Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol017oo00<007ooOol03Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo0000
7Woo000FOol00`00Oomoo`02Ool00`00Oomoo`0]Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03`00Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol01Goo00<007ooOol03Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo000COol01000Oomoo`000goo00<007ooOol0;Woo00<007oo00l0
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05001oogooOol03`04Ool0
100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Eoo`03001oogoo
00eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`004goo2@00;goo00<007oo00l0
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05001oogooOol03`04Ool0
100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Eoo`03001oogoo
00eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`006goo00<007ooOol0;Goo00<0
07oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05001oogooOol0
3`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Ioo`03
001oogoo00aoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l0
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300003goo009oo`0300mo
ogoo009oo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol01Woo
00<007ooOol037oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0000?Ool00Woo00<0
3gooOol00Woo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`07
Ool00`00Oomoo`0;Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01`0?Oomoogoo001oo`0?00=oo`0300moogoo009o
o`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol01goo00<007oo
Ool02goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000GOol4000`Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00L03gooOomoo`00Ool03`03Ool00`0?Oomo
o`02Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Moo`03
001oogoo00]oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`005Woo00<007oo0000
0Woo00<007ooOol0;Goo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0700mo
ogooOol007oo00l00goo00<03gooOol00Woo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`08Ool00`00Oomoo`0:Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol001Ioo`03001oo`00009oo`03001oogoo02eoo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool0100?Oomoo`000Woo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol027oo00<007ooOol02Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00Oomoo`0]Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00@03gooOol0009oo`0500moogooOol0
3`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Uoo`03
001oogoo00Uoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`005Woo00<007oo0000
0Woo00<007ooOol06Woo100017oo10001goo00<007oo00l067oo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moo`0000=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo00Uoo`03001oogoo00Uoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?
Oomoogoo00moo`0001ioo`005goo0P0000=oo`00Ool06goo00<007ooOol00Woo00@007ooOol000Ao
o`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Ool0
0003Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0:Ool00`00Oomoo`08Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool003Moo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03`00Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo
00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol02Woo00<007ooOol027oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000gOol20003Ool01000Oomoo`0017oo00<0
07ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300l007oo00=o
o`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo00]oo`03001oogoo00Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00
5goo10004Woo1P0017oo00<007oo00000P000goo00<007ooOol00Woo00<007ooOol017oo0`00SP0?
00<0000?00l0KP0?00<0000?00l0@@0?00<007ooOol077oo000FOol00`00Oomoo`02Ool01000Oomo
o`0067oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol017oo00<007oo00l067oo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`03001oogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?
5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00]oo`03001oogoo00Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`005Woo00<007ooOol00Woo00@007ooOol001Uo
o`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`02Ool00`0000moo`04Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0<Ool00`00Oomoo`06Ool00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001oogoo009oo`04001oogoo000JOol00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00Woo00<0000?Ool017oo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol037oo00<007ooOol01Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo000GOol01000Oomoo`000goo00<007ooOol06Goo0`000goo1000
1goo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0700moogooOol007oo00l01Goo00D03gooOomo
o`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol03Goo
00<007ooOol01Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol8000]Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00L03gooOomoo`00Ool03`05Ool01@0?Oomoogoo00l0
17oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0=Ool00`00
Oomoo`05Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001oogoo039o
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0100?Oomoo`000Woo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
3Woo00<007ooOol017oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00@03gooOol0009oo`0300moogoo00=oo`0500moogooOol0
3`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00ioo`03
001oogoo00Aoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0400moogoo0002Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0?Ool00`00Oomoo`03Ool0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Ool00003Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMo
o`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0?Ool00`00Oomoo`03Ool00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001oogoo009oo`03001oogoo02eoo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Ool00003Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0@Ool0
0`00Oomoo`02Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`H002moo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?001oo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0@Ool0
0`00Oomoo`02Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Moo`05001oogoo
Ool0000_Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03`00Ool00goo00<03gooOol00goo
00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol047oo00<007ooOol00Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000F
Ool00`00Oomoo`02Ool00`00Oomoo`0]Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<007oo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol04Goo00D007ooOomoo`0?00eoo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00mo
o`0001ioo`005Woo00<007ooOol00Woo00<007ooOol0;Goo00<007oo00l067oo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`03001oogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo015oo`05001oogooOol03`0=Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L0
3gooOomoo`0?Ool0000NOol001Ioo`03001oogoo039oo`03001oo`0?01Qoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0000moo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0BOol01000Oomoo`0?3Goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogoo
Ool03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol017oo00<0000?Ool017oo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol04Woo00@007ooOol03`eoo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo
0`0067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00=oo`03001oo`0?00Eoo`0300moogoo00=oo`0500moogooOol03`04
Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01=oo`03001o
o`0?00eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
009oo`04001oogoo00l5Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0COol00`00Ool03`0=Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol001Moo`@0031oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`02Ool01000Oomo
o`0?1Goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol057oo00<0000?Ool037oo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo0000
7Woo000FOol00`00Ool00002Ool00`00Oomoo`0]Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00D03gooOomoo`00
00=oo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Aoo`0300003goo00aoo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomo
ogoo00moo`0001ioo`005Woo00<007oo00000Woo00<007ooOol0;Goo00<007oo00l067oo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`05
00moogooOol00003Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`00Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001oo`00009oo`03001oogoo02eoo`03001oo`0?
01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool0100?Oomoo`0017oo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Ao
o`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<007oo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00Oomoo`0]Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00@03gooOol000Aoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300l007oo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`005goo0P0000=oo`00Ool0;goo00<0
07oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moo`0000Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00l007oo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
o`0000Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo
00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moo`0000]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?
Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300l007oo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0400moogoo000:Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?001oo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
100?Oomoo`002Woo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000GOol4000`Ool00`00Ool03`0HOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<007ooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400mo
ogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00D03gooOomoo`00
00Uoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`005Woo00<007oo00000Woo00<007ooOol0;Goo00<0
07oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`03001oogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`05
00moogooOol00009Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001oo`00009oo`03001o
ogoo02eoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`06Ool00`0000moo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`02Ool00`00Oomoo`06Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Io
o`03001oo`00009oo`03001oogoo01Yoo`@000Aoo`@000Moo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`06Ool00`0000mo
o`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`03Ool00`00Oomoo`05
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001oo`00009oo`03001oogoo01aoo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`00Ool03`07Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`03Ool00`00Oomoo`05Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00L03gooOomoo`0?Ool0000NOol001Moo`800003Ool007oo01ioo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`00Ool03`07Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`04Ool00`00Oomoo`04Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol003Ioo`H000=oo`03001oogoo009oo`03001oogoo00Aoo`<007d03`0300003`0?09003`03
00003`0?03003`03001oogoo01aoo`00;Goo1P0017oo00@007ooOol000Aoo`03001oogoo009oo`03
001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`04Ool01000Oomoo`0?1goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol01Goo00<007ooOol00goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
000gOol01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol017oo00<007oo00l067oo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00=oo`05
001oogooOol03`07Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`06Ool0
0`00Oomoo`02Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol003Qoo`03001oo`0000Aoo`03001oogoo
009oo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`03Ool01@00Oomoogoo00l01goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol01Woo00<007ooOol00Woo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol0
3goo00007Woo000hOol00`00Ool00004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool00Woo00<007ooOol00Woo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol01goo00D007ooOomoo`0?00Uoo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00>Goo0P001Goo10001goo
00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo009oo`03001oogoo009oo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00Moo`05001oogooOol03`09Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool01@0?Oomoogoo00001Goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol027oo00@007ooOol03`Uoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0500moogooOol0
0005Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@0
3gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`08
Ool01000Oomoo`0?2Goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00@03gooOol000Ioo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03goo
Ool037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00Uoo`03001oo`0?00Uoo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo
00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moo`0000Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00Uoo`03001oo`0?00Uoo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l0
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
o`0000Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0
100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00Yoo`0300003goo00Qoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300l007oo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03goo
Ool037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03001oogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo
00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300l007oo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`03001oogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<0
07oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`03001oogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300l007oo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03001oogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo
00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moo`00
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?
Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00Yoo`0300003goo00Qoo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moo`0000Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00
Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00Uoo`03001oo`0?00Uoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0400moogoo0006Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`09Ool00`00Ool03`09
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
1@0?Oomoogoo00001Goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol027oo00@007ooOol03`Uoo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0500moogooOol00005Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`07Ool01@00Oomoogoo00l02Goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol00Woo00<007ooOol00Woo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo
00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol01Woo00<007ooOol00Woo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol00goo00D007ooOomoo`0?
00Moo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`00
01ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00Ioo`03001oogoo009oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00=oo`05001oogooOol03`07
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`05Ool00`00Oomoo`03Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`04Ool01000Oomoo`0?1goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool017oo00<007ooOol017oo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01Goo00<007oo00l01goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol00goo
00<007ooOol01Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01Goo00<007oo00l01goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol00Woo00<007oo
Ool01Woo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01Woo00<0000?Ool01Woo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00D03gooOomoo`0000Uoo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?
Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`03001oogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0400moogoo000:Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?001oo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Ool0000;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Ool00005Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?001oo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@0
3gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool0100?Oomoo`0017oo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<007ooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00D0
3gooOomoo`0000=oo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomo
ogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Aoo`0300003goo00aoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0500moogooOol00003Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0
03Ioo`H000Aoo`@000Moo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0DOol00`0000moo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`02Ool01000Oomo
o`0?1Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000fOol0
0`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01=oo`03001oo`0?00eoo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo
00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00=oo`03001oo`0?00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?
Oomoogoo00moo`0001ioo`00=goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol017oo00<0
07oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo019oo`04001oogoo00l=
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool20005Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00L03gooOomoo`0?Ool0000NOol003Qoo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo00Aoo`<006@03`0300003`0?0<<03`0300003`0?01H03`03001oogoo01aoo`00;Goo1P00
1Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol017oo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo011oo`03001oogoo009oo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0
100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moo`0000=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00>Woo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00mo
o`03001oogoo00=oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`04
00moogoo0002Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0
03Ioo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol03Woo00<007ooOol017oo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00L03gooOomoo`00Ool03`05Ool01@0?Oomo
ogoo00l00goo00L03gooOomoo`0?Ool0000NOol003Ioo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool037oo0P001goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00Woo00<0000?Ool017oo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000g
Ool40005Ool40007Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool02goo00<007ooOol01goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo0P0017oo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol02Woo00<007oo
Ool027oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03goo00000goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol02Goo00<007ooOol02Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00@0
3gooOol0009oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l0
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Qoo`03001oogoo00Yoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0700moogoo
Ool007oo00l00goo00D03gooOomoo`0?00=oo`0300moo`0001ioo`00Bgoo0`0067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo00Ioo`8000eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomo
o`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`8000=oo`0500moogoo
Ool03`03Ool00`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`05Ool00`00Oomoo`0=Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@00Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`03Ool2000@Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?001oogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoogoo0P00
4Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03goo0000000?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol001Aoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04
Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0400mo
ogooOol20002Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300l0000001Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0900moogooOol03goo001oo`0?00=o
o`0300moo`0001ioo`00Bgooo`00B0007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<0000?Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moo`000000
3goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoogoo0`0000=oo`0?Ool0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol007oo00007Woo001;Ool3000HOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Ool0000000l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400mo
ogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?001o
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo
00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Ool000030003Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool20003
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700mo
ogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`0200000`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool40002Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`0200000goo00moo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700mo
ogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`02Ool60003Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Ool000020003Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Ao
o`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool0
0`0?Oomoo`06Ool30006Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo
00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?0000000600000goo00moo`06Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool0
3`0HOol00`0?Oomoo`07Ool50009Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400mo
ogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`02Ool50004Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogoo
Ool03goo00007Woo0010Ool40007Ool00`00Ool03`0?Ool>0009Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000oOol0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`05Ool:0009Ool00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo
00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool00005000COol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700mo
ogooOol03goo00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo
00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04Ool3000HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo
00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`04
00moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00
Ool0000HOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<007ooOol02goo
00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`00
00Aoo`04001oogoo000GOol00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<0
07ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00goo00D0
07ooOomoo`0000=oo`07001oogooOol007oo00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Ool0000HOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<007oo
Ool02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00goo00D007oo
Oomoo`0000Aoo`04001oogoo000GOol00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol0
5Goo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol0
0goo00D007ooOomoo`0000=oo`07001oogooOol007oo00007Woo0010Ool40007Oooo0018000NOol0
0?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00=Uoo`D000Aoo`<0009oo`<000=oo`D000=oo`D000Eoo`@00:eoo`00fWoo00<0
07ooOol01Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo009o
o`05001oogooOol00004Ool00`00Oomoo`2ZOol00=Yoo`03001oogoo00Ioo`03001oogoo009oo`05
001oogooOol00003Ool00`00Oomoo`07Ool01@00Oomoogoo0000/Goo003JOol50004Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool40005Ool40004Ool6002/Ool00=Yoo`03001oogoo009oo`04001oogoo
Ool20003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`03001oogoo0:Yoo`00fWoo00<007ooOol00Woo00H007ooOomoo`00Ool30005Ool30006Ool5
0004Ool4002]Ool00=Yoo`03001oogoo009oo`05001oogooOol0003<Ool00=Uoo`H000Aoo`03001o
ogoo0<Yoo`00hWoo0P00c7oo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.96984, -137.754, \
0.0186604, 0.863437}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ICS130 Whitening", "Section"],

Cell["Solve for specific pole frequency, zero frequency and gain.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(tr = \(Vout/Vin /. sol\) /. {Z1 \[Rule] par[1\/\(s\ C\), R2], 
            Z2 \[Rule] par[1\/\(s\ C\), R2], Z3 \[Rule] R3, Z4 \[Rule] R4} // 
        Simplify\), "\[IndentingNewLine]", 
    \(Numerator[tr]~Collect~s\), "\[IndentingNewLine]", 
    \(Denominator[tr]~Collect~s\), "\[IndentingNewLine]", 
    \(num = 
      Coefficient[Numerator[tr], s, {0, 1, 2}]\), "\[IndentingNewLine]", 
    \(den = 
      Coefficient[Denominator[tr], s, {0, 1, 2}]\), "\[IndentingNewLine]", 
    \(zeros = Solve[Numerator[tr] \[Equal] 0, s]\), "\[IndentingNewLine]", 
    \(poles = Solve[Denominator[tr] \[Equal] 0, s]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\((G\ R3\ R4\ \((1 + C\ R2\ s)\)\^2)\)/\((\(-R3\)\ R4 - 
            R2\^2\ \((1 + C\ \((R3 - G\ R3 + 2\ R4)\)\ s + 
                  C\^2\ R3\ R4\ s\^2)\) + 
            R2\ \((\(-2\)\ R4 + 
                  R3\ \((\(-1\) + G - 2\ C\ R4\ s)\))\))\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-G\)\ R3\ R4 - 2\ C\ G\ R2\ R3\ R4\ s - 
      C\^2\ G\ R2\^2\ R3\ R4\ s\^2\)], "Output"],

Cell[BoxData[
    \(\(-R2\^2\) - R2\ R3 + G\ R2\ R3 - 2\ R2\ R4 - 
      R3\ R4 + \((\(-2\)\ C\ R2\ R3\ R4 - 
            C\ R2\^2\ \((R3 - G\ R3 + 2\ R4)\))\)\ s - 
      C\^2\ R2\^2\ R3\ R4\ s\^2\)], "Output"],

Cell[BoxData[
    \({\(-G\)\ R3\ R4, \(-2\)\ C\ G\ R2\ R3\ R4, \(-C\^2\)\ G\ R2\^2\ R3\ R4}\
\)], "Output"],

Cell[BoxData[
    \({\(-R2\^2\) - R2\ R3 + G\ R2\ R3 - 2\ R2\ R4 - 
        R3\ R4, \(-C\)\ R2\^2\ R3 + C\ G\ R2\^2\ R3 - 2\ C\ R2\^2\ R4 - 
        2\ C\ R2\ R3\ R4, \(-C\^2\)\ R2\^2\ R3\ R4}\)], "Output"],

Cell[BoxData[
    \({{s \[Rule] \(-\(1\/\(C\ R2\)\)\)}, {s \[Rule] \(-\(1\/\(C\ \
R2\)\)\)}}\)], "Output"],

Cell[BoxData[
    \({{s \[Rule] \(-\(\(1\/\(2\ C\^2\ R2\^2\ R3\ R4\)\)\((C\ R2\^2\ R3 - 
                C\ G\ R2\^2\ R3 + 2\ C\ R2\^2\ R4 + 2\ C\ R2\ R3\ R4 - 
                C\ R2\^2\ \@\(R3\^2 - 2\ G\ R3\^2 + G\^2\ R3\^2 - 4\ G\ R3\ \
R4 + 4\ R4\^2\))\)\)\)}, {s \[Rule] \(-\(\(1\/\(2\ C\^2\ R2\^2\ R3\ \
R4\)\)\((C\ R2\^2\ R3 - C\ G\ R2\^2\ R3 + 2\ C\ R2\^2\ R4 + 
                2\ C\ R2\ R3\ R4 + 
                C\ R2\^2\ \@\(R3\^2 - 2\ G\ R3\^2 + G\^2\ R3\^2 - 4\ G\ R3\ \
R4 + 4\ R4\^2\))\)\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(eq1 = 
        1\/\(C\ R2\) \[Equal] 2  \[Pi]\ zerof;\)\), "\[IndentingNewLine]", 
    \(\(eq2 = 
        R3\^2 - 2\ G\ R3\^2 + G\^2\ R3\^2 - 4\ G\ R3\ R4 + 4\ R4\^2 \[Equal] 
          0\ ;\) (*\ real\ poles\ *) \), "\[IndentingNewLine]", 
    \(\(eq3 = \(1\/\(2\ C\^2\ R2\^2\ R3\ R4\)\) \((C\ R2\^2\ R3 - 
                C\ G\ R2\^2\ R3 + 2\ C\ R2\^2\ R4 + 
                2\ C\ R2\ R3\ R4)\) \[Equal] 
          2\ \[Pi]\ polef;\)\), "\[IndentingNewLine]", 
    \(\(eq4 = G \[Equal] gain;\)\), "\[IndentingNewLine]", 
    \(\(eq5 = C \[Equal] C1;\)\ \  (*\ 
      assume\ a\ value*) \), "\[IndentingNewLine]", 
    \(\(assume = {polef \[Rule] 100, zerof \[Rule] 20, gain \[Rule] 25, 
          C1 \[Rule] 330*^-9};\)\), "\[IndentingNewLine]", 
    \(Rs = 
      Solve[{eq1, eq2, eq3, eq4, eq5} /. assume, {R2, R3, R4}] // 
        N\)}], "Input"],

Cell[BoxData[
    \({{R2 \[Rule] 24114.38531695384`, R4 \[Rule] \(-18085.78898771538`\), 
        R3 \[Rule] \(-2009.5321097461533`\)}, {R2 \[Rule] 24114.38531695384`, 
        R4 \[Rule] 24114.38531695384`, 
        R3 \[Rule] 1507.149082309615`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Rs = {{}, {R2 \[Rule] 24000. , R4 \[Rule] 24000. , 
          R3 \[Rule] 1500. }}\)], "Input"],

Cell[BoxData[
    \({{}, {R2 \[Rule] 24000.`, R4 \[Rule] 24000.`, 
        R3 \[Rule] 1500.`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(Vout/Vin /. sol\) /. {Z1 \[Rule] par[1\/\(s\ C1\), R2], 
            Z2 \[Rule] par[1\/\(s\ C1\), R2], Z3 \[Rule] R3, Z4 \[Rule] R4, 
            G \[Rule] gain} // Together\) // 
      Simplify\), "\[IndentingNewLine]", 
    \(\(\(% /. assume\) /. 
        Rs\[LeftDoubleBracket]2\[RightDoubleBracket];\)\), "\
\[IndentingNewLine]", 
    \(getZPK[%]\), "\[IndentingNewLine]", 
    \(\(%% /. {s \[Rule] 
            2\ \[Pi]\ \[ImaginaryI]\ f};\)\), "\[IndentingNewLine]", 
    \(\(BodePlot[%, {f, 0.1, 1000}];\)\)}], "Input"],

Cell[BoxData[
    \(\(-\(\((gain\ R3\ R4\ \((1 + C1\ R2\ s)\)\^2)\)/\((\(-R3\)\ R4 - 
            R2\^2\ \((1 + C1\ \((R3 - gain\ R3 + 2\ R4)\)\ s + 
                  C1\^2\ R3\ R4\ s\^2)\) + 
            R2\ \((\(-2\)\ R4 + 
                  R3\ \((\(-1\) + gain - 
                        2\ C1\ R4\ s)\))\))\)\)\)\)], "Output"],

Cell[BoxData[
    InterpretationBox[\("K(f=0) = "\[InvisibleSpace]1.`\[InvisibleSpace]" ("\
\[InvisibleSpace]1.`\[InvisibleSpace]")"\),
      SequenceForm[ "K(f=0) = ", 1.0, " (", 1.0, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("K(f=\[Infinity]) = \
"\[InvisibleSpace]24.999999999999996`\[InvisibleSpace]" \
("\[InvisibleSpace]24.999999999999996`\[InvisibleSpace]")"\),
      SequenceForm[ 
      "K(f=\[Infinity]) = ", 24.999999999999996, " (", 24.999999999999996, 
        ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Poles at = \
"\[InvisibleSpace]\(-100.47660548730772`\)\[InvisibleSpace]" and "\
\[InvisibleSpace]\(-100.47660548730761`\)\[InvisibleSpace]" "\),
      SequenceForm[ 
      "Poles at = ", -100.47660548730772, " and ", -100.47660548730761, " "],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole frequency = \
"\[InvisibleSpace]100.47660548730767`\[InvisibleSpace]" \
("\[InvisibleSpace]100.47660548730767`\[InvisibleSpace]")"\),
      SequenceForm[ 
      "Pole frequency = ", 100.47660548730767, " (", 100.47660548730767, ")"],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole Q = "\[InvisibleSpace]0.5`\[InvisibleSpace]" ("\
\[InvisibleSpace]0.5`\[InvisibleSpace]")"\),
      SequenceForm[ "Pole Q = ", .5, " (", .5, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Zero frequency = \
"\[InvisibleSpace]20.095321097461536`\[InvisibleSpace]" \
("\[InvisibleSpace]20.095321097461536`\[InvisibleSpace]")"\),
      SequenceForm[ 
      "Zero frequency = ", 20.095321097461536, " (", 20.095321097461536, ")"],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Zero Q = "\[InvisibleSpace]0.4999999999999999`\
\[InvisibleSpace]" ("\[InvisibleSpace]0.4999999999999999`\[InvisibleSpace]")"\
\),
      SequenceForm[ 
      "Zero Q = ", .49999999999999989, " (", .49999999999999989, ")"],
      Editable->False]], "Print"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.253086 0.246914 0.0120563 0.0216834 [
[.00617 -0.0125 -11 -12.5625 ]
[.00617 -0.0125 11 0 ]
[.25309 -0.0125 -5 -12.5625 ]
[.25309 -0.0125 5 0 ]
[.5 -0.0125 -8 -12.5625 ]
[.5 -0.0125 8 0 ]
[.74691 -0.0125 -11 -12.5625 ]
[.74691 -0.0125 11 0 ]
[.99383 -0.0125 -14 -12.5625 ]
[.99383 -0.0125 14 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -8 -25.125 ]
[.5 -0.0125 8 -12.5625 ]
[-0.0125 .01206 -6 -4.5 ]
[-0.0125 .01206 0 4.5 ]
[-0.0125 .12047 -6 -4.5 ]
[-0.0125 .12047 0 4.5 ]
[-0.0125 .22889 -12 -4.5 ]
[-0.0125 .22889 0 4.5 ]
[-0.0125 .33731 -12 -4.5 ]
[-0.0125 .33731 0 4.5 ]
[-0.0125 .44572 -12 -4.5 ]
[-0.0125 .44572 0 4.5 ]
[-0.0125 .55414 -12 -4.5 ]
[-0.0125 .55414 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -24.5625 -8 ]
[-0.01875 .30902 -12 8 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12.5625 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .12047 m
1 .12047 L
s
0 .22889 m
1 .22889 L
s
0 .33731 m
1 .33731 L
s
0 .44572 m
1 .44572 L
s
0 .55414 m
1 .55414 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -69 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01206 m
.00625 .01206 L
s
[(0)] -0.0125 .01206 1 0 Mshowa
0 .12047 m
.00625 .12047 L
s
[(5)] -0.0125 .12047 1 0 Mshowa
0 .22889 m
.00625 .22889 L
s
[(10)] -0.0125 .22889 1 0 Mshowa
0 .33731 m
.00625 .33731 L
s
[(15)] -0.0125 .33731 1 0 Mshowa
0 .44572 m
.00625 .44572 L
s
[(20)] -0.0125 .44572 1 0 Mshowa
0 .55414 m
.00625 .55414 L
s
[(25)] -0.0125 .55414 1 0 Mshowa
.125 Mabswid
0 .03374 m
.00375 .03374 L
s
0 .05542 m
.00375 .05542 L
s
0 .07711 m
.00375 .07711 L
s
0 .09879 m
.00375 .09879 L
s
0 .14216 m
.00375 .14216 L
s
0 .16384 m
.00375 .16384 L
s
0 .18552 m
.00375 .18552 L
s
0 .20721 m
.00375 .20721 L
s
0 .25057 m
.00375 .25057 L
s
0 .27226 m
.00375 .27226 L
s
0 .29394 m
.00375 .29394 L
s
0 .31562 m
.00375 .31562 L
s
0 .35899 m
.00375 .35899 L
s
0 .38067 m
.00375 .38067 L
s
0 .40236 m
.00375 .40236 L
s
0 .42404 m
.00375 .42404 L
s
0 .46741 m
.00375 .46741 L
s
0 .48909 m
.00375 .48909 L
s
0 .51077 m
.00375 .51077 L
s
0 .53246 m
.00375 .53246 L
s
0 .57582 m
.00375 .57582 L
s
0 .59751 m
.00375 .59751 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -87.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 10.2813 translate
90 rotate
-69 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dB) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Magnitude) show
117.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .01206 m
.02372 .01206 L
.03955 .01206 L
.05352 .01207 L
.06699 .01207 L
.07854 .01207 L
.08806 .01208 L
.10505 .01208 L
.12005 .01209 L
.13273 .0121 L
.14475 .01212 L
.15518 .01213 L
.16433 .01214 L
.17329 .01216 L
.18125 .01217 L
.18912 .01219 L
.19619 .01221 L
.20257 .01223 L
.20897 .01225 L
.2148 .01228 L
.22066 .0123 L
.22601 .01233 L
.23093 .01235 L
.23592 .01238 L
.24051 .01241 L
.24476 .01244 L
.24909 .01247 L
.25309 .0125 L
s
.25309 .0125 m
.27063 .01268 L
.28646 .01289 L
.30044 .01314 L
.31391 .01344 L
.33497 .01411 L
.35197 .01486 L
.36749 .0158 L
.38058 .01682 L
.39182 .01791 L
.40262 .01919 L
.41208 .02053 L
.42045 .02192 L
.42869 .02351 L
.43607 .02514 L
.4434 .02698 L
.45001 .02884 L
.45601 .03073 L
.46205 .03282 L
.46755 .03492 L
.47311 .03725 L
.4782 .03957 L
.48288 .04187 L
.48765 .0444 L
.49205 .0469 L
.49612 .04937 L
.5 .05187 L
s
.5 .05187 m
.51754 .0651 L
.53337 .08008 L
.56082 .11387 L
.58072 .145 L
.5985 .17735 L
.61321 .207 L
.62691 .23654 L
.63864 .26293 L
.64882 .28643 L
.65869 .30947 L
.66741 .32986 L
.67517 .34794 L
.68285 .36567 L
.68977 .38136 L
.69666 .39671 L
.7029 .41031 L
.70858 .42238 L
.71432 .43424 L
.71956 .44479 L
.72487 .45513 L
.72974 .46434 L
.73423 .47255 L
.73881 .48066 L
.74304 .48789 L
.74691 .49431 L
s
.74691 .49431 m
.78029 .5408 L
.80773 .56777 L
.82836 .58235 L
.84504 .59125 L
.86033 .59758 L
.87324 .60181 L
.88545 .60504 L
.89603 .60734 L
.90531 .60904 L
.91437 .61044 L
.92242 .61152 L
.92964 .61236 L
.93682 .61309 L
.9433 .61368 L
.9498 .6142 L
.9557 .61462 L
.96108 .61497 L
.96653 .61529 L
.97153 .61555 L
.97659 .6158 L
.98126 .61601 L
.98556 .61618 L
.98996 .61635 L
.99383 .61648 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00fgoo0`000Woo0`000Woo1P00aGoo003L
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000aGoo003LOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`36Ool00=aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
0<Eoo`00g7oo1P000goo00D007ooOomoo`000<Ioo`00g7oo00<007ooOol00Woo00@007ooOomoo`H0
0<Eoo`00g7oo00<007ooOol00Woo00<007ooOol0c7oo003KOol30002Ool3003=Ool00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo000gOol40006Ool20005Ool70010Ool70015Ool70003Ool4000nOol7
0003Ool40005Ool4000eOol70003Ool40005Ool40005Ool4000MOol003Ioo`03001oogoo009oo`03
001oogoo00=oo`8000Qoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`0eOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`00
00Aoo`03001oogoo01Yoo`00=Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol0A7oo00<0
07ooOol0BGoo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0?Woo00<007ooOol00goo00<0
07ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo03Eoo`03001oogoo00=oo`03001oogoo009o
o`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol06Woo000fOol00`00Oomoo`02
Ool00`00Oomoo`0=Ool00`00Oomoo`14Ool00`00Oomoo`19Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`0nOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool0=Goo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004
Ool00`00Oomoo`0JOol003Ioo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03001o
ogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`0eOol00`00Oomoo`03Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo01Yoo`00=Woo00<007ooOol00Woo
00<007ooOol03Goo00<007ooOol0A7oo00<007ooOol0BGoo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol0?Woo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo
03Eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo
00<007ooOol06Woo000fOol00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`14Ool00`00Oomo
o`19Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0nOol00`00Oomoo`03Ool00`00Oomo
o`02Ool01@00Oomoogoo000017oo00<007ooOol0=Goo00<007ooOol00goo00<007ooOol00Woo00D0
07ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`0JOol003Ioo`03001oogoo009oo`03
001oogoo00]oo`<004Aoo`<004Uoo`<000Eoo`03001oogoo009oo`03001oogoo03aoo`<000Eoo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0cOol30005Ool00`00Oomoo`02Ool01@00
Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo01Yoo`00=goo100047oo00<007ooOol0
A7oo00<007ooOol0BGoo00<007ooOol017oo1000@Goo00<007ooOol017oo10001Goo1000>7oo00<0
07ooOol017oo10001Goo10001Goo10007Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol0
0?mook5oo`00ogoo/Goo003oOonaOol0041oool004P002Uoo`00=Goo10001goo00<007oo00005goo
00<007ooOol037oo00<007ooOol01goo00<007ooOol017oo00<007ooOol017oo00<007ooOol00Woo
00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo01Eoo`03001oogoo00]oo`03001oogoo
00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol00003Ool01@00
Oomoogoo00005goo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00009oo`03001oogoo01Ioo`03001oogoo
00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
009oo`05001oogooOol00003Ool00`00Ool0000YOol003Aoo`03001oogoo009oo`03001oogoo00Ao
o`03001oo`0001Moo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Ao
o`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol00`00Oomo
o`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0001Moo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomo
o`0FOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007oo0000:Goo000dOol00`00Oomoo`02
Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00
=7oo00<007ooOol00Woo00<007ooOol017ooEP005Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moo`0002Uoo`00=7oo00<007ooOol00Woo00<007ooOol017oo00<007oo
00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo020000=oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Ool0000YOol003Aoo`03001oogoo009oo`03001oogoo00Aoo`03
001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`08
Ool<00000goo00moo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000dOol00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01Woo1P000goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00=7oo00<007ooOol00Woo00<0
07ooOol017oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo009oo`D000Aoo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol003Eoo`@000Moo`03
001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Ool000040005Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03`0000000P0000=oo`0?Ool00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool200000`0?Oomoo`0EOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo0P000goo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03`00Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0300moo`0000<0009oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uo
o`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`09
00moogooOol03goo001oo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool0
0`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?009oo`8000=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0G
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00l0000000003`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo0000
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Ool0000YOol0041oo`80000300moogoo01Eoo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool2000COol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`00
02Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l017oo00<007ooOol047oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0
000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00Eoo`03001oogoo00moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`06Ool00`00Oomoo`0>Ool00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
o`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l01goo0P003Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000Y
Ool0041oo`80000300moogoo01Eoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00Uoo`03001oogoo00]oo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0:Ool00`00Oomoo`0:Ool00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
o`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l02goo00<007ooOol02Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00aoo`03001oogoo00Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0<Ool00`00Oomoo`08Ool00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l03Goo00<007ooOol01goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00ioo`03001oogoo00Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0?Ool00`00Oomoo`05Ool00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moo`0002Uoo`00@7oo0P0000<03gooOol05Goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l047oo00<007ooOol017oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?015oo`03001oogoo00=oo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0AOol00`00Oomoo`03Ool0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moo`0002Uoo`00=Goo10001goo00<007oo00l05goo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l04Woo00<007oo
Ool00Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Ool0000YOol003Aoo`03001oogoo009oo`03001oogoo00Aoo`03001o
o`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01=oo`05001oogooOol03`0=Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00>Goo00<007ooOol017oo
00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l057oo00@007ooOol03`eoo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000iOol00`00Oomoo`04
Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0DOol01000Oomoo`0?3Goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol003Uoo`03001oogoo
00Aoo`<00;H03`0300003`0?08X03`03001oogoo02Moo`00=Goo10001goo00<007oo00l05goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05Goo00<007oo00l03Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Ool0000YOol003Eoo`03001oogoo00Qoo`03001oo`0?01Moo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Ioo`0300003goo00aoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000eOol00`00Oomoo`08Ool00`00Ool03`0GOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0FOol00`0000moo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00=Goo1@001Woo00<007oo00l05goo00<03goo
Ool037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05goo00<007ooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03001o
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?001oo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`00
02Uoo`00@7oo0P0000<03gooOol05Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03`00Ool02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041o
o`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moo`0000]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0G
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol0100?Oomoo`002Woo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
01Moo`0400moogoo000:Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00D03goo
Oomoo`0000Uoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol01@0?Oomoogoo0000
2Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo009oo`03001oogoo
00Ioo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03goo0000:Goo0010Ool200000`0?Oomoo`0EOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`03Ool00`00
Oomoo`05Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol00goo00<0
07ooOol01Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00Aoo`03
001oogoo00Aoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`04Ool0
0`00Oomoo`04Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol01Goo
00<007ooOol00goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00Eo
o`03001oogoo00=oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`06
Ool00`00Oomoo`02Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moo`0002Uoo`00@7oo0P0000<03gooOol05Goo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool01Woo00<007ooOol00Woo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00Moo`05001oogooOol03`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol01goo
00D007ooOomoo`0?00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`08Ool01000Oomo
o`0?2Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000Y
Ool0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00Qoo`04001oogoo00l9Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<0
07oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02Goo00<007oo00l02Goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00Uoo`03001oo`0?00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool200000`0?Oomoo`0EOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0:Ool00`0000moo`08Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2Woo00<0000?Ool027oo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03001oogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo
000[Ool70003Ool40007Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`00Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uo
o`00;Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03goo
Ool037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05goo00<03gooOol02goo00<03`00Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Ool0000YOol002ioo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00Aoo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300l007oo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000^Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Ool00007Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moo`0002Uoo`00;Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol017oo0`00
b00?00<0000?00l0N00?00<007ooOol09goo000^Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0100?Oomoo`001Woo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol002ioo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0400moogoo0006Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moo`0002Uoo`00;7oo0`001Goo00<007ooOol00Woo00<007ooOol017oo00<007oo
00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00@03gooOol000Ioo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000^Ool00`00Oomoo`04Ool40007
Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool01@0?Oomoogoo00001Goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001o
o`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0500moogooOol00005Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo
00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol00Woo00<007ooOol00Woo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`80000300moogoo
01Eoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo009oo`03001oogoo009oo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool0
3`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`03Ool01@00Oomoogoo00l01goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00=oo`05001oogooOol03`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol017oo00@007ooOol03`Moo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`04Ool01000Oomoo`0?1goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Aoo`04001oogoo00l7Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`00
02Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01Goo00<0
07oo00l01goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`80
000300moogoo01Eoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Eoo`03001oo`0?00Mo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0G
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`00Ool03`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol01Woo00<0000?Ool01Woo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Ioo`0300003goo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`00Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uo
o`007Goo10007goo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo
00<007ooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol001ao
o`03001oogoo009oo`03001oogoo01aoo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300l007oo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3goo0000:Goo000LOol00`00Oomoo`02Ool00`00Oomoo`0LOol200000`0?Oomoo`0EOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?001oo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moo`0002Uoo`0077oo00<007ooOol00Woo00<007ooOol077oo00<007oo
00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo00001Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol001Uoo`04001oogoo0003Ool00`00
Oomoo`0MOol00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Ool00005Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`006Goo2@00
7Woo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00@03gooOol0
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000QOol00`00Oomo
o`0LOol00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0100?Oomo
o`0017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001o
o`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0500moogooOol00003Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo
00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00D03gooOomoo`0000=oo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000JOol00`00Oomoo`04Ool00`00Oomo
o`0LOol200000`0?Oomoo`0EOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`02Ool01000Oomoo`0?1Woo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol001Yoo`P0
01ioo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
009oo`04001oogoo00l6Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`006Woo00@007oo
Ool000=oo`03001oogoo01aoo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo009oo`04001oogoo00l6Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`00
02Uoo`006Woo00@007ooOol000=oo`03001oogoo01aoo`03001oo`0?01Moo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo009oo`04001oogoo00l6Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moo`0002Uoo`006Woo00@007ooOol000=oo`03001oogoo00Moo`L000=oo`@000Mo
o`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00=o
o`03001oo`0?00Ioo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000JOol01000Oomoo`00
0goo00<007ooOol02Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol017oo00<007oo00l0
5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol00goo00<007oo00l0
1Woo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol001]oo`800004Ool00000000=Ool00`00
Oomoo`08Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`03Ool00`00Ool03`06Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`00
02Uoo`00;Woo00<007ooOol027oo00<007ooOol017oo0`00e`0?00<0000?00l0J@0?00<007ooOol0
9goo000^Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0000moo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moo`0002Uoo`00;Woo00<007ooOol017oo10001goo00<007oo00l05goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<007ooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Ool0000YOol002ioo`03001oogoo00Aoo`03001oogoo00Qoo`03001oo`0?
01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03001oogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000/Ool30006Ool00`00Oomoo`08Ool0
0`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?001oo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00;Woo00<007ooOol017oo
1@001Woo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03goo000017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001o
o`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
o`0000Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool200000`0?Oomoo`0EOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0100?Oomoo`000goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0400moogoo0003Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00D03gooOomoo`00009oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool01@0?Oomoogoo00000Woo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo009oo`03001oo`0?00Aoo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010
Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`02Ool00`00Ool03`04Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l0
5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0Woo00<007oo00l017oo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`80000300moogoo01Eoo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`030000
3goo00=oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0000moo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0000?Ool00goo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0
000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`03001oogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool0
0`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`00Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo
00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03`00Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300l007oo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03goo0000:Goo0010Ool200000`0?Oomoo`0EOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?001oo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03goo00000Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000Y
Ool0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moo`00009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00
Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool01P0?Oomoo`00Ool03`Aoo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool01P0?Oomoo`00
Ool03`Aoo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool01P0?Oomoogoo00003`Aoo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010
Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool01P0?Oomoogoo00003`Aoo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool200000`0?Oomoo`0EOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`00Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<007ooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300l007oo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?001oo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00
:goo1P0017oo10001goo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo00000Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0
02]oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Ool00002Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00;7oo00<007ooOol01Goo00<007ooOol00Woo00<0
07ooOol017oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00H03gooOol007oo00l3Ool0100?Oomoo`0?
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00;Goo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol017oo0`00i`0?00<0000?00l0F@0?00<007ooOol09goo000^Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
1P0?Oomoo`00Ool03`=oo`0400moogoo00lHOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3goo0000:Goo000_Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0G
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool01P0?Oomoogoo00003`=oo`0400moogoo00lHOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03goo0000:Goo000[Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<0
07ooOol017oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00H03gooOomoo`0000l3Ool0100?Oomoo`0?
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00:goo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`05001oogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03goo0000:Goo000/Ool40005Ool40007Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?001oogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03`00
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000Y
Ool0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moo`00Ool03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool20000
0`0?Oomoo`0EOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Ool007oo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo
00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOol0000?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol00002Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00000Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00P03gooOomo
o`0?001oo`0?67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<0
07oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00P03gooOomoo`0?001oo`0?67oo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00P03gooOomoo`0?Ool0000?67oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moo`0002Uoo`00@7oo0P0000<03gooOol05Goo00<03gooOol037oo00<03gooOol01goo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00P03gooOomoo`0?Ool0000?67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uo
o`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
001oogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001o
o`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?001oo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03`00Ool05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moo`0001Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`005Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
o`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0500moogooOol0000DOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo
0010Ool200000`0?Oomoo`0EOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00D03gooOomoo`0001Aoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041o
o`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`02Ool00`00Oomoo`0AOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010
Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool00goo00<007ooOol047oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00
@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo00Aoo`03001oogoo00moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0
041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`04Ool00`00Oomoo`0?Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo
0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol01Goo00<007ooOol03Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uo
o`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo00Ioo`03001oogoo00eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000Y
Ool0041oo`80000300moogoo01Eoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`07Ool00`00Oomoo`0<Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol01goo00<007ooOol037oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
o`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo00Qoo`03001oogoo00]oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Ool0000YOol002]oo`H000Aoo`@000Moo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`09Ool00`00Oomoo`0:Ool00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03goo0000:Goo000[Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool017oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo00Yoo`03001oogoo00Uoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000Y
Ool002aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0;Ool00`00Oomoo`08Ool00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03goo0000:Goo000]Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00
Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol037oo
00<007ooOol01goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00;Woo00<0
07ooOol027oo00<007ooOol017oo0`00o`0?0@0?00<0000?00l0@00?00<007ooOol09goo000_Ool0
0`00Oomoo`03Ool40007Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol03Woo00<007ooOol01Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moo`0002Uoo`00:goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol027oo00<007oo
00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo00moo`03
001oogoo00Aoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol002]oo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo00Qoo`03001oo`0?01Moo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0@Ool00`00Oomoo`03Ool00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03goo0000:Goo000/Ool40005Ool50006Ool00`00Ool03`0GOol00`0?
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol04Goo00<007ooOol00Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo019oo`80009oo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0DOol00`00Ool03`0=Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03goo0000:Goo0010Ool200000`0?Oomoo`0EOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Goo00<0000?Ool037oo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`8000aoo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0
041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Ool0000;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool0
3`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<0
3gooOol00P002Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo009o
o`8000Moo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`04Ool20005
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol01Woo0P000goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo0P0000<03gooOol05Goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00Qoo`<0000300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool40006Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000
:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00@03gooOomoo`@0009oo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041o
o`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`05Ool40006Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03goo00001`0017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00005goo00<007ooOol037oo00<007ooOol01goo
00<007ooOol017oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00
00=oo`03001oogoo01Eoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo
00=oo`03001oogoo00=oo`05001oogooOol00003Ool01@00Oomoogoo00005goo00<007ooOol02goo
00<007ooOol01goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo
00D007ooOomoo`00009oo`03001oogoo01Ioo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo
00Eoo`03001oo`0000T000Aoo`05001oogooOol00003Ool00`00Ool0000YOol0041oo`03001oo`00
01Moo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo
009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00
Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo
00D007ooOomoo`0001Moo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`0FOol00`00
Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool>0000
0goo001oo`0XOol0041oool004P002Uoo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003o
OonaOol00?mook5oo`00cWoo1000gWoo003BOol00`00Oomoo`3KOol00=9oo`03001oogoo0=]oo`00
^Woo0`000goo0`000goo1@000goo0`0000=oo`00Ool00Woo0`000Woo0`0000=oo`0000001@001Goo
100017oo0`0000=oo`0000000Woo0`0000=oo`00000017oo1000Ygoo002kOol00`00Oomoo`03Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`8000Aoo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0003Ool20002Ool01000Oomoogoo0P0017oo
00<007ooOol00Woo00<007ooOol0Y7oo002kOol01000Oomoo`000Woo00D007ooOomoo`0000=oo`05
001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol0
ZGoo002kOol01`00Ool007oo001oo`0000Aoo`@000=oo`03001oogoo009oo`03001oogoo009oo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo009oo`04
001oogoo0004Ool00`00Oomoo`02Ool6002VOol00;]oo`07001oo`00Ool007oo00000goo00D007oo
Oomoo`0000=oo`04001oogooOol20004Ool20003Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000goo0P0017oo00<007ooOol00Woo00<007ooOol0
Y7oo002kOol01`00Ool007oo001oo`0000Aoo`<000Eoo`<00003Ool00000009oo`800004Ool00000
0004Ool30005Ool70002Ool20003Ool20003Ool300000goo001oo`04Ool4002WOol00;]oo`8000=o
o`8002Qoo`03001oogoo019oo`03001oogoo0:ioo`00^Woo0`000goo0`009goo00<007ooOol04Woo
00<007ooOol0[Woo003ROol00`00Oomoo`0IOol2002`Ool00>9oo`03001oogoo0<]oo`00ogoo/Goo
003oOonaOol00?mook5oo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-1.82989, -6.47146, \
0.0186604, 0.21249}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.253086 0.246914 0.012151 0.00719555 [
[.00617 -0.0125 -11 -12.5625 ]
[.00617 -0.0125 11 0 ]
[.25309 -0.0125 -5 -12.5625 ]
[.25309 -0.0125 5 0 ]
[.5 -0.0125 -8 -12.5625 ]
[.5 -0.0125 8 0 ]
[.74691 -0.0125 -11 -12.5625 ]
[.74691 -0.0125 11 0 ]
[.99383 -0.0125 -14 -12.5625 ]
[.99383 -0.0125 14 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -8 -25.125 ]
[.5 -0.0125 8 -12.5625 ]
[-0.0125 .01215 -6 -4.5 ]
[-0.0125 .01215 0 4.5 ]
[-0.0125 .15606 -12 -4.5 ]
[-0.0125 .15606 0 4.5 ]
[-0.0125 .29997 -12 -4.5 ]
[-0.0125 .29997 0 4.5 ]
[-0.0125 .44388 -12 -4.5 ]
[-0.0125 .44388 0 4.5 ]
[-0.0125 .58779 -12 -4.5 ]
[-0.0125 .58779 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -24.5625 -20 ]
[-0.01875 .30902 -12 20 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12.5625 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .15606 m
1 .15606 L
s
0 .29997 m
1 .29997 L
s
0 .44388 m
1 .44388 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -69 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01215 m
.00625 .01215 L
s
[(0)] -0.0125 .01215 1 0 Mshowa
0 .15606 m
.00625 .15606 L
s
[(20)] -0.0125 .15606 1 0 Mshowa
0 .29997 m
.00625 .29997 L
s
[(40)] -0.0125 .29997 1 0 Mshowa
0 .44388 m
.00625 .44388 L
s
[(60)] -0.0125 .44388 1 0 Mshowa
0 .58779 m
.00625 .58779 L
s
[(80)] -0.0125 .58779 1 0 Mshowa
.125 Mabswid
0 .04813 m
.00375 .04813 L
s
0 .08411 m
.00375 .08411 L
s
0 .12008 m
.00375 .12008 L
s
0 .19204 m
.00375 .19204 L
s
0 .22802 m
.00375 .22802 L
s
0 .264 m
.00375 .264 L
s
0 .33595 m
.00375 .33595 L
s
0 .37193 m
.00375 .37193 L
s
0 .40791 m
.00375 .40791 L
s
0 .47986 m
.00375 .47986 L
s
0 .51584 m
.00375 .51584 L
s
0 .55182 m
.00375 .55182 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -99.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
81 10.2813 translate
90 rotate
-81 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(degree) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phase) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .01543 m
.03955 .01663 L
.06699 .01794 L
.08762 .01917 L
.1043 .02035 L
.11959 .0216 L
.1325 .02281 L
.14471 .0241 L
.15529 .02534 L
.16457 .02653 L
.17363 .02779 L
.18168 .02901 L
.1889 .03019 L
.19608 .03143 L
.20256 .03264 L
.20906 .03391 L
.21496 .03514 L
.22034 .03633 L
.22579 .03758 L
.23079 .0388 L
.23585 .04008 L
.24052 .04132 L
.24482 .04252 L
.24922 .04378 L
.25309 .04494 L
s
.25309 .04494 m
.28646 .05688 L
.31391 .06985 L
.33453 .08198 L
.35121 .09359 L
.3665 .10589 L
.37942 .11764 L
.39162 .13004 L
.4022 .14189 L
.41148 .15319 L
.42054 .16509 L
.4286 .17643 L
.43581 .18721 L
.44299 .19856 L
.44948 .20935 L
.45597 .22066 L
.46187 .2314 L
.46726 .24158 L
.4727 .25226 L
.4777 .26237 L
.48277 .27293 L
.48743 .28292 L
.49174 .29237 L
.49613 .30224 L
.5 .31109 L
s
.5 .31109 m
.53337 .39282 L
.56082 .46277 L
.58144 .51232 L
.59812 .54774 L
.61342 .57483 L
.62633 .59271 L
.63236 .5993 L
.63854 .60483 L
.64417 .60875 L
.64675 .61018 L
.64912 .61128 L
.65155 .61222 L
.65374 .61287 L
.65611 .6134 L
.6574 .6136 L
.65802 .61368 L
.65861 .61373 L
.65917 .61378 L
.65946 .6138 L
.65976 .61381 L
.66002 .61383 L
.6603 .61384 L
.66056 .61384 L
.6608 .61385 L
.66094 .61385 L
.6611 .61385 L
.66138 .61385 L
.66166 .61384 L
.66191 .61384 L
.66218 .61383 L
.66248 .61381 L
.66309 .61378 L
.66361 .61374 L
.66409 .61369 L
.66517 .61356 L
.6661 .61341 L
.66708 .61322 L
.6691 .61272 L
.67121 .61204 L
.67492 .61047 L
.67907 .60814 L
.68285 .60551 L
.68971 .5995 L
.69655 .59196 L
.70276 .58387 L
.7084 .57552 L
.7141 .56619 L
.71932 .55691 L
.72459 .54685 L
Mistroke
.72944 .53706 L
.73391 .52762 L
.73847 .51761 L
.74268 .50806 L
.74691 .49819 L
Mfstroke
.74691 .49819 m
.78029 .41482 L
.80773 .34565 L
.82836 .29721 L
.84504 .26139 L
.86033 .23151 L
.87324 .20857 L
.88545 .18876 L
.89603 .17303 L
.90531 .16028 L
.91437 .14872 L
.92242 .13915 L
.92964 .13112 L
.93682 .1236 L
.9433 .1172 L
.9498 .11115 L
.9557 .10594 L
.96108 .10141 L
.96653 .09705 L
.97153 .09324 L
.97659 .08954 L
.98126 .08628 L
.98556 .08339 L
.98996 .08056 L
.99383 .07815 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00fgoo0`000Woo0`000Woo1P00aGoo003L
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000aGoo003LOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`36Ool00=aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
0<Eoo`00g7oo1P000goo00D007ooOomoo`000<Ioo`00g7oo00<007ooOol00Woo00@007ooOomoo`H0
0<Eoo`00g7oo00<007ooOol00Woo00<007ooOol0c7oo003KOol30002Ool3003=Ool00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo000gOol40006Ool20005Ool70010Ool70015Ool70003Ool4000nOol7
0003Ool40005Ool4000eOol70003Ool40005Ool40005Ool4000MOol003Ioo`03001oogoo009oo`03
001oogoo00=oo`8000Qoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`0eOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`00
00Aoo`03001oogoo01Yoo`00=Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol0A7oo00<0
07ooOol0BGoo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0?Woo00<007ooOol00goo00<0
07ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo03Eoo`03001oogoo00=oo`03001oogoo009o
o`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol06Woo000fOol00`00Oomoo`02
Ool00`00Oomoo`0=Ool00`00Oomoo`14Ool00`00Oomoo`19Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`0nOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool0=Goo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004
Ool00`00Oomoo`0JOol003Ioo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03001o
ogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`0eOol00`00Oomoo`03Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo01Yoo`00=Woo00<007ooOol00Woo
00<007ooOol03Goo00<007ooOol0A7oo00<007ooOol0BGoo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol0?Woo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo
03Eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo
00<007ooOol06Woo000fOol00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`14Ool00`00Oomo
o`19Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0nOol00`00Oomoo`03Ool00`00Oomo
o`02Ool01@00Oomoogoo000017oo00<007ooOol0=Goo00<007ooOol00goo00<007ooOol00Woo00D0
07ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`0JOol003Ioo`03001oogoo009oo`03
001oogoo00]oo`<004Aoo`<004Uoo`<000Eoo`03001oogoo009oo`03001oogoo03aoo`<000Eoo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0cOol30005Ool00`00Oomoo`02Ool01@00
Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo01Yoo`00=goo100047oo00<007ooOol0
A7oo00<007ooOol0BGoo00<007ooOol017oo1000@Goo00<007ooOol017oo10001Goo1000>7oo00<0
07ooOol017oo10001Goo10001Goo10007Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol0
0?mook5oo`00ogoo/Goo003oOonaOol0041oool004P002Uoo`00=Goo10001goo00<007oo00005goo
00<007ooOol037oo00<007ooOol01goo00<007ooOol017oo00<007ooOol017oo00<007ooOol00Woo
00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo01Eoo`03001oogoo00]oo`03001oogoo
00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol00003Ool01@00
Oomoogoo00005goo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00009oo`03001oogoo01Ioo`03001oogoo
00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
009oo`05001oogooOol00003Ool00`00Ool0000YOol003Aoo`03001oogoo009oo`03001oogoo00Ao
o`03001oo`0001Moo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Ao
o`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol00`00Oomo
o`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0001Moo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomo
o`0FOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007oo0000:Goo000dOol00`00Oomoo`02
Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00
=7oo00<007ooOol00Woo00<007ooOol017oo0`005goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0
000YOol003Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0000D0019oo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03goo0000:Goo000dOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`05
OolB00000`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00=7oo00<007ooOol00Woo00<007oo
Ool017oo00<007oo00l05goo3`0000<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol003Aoo`03001oogoo009oo`03
001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00aoo`P0009oo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000eOol40007Ool0
0`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`05Ool900000`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo1@000Woo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo009oo`H00003Ool03goo00=oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010
Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool0100?Oomoogoo10000Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo00D00003Ool03goo009oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0300moogoo
00<0009oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0600moogooOol03goo10005Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo0P00
00<03gooOol05Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moo`00000DOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0G
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOomoo`<0015oo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`04Ool2000?Ool00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol01Woo0`0037oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo00Uoo`8000Yoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0;Ool20008Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol03Goo0P001Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo00moo`8000Aoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0AOol20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000
:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol04goo
0P0000<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo
00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`8000aoo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`00Ool0000YOol0041oo`03001oo`0?01Moo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Ool0000;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1P0?Oomoogoo00moo`80000300moo`0002Uoo`00@7oo0P0000<03gooOol05Goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo008000Uoo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400mo
ogooOol20002Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`02Ool00`00Oomoo`06Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoo`0000l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol00goo0P001Woo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo001o
o`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00Eoo`03001oogoo00=oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`80009oo`07
00moogooOol03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol01Woo00<007ooOol00Woo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00H03gooOomoo`0000l3Ool01`0?
Oomoogoo00moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00Moo`80009oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0600moo`00001oo`0?0goo00L03gooOomoo`0?
Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`09Ool00`00Ool03`09Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?001oo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010
Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02Woo00<0000?Ool027oo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<007ooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l0
5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03001o
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0600moogooOol0000?17oo
00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300l007oo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0600moogoo001oo`0?17oo00D03gooOomoo`0?00=oo`03
00moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moo`0000Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moo`00009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0
041oo`80000300moogoo01Eoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool0100?Oomoo`001Woo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03`00Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<0
07oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0500moogooOol00005Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`00Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0G
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool00Woo00<007ooOol00Woo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00Woo00<0000?
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l0
5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00=oo`05001oogooOol03`07Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool01`0?Oomoogoo001oo`0?00Aoo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`04Ool01000
Oomoo`0?1goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00@03gooOol0009oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`00Ool03`07Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Ool00003Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01Goo00<007oo00l01goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03goo00000goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`00
02Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Ioo`0300003goo00Ioo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300l007oo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03
001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`00Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`00Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000[Ool60004Ool40007Ool0
0`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03`00Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol017oo00<0000?Ool017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00:goo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Ool00005Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`03Ool00`00Ool03`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03goo0000:Goo000/Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool0
3`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00@03gooOol000Aoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo009oo`04001oogoo00l5Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000]Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool3002400l00`0000l03`2N00l00`0000l03`0K00l00`00Oomoo`0W
Ool002ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
1@0?Oomoogoo00000goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01goo00D03gooOomoo`0000=oo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol002moo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`02Ool01000Oomoo`0?1Goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00@03gooOol000Aoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000Y
Ool002]oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0GOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol00goo00<007oo00l01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01goo00<03goo00001Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00:goo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0000moo`04Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?001oo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo
000/Ool40005Ool40007Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol017oo00<0000?Ool017oo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03`00Ool01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uo
o`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03001oogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03001oogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001o
o`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?001oo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`06Ool00`0000moo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03goo00000goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01Goo00<007oo00l01goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moo`0000=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Eo
o`03001oo`0?00Moo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0100?Oomoo`00
0Woo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol017oo00@007ooOol0
3`Moo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0100?Oomoo`000Woo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol00goo00D007ooOomoo`0?00Moo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000Y
Ool0041oo`80000300moogoo01Eoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool01`0?Oomoogoo001oo`0?00Eoo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo009oo`03001oogoo009oo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000Y
Ool0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool01`0?Oomoogoo001oo`0?00Eoo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moogoo009oo`03001oogoo009oo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0
041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0000moo`04Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool01@0?Oomoogoo00001Goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<0
07oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03001oogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0400moogoo0006Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<007ooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00@03gooOol000Ioo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?001oo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Ool0
0007Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03goo00000goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03`00Ool01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0400mo
ogoo0002Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?001oo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo
0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00@03gooOol0009oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`03001oogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001o
o`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01`0?Oomoogoo001oo`0?00=oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<007ooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo
00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0700moogooOol007oo00l00goo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0:Ool00`0000moo`08Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0000?Ool00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0:Ool00`0000moo`08Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool200000`0?Oomoo`0EOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0000?Ool00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`09Ool00`00Ool03`09Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000MOol4000OOol00`00Ool03`0GOol00`0?
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D007ooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02Goo
00<007oo00l02Goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moo`0002Uoo`0077oo00<007ooOol00Woo00<007ooOol077oo00<0
07oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05001oogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00Qoo`04001oogoo00l9Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000LOol00`00Oomoo`02Ool0
0`00Oomoo`0LOol00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03`00Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol027oo00@007ooOol03`Uoo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol001ao
o`03001oogoo009oo`03001oogoo01aoo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?001oogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`07Ool01@00Oomoogoo00l02Goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moo`0002Uoo`006Goo00@007ooOol000=oo`03001oogoo01eoo`03001oo`0?01Moo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?001oogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`07Ool0
1@00Oomoogoo00l02Goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`006Goo2@007Woo00<007oo00l05goo00<03goo
Ool037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moo`00Ool03`03Ool01@0?Oomoogoo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00Ioo`03
001oogoo009oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0025oo`03001oogoo01aoo`03001o
o`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Ool007oo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`06Ool00`00Oomoo`02Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00
Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOol0000?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol01Goo00<007ooOol00goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<0
07oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
0003Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00Eoo`03001oogoo00=oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03
001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00000goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`04Ool00`00Oomoo`04Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000MOol4
000OOol200000`0?Oomoo`0EOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00H03gooOomoo`0?0002Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00Aoo`03001oogoo00Aoo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0
000YOol001aoo`03001oo`00009oo`03001oogoo01aoo`03001oo`0?01Moo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01P0?Oomoogoo00l0009oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol00goo00<007ooOol0
1Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`0077oo00<007oo00000Woo00<007ooOol077oo
00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0900moogoo
Ool03goo001oo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`03Ool00`00Oomoo`05Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo
000LOol00`00Ool00002Ool00`00Oomoo`0LOol00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00T03gooOomoo`0?Ool007oo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo009oo`03001oogoo00Io
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Ool0000YOol001aoo`03001oo`00009oo`03001oogoo01aoo`03
001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00Woo00<0000?Ool00Woo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo009oo`03001oogoo00Ioo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000Y
Ool001eoo`800003Ool007oo01ioo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00<0000?Ool00Woo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0500moogooOol00009Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05001oogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00D03gooOomoo`0000Uoo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D007ooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol01@0?Oomoogoo00002Goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`00
02Uoo`007Goo10007goo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@00Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0400moogoo000:Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo
000LOol00`00Oomoo`02Ool01000Oomoo`0027oo100017oo10001goo00<007oo00l05goo00<03goo
Ool037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?001oogoo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0400moogoo000:Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03goo0000:Goo000LOol00`00Oomoo`02Ool01000Oomoo`002Woo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?001oogoo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moo`0000]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Ool0000YOol001aoo`03001oogoo009oo`04001oogoo000:Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moo`00Ool03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo00002goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
o`0002Uoo`007Goo00@007ooOol000=oo`03001oogoo00Aoo`H000=oo`03001oogoo009oo`03001o
ogoo00Aoo`<009h03`0300003`0?06X03`0300003`0?03D03`03001oogoo02Moo`0077oo200027oo
00@007ooOol000Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOol0000?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?001oo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03goo0000:Goo000LOol00`00Oomoo`0=Ool01000Oomoo`0017oo00<007ooOol0
0Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoo`0000l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300l007oo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0
02eoo`03001oo`0000Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`00
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`00Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03goo0000:Goo000]Ool00`00Ool00004Ool00`00Oomoo`02Ool00`00Oomo
o`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol0000GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<007ooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00;Woo0P001Goo
10001goo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00005goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Eoo`0300003goo00aoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol001aoo`03001o
ogoo009oo`03001oogoo01aoo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Goo00<0000?Ool037oo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`00
02Uoo`0077oo1P007Woo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01P0?Oomoogoo00l001Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0DOol00`00Ool03`0=Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo
000MOol01@00Oomoogoo00007Woo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0DOol00`00Ool03`0=Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3goo0000:Goo000LOol00`00Oomoo`02Ool00`00Oomoo`0LOol00`00Ool03`0GOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo
00005Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Aoo`03001oo`0?00eoo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Ool0000YOol001aoo`03001oogoo009oo`03001oogoo01aoo`03001o
o`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?009oo`03001oogoo019oo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0COol01000Oomoo`0?3Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`0077oo00<0
07ooOol08Goo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l00Woo00<007ooOol04Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01=oo`04001oogoo00l=Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
0000:Goo0010Ool200000`0?Oomoo`0EOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool00`00Oomoo`0BOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol04Woo00D007ooOomoo`0?00eoo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00=oo`03001oogoo015oo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol01@00Oomoogoo00l03Goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l00goo00<007ooOol04Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo015oo`03001oogoo009oo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Ool0000YOol001eoo`@001moo`03001oo`0?01Moo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?00Aoo`03001oogoo011oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0AOol0
0`00Oomoo`02Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000LOol00`00
Ool00002Ool00`00Oomoo`0LOol00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`04Ool00`00Oomoo`0@Ool00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol04Goo00<007ooOol00Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moo`0002Uoo`0077oo00<007oo00000Woo00<007ooOol077oo00<0
07oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l017oo00<007ooOol047oo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo011oo`03001oogoo00=oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0
000YOol001aoo`03001oo`00009oo`03001oogoo01aoo`03001oo`0?01Moo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00Eoo`03
001oogoo00moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0@Ool00`00Oomoo`03
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000LOol00`00Ool00002Ool0
0`00Oomoo`0LOol00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`05Ool00`00Oomoo`0?Ool00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol03goo00<007ooOol017oo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moo`0002Uoo`007Goo0P0000=oo`00Ool07Woo00<007oo00l05goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
1Woo00<007ooOol03Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo00moo`03001o
ogoo00Aoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?
01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?00Ioo`03001oogoo00ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0?Ool00`00Oomoo`04Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo
0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`07Ool00`00Oomoo`0=Ool00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol03Woo00<007ooOol01Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moo`0002Uoo`00@7oo0P0000<03gooOol05Goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l01goo00<007ooOol03Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo00ioo`03001oogoo00Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Ool0000YOol001eoo`@001moo`03001oo`0?01Moo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
00Moo`03001oogoo00eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0=Ool00`00
Oomoo`06Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000LOol00`00Ool0
0002Ool00`00Oomoo`0LOol00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`08Ool00`00Oomoo`0<Ool00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol03Goo00<007ooOol01Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moo`0002Uoo`0077oo00<007oo00000Woo00<007ooOol077oo00<007oo
00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l027oo00<007ooOol037oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo00aoo`03001oogoo00Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000Y
Ool001aoo`03001oo`00009oo`03001oogoo01aoo`03001oo`0?01Moo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00Uoo`03001o
ogoo00]oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0<Ool00`00Oomoo`07Ool0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000LOol00`00Ool00002Ool00`00
Oomoo`0LOol00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`09Ool00`00Oomoo`0;Ool00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol037oo00<007ooOol01goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moo`0002Uoo`007Goo0P0000=oo`00Ool07Woo00<007oo00l05goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l02Woo
00<007ooOol02Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo00]oo`03001oogoo
00Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Mo
o`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?00Yoo`03001oogoo00Yoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0;Ool00`00Oomoo`08Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010
Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0:Ool00`00Oomoo`0:Ool00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol02Woo00<007ooOol02Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l02goo00<007ooOol02Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo00Yoo`03001oogoo00Uoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00]oo`03001oogoo
00Uoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0:Ool00`00Oomoo`09Ool00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0<Ool00`00Oomoo`08Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol02Goo00<0
07ooOol02Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo0P0000<0
3gooOol05Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l037oo00<007ooOol027oo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo00Uoo`03001oogoo00Yoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0
000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00aoo`03001oogoo00Qoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`08Ool00`00Oomoo`0;Ool00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0=Ool00`00Oomoo`07Ool0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol027oo00<007ooOol02goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l03Goo
00<007ooOol01goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo00Qoo`03001oogoo
00]oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Mo
o`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?00ioo`03001oogoo00Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`07Ool00`00Oomoo`0<Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010
Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0>Ool00`00Oomoo`06Ool00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol01goo00<007ooOol037oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l03Woo00<007ooOol01Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo00Ioo`03001oogoo00eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00moo`03001oogoo
00Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`06Ool00`00Oomoo`0=Ool00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000]Ool40004Ool40007Ool00`00Ool0
3`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0?Ool00`00Oomoo`05Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol01Woo00<007ooOol03Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uo
o`00;7oo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Aoo`03001oo`0?01Moo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?00moo`03001oogoo00Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`05Ool0
0`00Oomoo`0>Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000/Ool00`00
Oomoo`02Ool01000Oomoo`0017oo00<007ooOol017oo00<007oo00l05goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l047oo00<0
07ooOol017oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo00Eoo`03001oogoo00io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol002aoo`8000=oo`04001oogoo
0004Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0@Ool00`00Oomoo`04Ool00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol017oo00<007ooOol03goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moo`0002Uoo`00;7oo00<007oo00000P000goo00<007ooOol00Woo00<0
07ooOol017oo0`00/P0?00<0000?00l0@P0?00<0000?00l0B@0?00<007ooOol09goo000/Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0AOol00`00
Oomoo`03Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol017oo00<007ooOol03goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00;Goo00<007ooOol017oo00<0
07ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l04Goo00<007ooOol00goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo00=oo`03001oogoo011oo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Ool0000YOol002ioo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?019oo`03001oogoo009oo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`03Ool00`00Oomoo`0@Ool00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03goo0000:Goo000_Ool30003Ool40007Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0BOol0
0`00Oomoo`02Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol00Woo00<007ooOol0
4Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo
00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l04goo00D007ooOomoo`0?00eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`02Ool00`00
Oomoo`0AOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool0
3`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0COol01@00Oomoogoo00l03Goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo009o
o`03001oogoo015oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03
001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01=oo`05001oogooOol03`0=Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03goo
Oomoo`0001Aoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001o
o`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Aoo`04001oogoo00l=Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`00
01Aoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Mo
o`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Aoo`04001oogoo00l=Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0001Aoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Aoo`04001oogoo00l=Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol001Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`03
001oo`0?00eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`005Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moo`0002Uoo`00@7oo0P0000<03gooOol05Goo00<03gooOol037oo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05Goo00<007oo00l0
3Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moo`0001Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Ioo`0300003goo00aoo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Ool0000FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo
0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0FOol00`0000moo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3goo00005Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo
00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05Woo00<0000?Ool037oo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300l007oo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`03001oogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?001oo`0FOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`00
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<007ooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<007ooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`03001oogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0
000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300l007oo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`00Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool0
0`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?001oo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomoogoo00moo`0000lHOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Ool0000;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0200?Oomoogoo00moo`0000lHOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Ool0000;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
200?Oomoogoo00moo`0000lHOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo
0010Ool200000`0?Oomoo`0EOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Ool0000;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomoogoo00l007oo
00lHOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0G
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol0100?Oomoo`002Woo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00P03gooOomoo`0?001oo`0?67oo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00@0
3gooOol000Yoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol00002Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol01@0?Oomoogoo0000
2Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`00009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0500moogooOol00009Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoo`0000l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`00
02Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol00Woo00<007ooOol01Woo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOol0000?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0
000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo009oo`03001oogoo00Ioo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moo`00Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`03Ool00`00Oomoo`05Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Ool007oo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
o`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol00goo00<007ooOol01Goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03`00Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00Aoo`03001oogoo00Ao
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500l007ooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`04Ool00`00Oomoo`04
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@00Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol01Goo00<007ooOol0
0goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00H03gooOomo
o`0000l3Ool0100?Oomoo`0?67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uo
o`00@7oo0P0000<03gooOol05Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol01Woo00<007ooOol00Woo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00H03gooOomoo`0000l3
Ool0100?Oomoo`0?67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo
00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol01Woo00<007ooOol00Woo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00H03gooOol007oo00l3Ool0100?Oomo
o`0?67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l0
5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol01goo00D007ooOomoo`0?00Uoo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0600moogoo001oo`0?0goo00@03gooOol03aQoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00Moo`05001oogooOol03`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool01P0?Oomoo`00Ool03`=oo`0400moogoo00lHOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`08Ool01000Oomo
o`0?2Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo00000Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000Y
Ool0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00Qoo`04001oogoo00l9Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Ool00002Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<0
07oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02Goo00<007oo00l02Goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03`00Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00Uoo`03001oo`0?00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300l007oo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000/Ool40005Ool40007Ool00`00Ool03`0GOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0:Ool00`0000moo`08Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`00Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00:goo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03001oogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0600moogooOol0000?17oo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol002]oo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?001oo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool01P0?Oomoo`00
Ool03`Aoo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03goo0000:Goo000[Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo
00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03`00Ool01goo00<03gooOol01Goo
00<03gooOol017oo00<03goo00000Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol002aoo`@000Aoo`03001o
ogoo009oo`03001oogoo00Aoo`<001Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moo`0000Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moo`00009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000[
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l05goo00<03goo
Ool037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05goo00<03gooOol02goo00@03gooOol000Ioo`0300moogoo00Eoo`0300moogoo00Aoo`0300l0
07oo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03goo0000:Goo000[Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo
00<007ooOol017oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00D03gooOomoo`00
00Eoo`0300moogoo00Eoo`0300moogoo00Aoo`03001oogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo
000[Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l05goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05goo00<03gooOol02goo00<03gooOol00Woo00<007ooOol00Woo00<03gooOol01Goo00<0
3gooOol017oo00<007ooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol002aoo`@000Eoo`@000Moo`03
001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00=oo`05001oogooOol03`07
Ool00`0?Oomoo`03Ool00`0000moo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l0
5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol017oo00@007ooOol03`Moo`0300moogoo
009oo`03001oo`0?00Aoo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`00Ool03`07Ool00`0?Ool000020002Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol01Woo0`001Woo00<03`00Ool017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Ool0000YOol0041oo`03001oo`0001Moo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo
00Aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00
Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool01@00Oomoogoo00000goo00D007ooOomoo`0001Moo`03001oogoo00]oo`03001oogoo
00Moo`T000Ioo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`0F
Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007oo0000:Goo0010Ool00`00Ool0000GOol0
0`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol0
1goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000=oo`05001o
ogooOol0000GOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00<007ooOol05Woo00<007ooOol0
2goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
0Woo00D007ooOomoo`0000=oo`03001oo`0002Uoo`00@7ooo`00B000:Goo003oOonaOol00?mook5o
o`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003=
Ool50004Ool30002Ool30003Ool50003Ool50005Ool4002iOol00<ioo`03001oogoo00Ioo`03001o
ogoo009oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000
17oo00<007ooOol0]Woo003>Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo
00<007ooOol01goo00D007ooOomoo`000;eoo`00cWoo1@0017oo00<007ooOol00Woo00<007ooOol0
0Woo10001Goo100017oo1P00^7oo003>Ool00`00Oomoo`02Ool01000Oomoogoo0P000goo00D007oo
Oomoo`0000=oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`2f
Ool00<ioo`03001oogoo009oo`06001oogooOol007oo0`001Goo0`001Woo1@0017oo1000^Goo003>
Ool00`00Oomoo`02Ool01@00Oomoogoo0000f7oo003=Ool60004Ool00`00Oomoo`3FOol00=Ioo`80
0=Qoo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-1.82989, -19.5146, \
0.0186604, 0.640329}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1600}, {0, 1082}},
WindowSize->{780, 1029},
WindowMargins->{{207, Automatic}, {Automatic, 6}},
Magnification->1.5
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 69, 1, 42, "Input"],
Cell[1789, 52, 130, 2, 111, "Input"],

Cell[CellGroupData[{
Cell[1944, 58, 294, 6, 177, "Input"],
Cell[2241, 66, 158, 2, 58, "Output"]
}, Open  ]],
Cell[2414, 71, 2549, 44, 667, "Input"],

Cell[CellGroupData[{
Cell[4988, 119, 28, 0, 79, "Section"],

Cell[CellGroupData[{
Cell[5041, 123, 427, 7, 180, "Input"],
Cell[5471, 132, 137, 2, 74, "Output"],
Cell[5611, 136, 220, 4, 35, "Print"],
Cell[5834, 142, 378, 9, 38, "Print"],
Cell[6215, 153, 490, 13, 51, "Print"],
Cell[6708, 168, 302, 6, 58, "Print"],
Cell[7013, 176, 264, 4, 35, "Print"],

Cell[CellGroupData[{
Cell[7302, 184, 132379, 2405, 279, 15479, 957, "GraphicsData", "PostScript", \
"Graphics"],
Cell[139684, 2591, 130407, 2427, 279, 15982, 1010, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[270152, 5025, 27, 0, 79, "Section"],

Cell[CellGroupData[{
Cell[270204, 5029, 427, 7, 180, "Input"],
Cell[270634, 5038, 86, 1, 71, "Output"],
Cell[270723, 5041, 358, 9, 38, "Print"],
Cell[271084, 5052, 240, 4, 35, "Print"],
Cell[271327, 5058, 490, 13, 51, "Print"],
Cell[271820, 5073, 302, 6, 58, "Print"],
Cell[272125, 5081, 1107, 29, 89, "Print"],
Cell[273235, 5112, 264, 4, 35, "Print"],

Cell[CellGroupData[{
Cell[273524, 5120, 132275, 2404, 279, 15488, 958, "GraphicsData", \
"PostScript", "Graphics"],
Cell[405802, 7526, 130638, 2432, 279, 16079, 1013, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[536501, 9965, 28, 0, 79, "Section"],

Cell[CellGroupData[{
Cell[536554, 9969, 517, 9, 201, "Input"],
Cell[537074, 9980, 89, 1, 65, "Output"],
Cell[537166, 9983, 303, 6, 35, "Print"],
Cell[537472, 9991, 244, 4, 35, "Print"],
Cell[537719, 9997, 307, 6, 35, "Print"],
Cell[538029, 10005, 295, 6, 35, "Print"],
Cell[538327, 10013, 286, 6, 35, "Print"],
Cell[538616, 10021, 224, 4, 35, "Print"],

Cell[CellGroupData[{
Cell[538865, 10029, 132305, 2404, 279, 15397, 956, "GraphicsData", \
"PostScript", "Graphics"],
Cell[671173, 12435, 133423, 2451, 279, 16004, 997, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[804657, 14893, 30, 0, 79, "Section"],

Cell[CellGroupData[{
Cell[804712, 14897, 516, 9, 226, "Input"],
Cell[805231, 14908, 88, 1, 65, "Output"],
Cell[805322, 14911, 220, 4, 35, "Print"],
Cell[805545, 14917, 332, 7, 35, "Print"],
Cell[805880, 14926, 317, 6, 35, "Print"],
Cell[806200, 14934, 318, 7, 35, "Print"],
Cell[806521, 14943, 295, 6, 35, "Print"],
Cell[806819, 14951, 246, 4, 35, "Print"],
Cell[807068, 14957, 224, 4, 35, "Print"],

Cell[CellGroupData[{
Cell[807317, 14965, 132463, 2406, 279, 15401, 956, "GraphicsData", \
"PostScript", "Graphics"],
Cell[939783, 17373, 130853, 2422, 279, 16006, 1000, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1070697, 19802, 35, 0, 79, "Section"],
Cell[1070735, 19804, 75, 0, 47, "Text"],

Cell[CellGroupData[{
Cell[1070835, 19808, 639, 11, 282, "Input"],
Cell[1071477, 19821, 294, 5, 94, "Output"],
Cell[1071774, 19828, 111, 2, 43, "Output"],
Cell[1071888, 19832, 211, 4, 69, "Output"],
Cell[1072102, 19838, 107, 2, 43, "Output"],
Cell[1072212, 19842, 206, 3, 69, "Output"],
Cell[1072421, 19847, 106, 2, 57, "Output"],
Cell[1072530, 19851, 522, 8, 198, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1073089, 19864, 874, 17, 357, "Input"],
Cell[1073966, 19883, 262, 4, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1074265, 19892, 114, 2, 42, "Input"],
Cell[1074382, 19896, 108, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1074527, 19903, 551, 11, 201, "Input"],
Cell[1075081, 19916, 332, 6, 94, "Output"],
Cell[1075416, 19924, 224, 4, 35, "Print"],
Cell[1075643, 19930, 324, 7, 35, "Print"],
Cell[1075970, 19939, 317, 6, 35, "Print"],
Cell[1076290, 19947, 318, 7, 35, "Print"],
Cell[1076611, 19956, 224, 4, 35, "Print"],
Cell[1076838, 19962, 318, 7, 35, "Print"],
Cell[1077159, 19971, 295, 6, 35, "Print"],

Cell[CellGroupData[{
Cell[1077479, 19981, 131430, 2419, 279, 15741, 986, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1208912, 22402, 133668, 2430, 279, 15682, 969, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

